@@ -7,9 +7,9 @@ Build a list of significant excesses in a Fermi-LAT map.
 Context
 -------
 
-The first task in a source catalogue production is to identify
+The first task in a source catalog production is to identify
 significant excesses in the data that can be associated to unknown
-sources and provide a preliminary parametrization in term of position,
+sources and provide a preliminary parametrization in terms of position,
 extent, and flux. In this notebook we will use Fermi-LAT data to
 illustrate how to detect candidate sources in counts images with known
 background.
@@ -57,7 +57,7 @@ import matplotlib.pyplot as plt
 from IPython.display import display
 from gammapy.datasets import MapDataset
 from gammapy.estimators import ASmoothMapEstimator, TSMapEstimator
-from gammapy.estimators.utils import find_peaks
+from gammapy.estimators.utils import find_peaks, find_peaks_in_flux_map
 from gammapy.irf import EDispKernelMap, PSFMap
 from gammapy.maps import Map
 from gammapy.modeling.models import PointSpatialModel, PowerLawSpectralModel, SkyModel
@@ -167,7 +167,7 @@ maps = estimator.run(dataset)
 
 fig, (ax1, ax2, ax3) = plt.subplots(
     ncols=3,
-    figsize=(15, 3),
+    figsize=(20, 3),
     subplot_kw={"projection": counts.geom.wcs},
     gridspec_kw={"left": 0.1, "right": 0.98},
 )
@@ -202,7 +202,7 @@ ax = maps["sqrt_ts"].plot(add_cbar=True)
 ax.scatter(
     sources["ra"],
     sources["dec"],
-    transform=plt.gca().get_transform("icrs"),
+    transform=ax.get_transform("icrs"),
     color="none",
     edgecolor="w",
     marker="o",
@@ -213,6 +213,15 @@ plt.show()
 
 # sphinx_gallery_thumbnail_number = 3
 
+
+######################################################################
+# We can also utilise `~gammapy.estimators.utils.find_peaks_in_flux_map`
+# to display various parameters from the FluxMaps
+
+sources_flux_map = find_peaks_in_flux_map(maps, threshold=5, min_distance="0.25 deg")
+display(sources_flux_map)
+
+
 ######################################################################
 # Note that we used the instrument point-spread-function (PSF) as kernel,
 # so the hypothesis we test is the presence of a point source. In order to
