@@ -59,6 +59,7 @@ from gammapy.analysis import Analysis, AnalysisConfig
 from gammapy.datasets import MapDatasetOnOff
 from gammapy.estimators import ExcessMapEstimator
 from gammapy.makers import RingBackgroundMaker
+from gammapy.visualization import plot_distribution
 
 log = logging.getLogger(__name__)
 
@@ -237,7 +238,7 @@ excess_map = lima_maps["npred_excess"]
 
 # We can plot the excess and significance maps
 fig, (ax1, ax2) = plt.subplots(
-    figsize=(11, 5), subplot_kw={"projection": lima_maps.geom.wcs}, ncols=2
+    figsize=(11, 4), subplot_kw={"projection": lima_maps.geom.wcs}, ncols=2
 )
 
 ax1.set_title("Significance map")
@@ -258,41 +259,35 @@ plt.show()
 
 # create a 2D mask for the images
 significance_map_off = significance_map * exclusion_mask
-significance_all = significance_map.data[np.isfinite(significance_map.data)]
-significance_off = significance_map_off.data[np.isfinite(significance_map_off.data)]
 
-fig, ax = plt.subplots()
-ax.hist(
-    significance_all,
-    density=True,
-    alpha=0.5,
-    color="red",
-    label="all bins",
-    bins=21,
+kwargs_axes = {"xlabel": "Significance", "yscale": "log", "ylim": (1e-5, 1)}
+
+ax, _ = plot_distribution(
+    significance_map,
+    kwargs_hist={
+        "density": True,
+        "alpha": 0.5,
+        "color": "red",
+        "label": "all bins",
+        "bins": 21,
+    },
+    kwargs_axes=kwargs_axes,
 )
 
-ax.hist(
-    significance_off,
-    density=True,
-    alpha=0.5,
-    color="blue",
-    label="off bins",
-    bins=21,
+ax, res = plot_distribution(
+    significance_map_off,
+    ax=ax,
+    func="norm",
+    kwargs_hist={
+        "density": True,
+        "alpha": 0.5,
+        "color": "blue",
+        "label": "off bins",
+        "bins": 21,
+    },
+    kwargs_axes=kwargs_axes,
 )
 
-# Now, fit the off distribution with a Gaussian
-mu, std = norm.fit(significance_off)
-x = np.linspace(-8, 8, 50)
-p = norm.pdf(x, mu, std)
-ax.plot(x, p, lw=2, color="black")
-ax.legend()
-ax.set_xlabel("Significance")
-ax.set_yscale("log")
-ax.set_ylim(1e-5, 1)
-xmin, xmax = np.min(significance_all), np.max(significance_all)
-ax.set_xlim(xmin, xmax)
-
-print(f"Fit results: mu = {mu:.2f}, std = {std:.2f}")
 plt.show()
 
 # sphinx_gallery_thumbnail_number = 2
