@@ -7,7 +7,7 @@ Compute per-observation and nightly fluxes of four Crab nebula observations.
 Prerequisites
 -------------
 
--  Knowledge of the high level interface to perform data reduction, see
+-  Knowledge of the high level interface to perform data reduction, see the
    :doc:`/tutorials/starting/analysis_1` tutorial.
 
 Context
@@ -26,8 +26,7 @@ run-wise binning, nightly, weekly etc.
 energies, so we expect constant brightness within statistical and
 systematic errors. Compute per-observation and nightly fluxes of the
 four Crab nebula observations from the H.E.S.S. first public test data
-release**\ `o <https://www.mpi-hd.mpg.de/hfm/HESS/pages/dl3-dr1/>`__\ **to
-check it.**
+release.**
 
 Proposed approach
 -----------------
@@ -87,7 +86,7 @@ check_tutorials_setup()
 # using the high level interface of Gammapy.
 #
 # From the high level interface, the data reduction for those observations
-# is performed as followed
+# is performed as follows.
 #
 
 
@@ -103,7 +102,8 @@ conf_3d = AnalysisConfig()
 # Definition of the data selection
 # ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 #
-# Here we use the Crab runs from the HESS DL3 data release 1
+# Here we use the Crab runs from the
+# `H.E.S.S. DL3 data release 1 <https://www.mpi-hd.mpg.de/hfm/HESS/pages/dl3-dr1/>`__.
 #
 
 conf_3d.observations.obs_ids = [23523, 23526, 23559, 23592]
@@ -191,7 +191,7 @@ analysis_3d.set_models(models)
 # bin.
 #
 # If we don’t set any time interval, the
-# `~gammapy.estimators.LightCurveEstimator` is determines the flux of
+# `~gammapy.estimators.LightCurveEstimator` determines the flux of
 # each dataset and places it at the corresponding time in the light curve.
 # Here one dataset equals to one observing run.
 #
@@ -208,7 +208,7 @@ lc_3d = lc_maker_3d.run(analysis_3d.datasets)
 
 
 ######################################################################
-# The LightCurve object contains a table which we can explore.
+# The lightcurve `~gammapy.estimators.FluxPoints` object `lc_3d` contains a table which we can explore.
 #
 
 # Example showing how to change just before plotting the threshold on the signal significance
@@ -243,7 +243,8 @@ conf_1d = AnalysisConfig()
 # Definition of the data selection
 # ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 #
-# Here we use the Crab runs from the HESS DL3 data release 1
+# Here we use the Crab runs from the
+# `H.E.S.S. DL3 data release 1 <https://www.mpi-hd.mpg.de/hfm/HESS/pages/dl3-dr1/>`__
 #
 
 conf_1d.observations.obs_ids = [23523, 23526, 23559, 23592]
@@ -362,7 +363,7 @@ time_intervals = [
 
 ######################################################################
 # To compute the LC on the time intervals defined above, we pass the
-# `LightCurveEstimator` the list of time intervals.
+# `~gammapy.estimators.LightCurveEstimator` the list of time intervals.
 #
 # Internally, datasets are grouped per time interval and a flux extraction
 # is performed for each group.
