@@ -37,6 +37,7 @@ import matplotlib.pyplot as plt
 from matplotlib.colors import LogNorm
 from gammapy.astro.darkmatter import (
     DarkMatterAnnihilationSpectralModel,
+    DarkMatterDecaySpectralModel,
     JFactory,
     PrimaryFlux,
     profiles,
@@ -84,7 +85,7 @@ print("DISTANCE_GC:", profiles.DMProfile.DISTANCE_GC)
 #
 # There are utilities to compute J-Factor maps that can serve as a basis
 # to compute J-Factors for certain regions. In the following we compute a
-# J-Factor map for the Galactic Centre region
+# J-Factor annihilation map for the Galactic Centre region
 #
 
 profile = profiles.NFWProfile(r_s=20 * u.kpc)
@@ -132,6 +133,46 @@ print(
     f"{profile.__class__.__name__} is {total_jfact:.3g}"
 )
 
+######################################################################
+# The J-Factor can also be computed for dark matter decay
+jfactory = JFactory(
+    geom=geom,
+    profile=profile,
+    distance=profiles.DMProfile.DISTANCE_GC,
+    annihilation=False,
+)
+jfact_decay = jfactory.compute_jfactor()
+
+jfact_map = WcsNDMap(geom=geom, data=jfact_decay.value, unit=jfact_decay.unit)
+plt.figure()
+ax = jfact_map.plot(cmap="viridis", norm=LogNorm(), add_cbar=True)
+plt.title(f"J-Factor [{jfact_map.unit}]")
+
+# 1 deg circle usually used in H.E.S.S. analyses without the +/- 0.3 deg band around the plane
+sky_reg = CircleSkyRegion(center=position, radius=1 * u.deg)
+pix_reg = sky_reg.to_pixel(wcs=geom.wcs)
+pix_reg.plot(ax=ax, facecolor="none", edgecolor="red", label="1 deg circle")
+
+sky_reg_rec = RectangleSkyRegion(center=position, height=0.6 * u.deg, width=2 * u.deg)
+pix_reg_rec = sky_reg_rec.to_pixel(wcs=geom.wcs)
+pix_reg_rec.plot(ax=ax, facecolor="none", edgecolor="orange", label="+/- 0.3 deg band")
+
+plt.legend()
+plt.show()
+
+total_jfact_decay = (
+    pix_reg.to_mask().multiply(jfact_decay).sum()
+    - pix_reg_rec.to_mask().multiply(jfact_decay).sum()
+)
+total_jfact_decay = (
+    pix_reg.to_mask().multiply(jfact_decay).sum()
+    - pix_reg_rec.to_mask().multiply(jfact_decay).sum()
+)
+print(
+    "J-factor in 1 deg circle without the +/- 0.3 deg band around GC assuming a "
+    f"{profile.__class__.__name__} is {total_jfact_decay:.3g}"
+)
+
 ######################################################################
 # Gamma-ray spectra at production
 # -------------------------------
@@ -154,8 +195,9 @@ for mDM, ax in zip(mDMs, axes):
     ax.set_ylabel("dN/dE")
 
     for channel in ["tau", "mu", "b", "Z"]:
+        fluxes = PrimaryFlux(mDM=mDM, channel=channel)
         fluxes.channel = channel
-        fluxes.table_model.plot(
+        fluxes.plot(
             energy_bounds=[mDM / 100, mDM],
             ax=ax,
             label=channel,
@@ -168,8 +210,8 @@ plt.show()
 
 
 ######################################################################
-# Flux maps
-# ---------
+# Flux maps for annihilation
+# --------------------------
 #
 # Finally flux maps can be produced like this:
 #
@@ -189,3 +231,27 @@ plt.title(
 )
 
 plt.show()
+
+
+######################################################################
+# Flux maps for decay
+# -------------------
+#
+# Finally flux maps for decay can be produced like this:
+#
+
+channel = "Z"
+massDM = 10 * u.TeV
+diff_flux = DarkMatterDecaySpectralModel(mass=massDM, channel=channel)
+int_flux = (
+    jfact_decay * diff_flux.integral(energy_min=0.1 * u.TeV, energy_max=10 * u.TeV)
+).to("cm-2 s-1")
+
+flux_map = WcsNDMap(geom=geom, data=int_flux.value, unit="cm-2 s-1")
+plt.figure()
+ax = flux_map.plot(cmap="viridis", norm=LogNorm(), add_cbar=True)
+plt.title(
+    f"Flux [{int_flux.unit}]\n m$_{{DM}}$={fluxes.mDM.to('TeV')}, channel={fluxes.channel}"
+)
+
+plt.show()
