@@ -9,7 +9,7 @@ related to modeling and fitting data. This includes spectral, spatial
 and temporal model classes, as well as the fit and parameter API.The
 models follow a naming scheme which contains the category as a suffix to
 the class name. An overview of all the available models can be found in
-the `model gallery <../../user-guide/model-gallery/index.rst>`__.
+the :ref:`model-gallery`.
 
 Note that there are separate tutorials,
 :doc:`/tutorials/api/model_management` and
@@ -46,7 +46,7 @@ check_tutorials_setup()
 # ---------------
 #
 # All models are imported from the `~gammapy.modeling.models` namespace.
-# Let’s start with a `PowerLawSpectralModel`:
+# Let’s start with a `~gammapy.modeling.models.PowerLawSpectralModel`:
 #
 
 from gammapy.modeling.models import PowerLawSpectralModel
@@ -57,7 +57,7 @@ print(pwl)
 
 ######################################################################
 # To get a list of all available spectral models you can import and print
-# the spectral model registry or take a look at the :ref:`spectral-models-gallery`
+# the spectral model registry or take a look at the :ref:`model-gallery`
 #
 
 from gammapy.modeling.models import SPECTRAL_MODEL_REGISTRY
@@ -152,7 +152,7 @@ plt.show()
 # spectral shape. They can be typically used for adjusting template based
 # models, or adding a EBL correction to some analytic model.
 #
-# To check if a given `SpectralModel` is a norm model, you can simply
+# To check if a given `~gammapy.modeling.models.SpectralModel` is a norm model, you can simply
 # look at the `is_norm_spectral_model` property
 #
 
@@ -163,7 +163,7 @@ for model in SPECTRAL_MODEL_REGISTRY:
 
 
 ######################################################################
-# As an example, we see the `PowerLawNormSpectralModel`
+# As an example, we see the `~gammapy.modeling.models.PowerLawNormSpectralModel`
 #
 
 from gammapy.modeling.models import PowerLawNormSpectralModel
@@ -182,7 +182,7 @@ print(pwl_norm(energy))
 
 ######################################################################
 # A typical use case of a norm model would be in applying spectral
-# correction to a `TemplateSpectralModel`. A template model is defined
+# correction to a `~gammapy.modeling.models.TemplateSpectralModel`. A template model is defined
 # by custom tabular values provided at initialization.
 #
 
@@ -226,7 +226,7 @@ print(model_add)
 
 ######################################################################
 # Spatial models are imported from the same `~gammapy.modeling.models`
-# namespace, let’s start with a `GaussianSpatialModel`:
+# namespace, let’s start with a `~gammapy.modeling.models.GaussianSpatialModel`:
 #
 
 from gammapy.modeling.models import GaussianSpatialModel
@@ -237,7 +237,7 @@ print(gauss)
 
 ######################################################################
 # Again you can check the `SPATIAL_MODELS` registry to see which models
-# are available or take a look at the :ref:`spatial-models-gallery`
+# are available or take a look at the :ref:`model-gallery`
 #
 
 from gammapy.modeling.models import SPATIAL_MODEL_REGISTRY
@@ -304,17 +304,15 @@ print(gauss.to_region())
 
 
 ######################################################################
-# Now we can plot the region on an sky image:
+# Now we can plot the region on a sky image:
 #
 
-# create and plot the model
 plt.figure()
 gauss_elongated = GaussianSpatialModel(
     lon_0="0 deg", lat_0="0 deg", sigma="0.2 deg", e=0.7, phi="45 deg"
 )
 ax = gauss_elongated.plot(add_cbar=True)
 
-# add region illustration
 region = gauss_elongated.to_region()
 region_pix = region.to_pixel(ax.wcs)
 ax.add_artist(region_pix.as_artist(ec="w", fc="None"))
@@ -348,7 +346,7 @@ regions.write(
 
 ######################################################################
 # Temporal models are imported from the same `~gammapy.modeling.models`
-# namespace, let’s start with a `GaussianTemporalModel`:
+# namespace, let’s start with a `~gammapy.modeling.models.GaussianTemporalModel`:
 #
 
 from gammapy.modeling.models import GaussianTemporalModel
@@ -391,9 +389,6 @@ plt.show()
 # SkyModel
 # --------
 #
-
-
-######################################################################
 # The `~gammapy.modeling.models.SkyModel` class combines a spectral, and
 # optionally, a spatial model and a temporal. It can be created from
 # existing spectral, spatial and temporal model components:
@@ -479,7 +474,7 @@ print(diffuse)
 # Note that if the spatial model is not normalized over the sky it has to
 # be combined with a normalized spectral model, for example
 # `~gammapy.modeling.models.PowerLawNormSpectralModel`. This is the only
-# case in `gammapy.models.SkyModel` where the unit is fully attached to
+# case in `~gammapy.models.SkyModel` where the unit is fully attached to
 # the spatial model.
 #
 
@@ -520,7 +515,7 @@ display(model.parameters.to_table())
 #
 # In a typical analysis scenario a model consists of multiple model
 # components, or a “catalog” or “source library”. To handle this list of
-# multiple model components, Gammapy has a `Models` class:
+# multiple model components, Gammapy has a `~gammapy.modeling.models.Models` class:
 #
 
 from gammapy.modeling.models import Models
@@ -547,9 +542,10 @@ print(models.names)
 
 
 ######################################################################
-# Note that a `SkyModel` object can be evaluated for a given longitude,
-# latitude, and energy, but the `Models` object cannot. This `Models`
-# container object will be assigned to `Dataset` or `Datasets`
+# Note that a `~gammapy.modeling.models.SkyModel` object can be evaluated for a given longitude,
+# latitude, and energy, but the `~gammapy.modeling.models.Models` object cannot.
+# This `~gammapy.modeling.models.Models`
+# container object will be assigned to `~gammapy.datasets.Dataset` or `~gammapy.datasets.Datasets`
 # together with the data to be fitted. Checkout e.g. the
 # :doc:`/tutorials/api/model_management` tutorial for details.
 #
@@ -572,10 +568,10 @@ print(models_yaml)
 
 ######################################################################
 # The structure of the yaml files follows the structure of the python
-# objects. The ``components`` listed correspond to the `SkyModel` and
-# components of the ``Models``. For each ``SkyModel``
+# objects. The ``components`` listed correspond to the `~gammapy.modeling.models.SkyModel` and
+# components of the `~gammapy.modeling.models.Models`. For each `~gammapy.modeling.models.SkyModel`
 # we have information about its ``name``, ``type`` (corresponding to the
-# tag attribute) and sub-mobels (i.e ``spectral`` model and eventually
+# tag attribute) and sub-models (i.e ``spectral`` model and eventually
 # ``spatial`` model). Then the spatial and spectral models are defined by
 # their type and parameters. The ``parameters`` keys name/value/unit are
 # mandatory, while the keys min/max/frozen are optional (so you can
@@ -592,7 +588,7 @@ models_read = Models.read("models.yaml")
 
 ######################################################################
 # Additionally the models can be exported and imported together with the data
-# using the ``Datasets.read()`` and ``Datasets.write()`` methods as shown
+# using the `~gammapy.datasets.Datasets.read()` and `~gammapy.datasets.Datasets.write()` methods as shown
 # in the :doc:`/tutorials/analysis-3d/analysis_mwl`
 # notebook.
 #
@@ -630,7 +626,7 @@ print(models_yaml)
 # ---------------------------
 #
 # In order to add a user defined spectral model you have to create a
-# SpectralModel subclass. This new model class should include:
+# `~gammapy.modeling.models.SpectralModel` subclass. This new model class should include:
 #
 # -  a tag used for serialization (it can be the same as the class name)
 # -  an instantiation of each Parameter with their unit, default values
@@ -688,7 +684,7 @@ class MyCustomSpectralModel(SpectralModel):
 # It is good practice to also implement a docstring for the model,
 # defining the parameters and also defining a ``.tag``, which specifies the
 # name of the model for serialisation. Also note that gammapy assumes that
-# all SpectralModel evaluate functions return a flux in unit of
+# all `~gammapy.modeling.models.SpectralModel` evaluate functions return a flux in unit of
 # `"cm-2 s-1 TeV-1"` (or equivalent dimensions).
 #
 # This model can now be used as any other spectral model in Gammapy:
@@ -760,7 +756,7 @@ models.write("my-custom-models.yaml", overwrite=True)
 # models.
 #
 
-from astropy.coordinates.angle_utilities import angular_separation
+from astropy.coordinates import angular_separation
 from gammapy.modeling.models import SpatialModel
 
 
@@ -806,10 +802,10 @@ class MyCustomGaussianModel(SpatialModel):
 
 ######################################################################
 # Serialisation of this model can be achieved as explained in the previous
-# section. You can now use it as standard ``SpatialModel`` in your
-# analysis. Note that this is still a ``SpatialModel`` and not a
-# ``SkyModel``, so it needs to be multiplied by a ``SpectralModel`` as
-# before.
+# section. You can now use it as standard `~gammapy.modeling.models.SpatialModel` in your
+# analysis. Note that this is still a `~gammapy.modeling.models.SpatialModel` and not a
+# `~gammapy.modeling.models.SkyModel`, so it needs to be multiplied by a
+# `~gammapy.modeling.models.SpectralModel` as before.
 #
 
 spatial_model = MyCustomGaussianModel()
@@ -834,7 +830,7 @@ plt.show()
 
 ######################################################################
 # For computational purposes, it is useful to specify a
-# ``evaluation_radius`` for ``SpatialModels`` - this gives a size on which
+# ``evaluation_radius`` for `~gammapy.modeling.models.SpatialModels` - this gives a size on which
 # to compute the model. Though optional, it is highly recommended for
 # Custom Spatial Models. This can be done, for ex, by defining the
 # following function inside the above class:
