@@ -45,9 +45,8 @@ from astropy.coordinates import SkyCoord
 import matplotlib.pyplot as plt
 from IPython.display import display
 from gammapy.data import DataStore
-from gammapy.makers import MapDatasetMaker
 from gammapy.makers.utils import make_theta_squared_table
-from gammapy.maps import Map, MapAxis, WcsGeom
+from gammapy.maps import MapAxis, WcsGeom
 
 ######################################################################
 # Check setup
@@ -65,7 +64,7 @@ check_tutorials_setup()
 # relevant file (i.e., events, effective area, psf…) and contains the path
 # to said file. Together they can be loaded into a Datastore by indicating
 # the directory in which they can be found, in this case
-# “$GAMMAPY_DATA/hess-dl3-dr1”:
+# `$GAMMAPY_DATA/hess-dl3-dr1`:
 #
 
 ######################################################################
@@ -81,7 +80,7 @@ data_store.info()
 display(data_store.obs_table[:2][["OBS_ID", "DATE-OBS", "RA_PNT", "DEC_PNT", "OBJECT"]])
 
 ######################################################################
-# Get a single obervation
+# Get a single observation
 
 obs = data_store.obs(23523)
 
@@ -131,70 +130,6 @@ plt.figure(figsize=(10, 5))
 plot_theta_squared_table(theta2_table)
 plt.show()
 
-######################################################################
-# On-axis equivalent livetime
-# ---------------------------
-#
-# Since the acceptance of the H.E.S.S. camera varies within the field of
-# view, what is often interesting is not the simply the total number of
-# hours a source was observed, but the on-axis equivalent number of hours.
-# We calculated the same for the MSH 1552 runs here.
-#
-
-# Get the observations
-obs_id = data_store.obs_table["OBS_ID"][data_store.obs_table["OBJECT"] == "MSH 15-5-02"]
-observations = data_store.get_observations(obs_id)
-print("No. of observations: ", len(observations))
-
-# Define an energy range
-energy_min = 100 * u.GeV
-energy_max = 10.0 * u.TeV
-
-# define a offset cut
-offset_max = 2.5 * u.deg
-
-# define the geom
-source_pos = SkyCoord(228.32, -59.08, unit="deg")
-energy_axis_true = MapAxis.from_energy_bounds(
-    energy_min, energy_max, nbin=1, name="energy_true"
-)
-geom = WcsGeom.create(
-    skydir=source_pos,
-    binsz=0.02,
-    width=(6, 6),
-    frame="icrs",
-    proj="CAR",
-    axes=[energy_axis_true],
-)
-
-# compute
-livetime = Map.from_geom(geom, unit=u.hr)
-for obs in observations:
-    geom_obs = geom.cutout(
-        position=obs.get_pointing_icrs(obs.tmid), width=2.0 * offset_max
-    )
-    exposure = MapDatasetMaker.make_exposure(geom=geom_obs, observation=obs)
-    on_axis = obs.aeff.evaluate(
-        offset=0.0 * u.deg, energy_true=geom.axes["energy_true"].center
-    )
-    on_axis = on_axis.reshape((on_axis.shape[0], 1, 1))
-    lv_obs = exposure / on_axis
-    livetime.stack(lv_obs)
-
-# Plot
-ax = livetime.plot(add_cbar=True)
-plt.show()
-
-# Add the pointing position on top
-for obs in observations:
-    ax.plot(
-        obs.get_pointing_icrs(obs.tmid).to_pixel(wcs=ax.wcs)[0],
-        obs.get_pointing_icrs(obs.tmid).to_pixel(wcs=ax.wcs)[1],
-        "+",
-        color="black",
-    )
-plt.show()
-
 ######################################################################
 # Exercises
 # ---------
