@@ -26,24 +26,28 @@ ZMIN, ZMAX = Quantity([-0.5, 0.5], "kpc")
 
 
 class Paczynski1990(Fittable1DModel):
-    r"""Radial distribution of the birth surface density of neutron stars - Paczynski 1990.
+    r"""Radial distribution of the birth surface density of neutron stars.
 
     .. math::
         f(r) = A r_{exp}^{-2} \exp \left(-\frac{r}{r_{exp}} \right)
 
-    Reference: https://ui.adsabs.harvard.edu/abs/1990ApJ...348..485P (Formula (2))
+    Formula (2) [Paczynski1990]_.
 
     Parameters
     ----------
     amplitude : float
-        See formula
+        See formula.
     r_exp : float
-        See formula
+        See formula.
 
     See Also
     --------
     CaseBattacharya1998, YusifovKucuk2004, Lorimer2006, YusifovKucuk2004B,
     FaucherKaspi2006, Exponential
+
+    References
+    ----------
+    .. [Paczynski1990] https://ui.adsabs.harvard.edu/abs/1990ApJ...348..485P
     """
 
     amplitude = Parameter()
@@ -60,28 +64,31 @@ class Paczynski1990(Fittable1DModel):
 
 
 class CaseBattacharya1998(Fittable1DModel):
-    r"""Radial distribution of the surface density of supernova remnants in the galaxy
-    - Case & Battacharya 1998.
+    r"""Radial distribution of the surface density of supernova remnants in the galaxy.
 
     .. math::
         f(r) = A \left( \frac{r}{r_{\odot}} \right) ^ \alpha \exp
         \left[ -\beta \left( \frac{ r - r_{\odot}}{r_{\odot}} \right) \right]
 
-    Reference: https://ui.adsabs.harvard.edu/abs/1998ApJ...504..761C (Formula (14))
+    Formula (14) [CaseBattacharya1998]_.
 
     Parameters
     ----------
     amplitude : float
-        See model formula
+        See model formula.
     alpha : float
-        See model formula
+        See model formula.
     beta : float
-        See model formula
+        See model formula.
 
     See Also
     --------
     Paczynski1990, YusifovKucuk2004, Lorimer2006, YusifovKucuk2004B,
     FaucherKaspi2006, Exponential
+
+    References
+    ----------
+    .. [CaseBattacharya1998] https://ui.adsabs.harvard.edu/abs/1998ApJ...504..761C
     """
 
     amplitude = Parameter()
@@ -102,7 +109,7 @@ class CaseBattacharya1998(Fittable1DModel):
 
 
 class YusifovKucuk2004(Fittable1DModel):
-    r"""Radial distribution of the surface density of pulsars in the galaxy - Yusifov & Kucuk 2004.
+    r"""Radial distribution of the surface density of pulsars in the galaxy.
 
     .. math::
         f(r) = A \left ( \frac{r + r_1}{r_{\odot} + r_1} \right )^a \exp
@@ -110,23 +117,27 @@ class YusifovKucuk2004(Fittable1DModel):
 
     Used by Faucher-Guigere and Kaspi. Density at ``r = 0`` is nonzero.
 
-    Reference: https://ui.adsabs.harvard.edu/abs/2004A%26A...422..545Y (Formula (15))
+    Formula (15) [YusifovKucuk2004]_.
 
     Parameters
     ----------
     amplitude : float
-        See model formula
+        See model formula.
     a : float
-        See model formula
+        See model formula.
     b : float
-        See model formula
+        See model formula.
     r_1 : float
-        See model formula
+        See model formula.
 
     See Also
     --------
     CaseBattacharya1998, Paczynski1990, Lorimer2006, YusifovKucuk2004B,
     FaucherKaspi2006, Exponential
+
+    References
+    ----------
+    .. [YusifovKucuk2004] https://ui.adsabs.harvard.edu/abs/2004A%26A...422..545Y
     """
 
     amplitude = Parameter()
@@ -148,7 +159,7 @@ class YusifovKucuk2004(Fittable1DModel):
 
 
 class YusifovKucuk2004B(Fittable1DModel):
-    r"""Radial distribution of the surface density of OB stars in the galaxy - Yusifov & Kucuk 2004.
+    r"""Radial distribution of the surface density of OB stars in the galaxy.
 
     .. math::
         f(r) = A \left( \frac{r}{r_{\odot}} \right) ^ a
@@ -156,21 +167,26 @@ class YusifovKucuk2004B(Fittable1DModel):
 
     Derived empirically from OB-stars distribution.
 
-    Reference: https://ui.adsabs.harvard.edu/abs/2004A%26A...422..545Y (Formula (17))
+    Formula (17) [YusifovKucuk2004]_.
 
     Parameters
     ----------
     amplitude : float
-        See model formula
+        See model formula.
     a : float
-        See model formula
+        See model formula.
     b : float
-        See model formula
+        See model formula.
 
     See Also
     --------
     CaseBattacharya1998, Paczynski1990, YusifovKucuk2004, Lorimer2006,
     FaucherKaspi2006, Exponential
+
+    References
+    ----------
+    .. [YusifovKucuk2004] https://ui.adsabs.harvard.edu/abs/2004A%26A...422..545Y
+
     """
 
     amplitude = Parameter()
@@ -189,28 +205,32 @@ class YusifovKucuk2004B(Fittable1DModel):
 
 
 class FaucherKaspi2006(Fittable1DModel):
-    r"""Radial distribution of the birth surface density of pulsars in the galaxy
-     - Faucher-Giguere & Kaspi 2006.
+    r"""
+    Radial distribution of the birth surface density of pulsars in the galaxy.
 
     .. math::
         f(r) = A \frac{1}{\sqrt{2 \pi} \sigma} \exp
         \left(- \frac{(r - r_0)^2}{2 \sigma ^ 2}\right)
 
-    Reference: https://ui.adsabs.harvard.edu/abs/2006ApJ...643..332F (Appendix B)
+    Appendix B [FaucherKaspi2006]_.
 
     Parameters
     ----------
     amplitude : float
-        See model formula
+        See model formula.
     r_0 : float
-        See model formula
+        See model formula.
     sigma : float
-        See model formula
+        See model formula.
 
     See Also
     --------
     CaseBattacharya1998, Paczynski1990, YusifovKucuk2004, Lorimer2006,
     YusifovKucuk2004B, Exponential
+
+    References
+    ----------
+    .. [FaucherKaspi2006] https://ui.adsabs.harvard.edu/abs/2006ApJ...643..332F
     """
 
     amplitude = Parameter()
@@ -230,27 +250,31 @@ class FaucherKaspi2006(Fittable1DModel):
 
 
 class Lorimer2006(Fittable1DModel):
-    r"""Radial distribution of the surface density of pulsars in the galaxy - Lorimer 2006.
+    r"""Radial distribution of the surface density of pulsars in the galaxy.
 
     .. math::
         f(r) = A \left( \frac{r}{r_{\odot}} \right) ^ B \exp
         \left[ -C \left( \frac{r - r_{\odot}}{r_{\odot}} \right) \right]
 
-    Reference: https://ui.adsabs.harvard.edu/abs/2006MNRAS.372..777L (Formula (10))
+    Formula (10) [Lorimer2006]_.
 
     Parameters
     ----------
     amplitude : float
-        See model formula
+        See model formula.
     B : float
-        See model formula
+        See model formula.
     C : float
-        See model formula
+        See model formula.
 
     See Also
     --------
     CaseBattacharya1998, Paczynski1990, YusifovKucuk2004, Lorimer2006,
     YusifovKucuk2004B, FaucherKaspi2006
+
+    References
+    ----------
+    .. [Lorimer2006] https://ui.adsabs.harvard.edu/abs/2006MNRAS.372..777L
     """
 
     amplitude = Parameter()
@@ -282,9 +306,9 @@ class Exponential(Fittable1DModel):
     Parameters
     ----------
     amplitude : float
-        See model formula
+        See model formula.
     z_0 : float
-        Scale height of the distribution
+        Scale height of the distribution.
 
     See Also
     --------
@@ -316,17 +340,17 @@ class LogSpiral:
 
         Parameters
         ----------
-        theta : array_like
-            Angle (deg)
-        radius : array_like
-            Radius (kpc)
-        spiralarm_index : int
-            Spiral arm index
+        theta : `~astropy.units.Quantity`, optional
+            Angle (deg). Default is None.
+        radius : `~astropy.units.Quantity`, optional
+            Radius (kpc). Default is None.
+        spiralarm_index : int, optional
+            Spiral arm index. Default is 0.
 
         Returns
         -------
-        x, y : array_like
-            Position (x, y)
+        x, y : `~numpy.ndarray`
+            Position (x, y).
         """
         if (theta is None) and not (radius is None):
             theta = self.theta(radius, spiralarm_index=spiralarm_index)
@@ -345,15 +369,15 @@ class LogSpiral:
 
         Parameters
         ----------
-        theta : array_like
-            Angle (deg)
+        theta : `~astropy.units.Quantity`
+            Angle (deg).
         spiralarm_index : int
-            Spiral arm index
+            Spiral arm index.
 
         Returns
         -------
-        radius : array_like
-            Radius (kpc)
+        radius : `~numpy.ndarray`
+            Radius (kpc).
         """
         k = self.k[spiralarm_index]
         r_0 = self.r_0[spiralarm_index]
@@ -367,15 +391,15 @@ class LogSpiral:
 
         Parameters
         ----------
-        radius : array_like
-            Radius (kpc)
+        radius : `~astropy.units.Quantity`
+            Radius (kpc).
         spiralarm_index : int
-            Spiral arm index
+            Spiral arm index.
 
         Returns
         -------
-        theta : array_like
-            Angle (deg)
+        theta : `~numpy.ndarray`
+            Angle (deg).
         """
         k = self.k[spiralarm_index]
         r_0 = self.r_0[spiralarm_index]
@@ -399,7 +423,7 @@ class FaucherSpiral(LogSpiral):
 
     @staticmethod
     def _blur(radius, theta, amount=0.07, random_state="random-seed"):
-        """Blur the positions around the centroid of the spiralarm.
+        """Blur the positions around the centroid of the spiral arm.
 
         The given positions are blurred by drawing a displacement in radius from
         a normal distribution, with sigma = amount * radius. And a direction
@@ -408,14 +432,16 @@ class FaucherSpiral(LogSpiral):
         Parameters
         ----------
         radius : `~astropy.units.Quantity`
-            Radius coordinate
+            Radius coordinate.
         theta : `~astropy.units.Quantity`
-            Angle coordinate
-        amount: float, optional
+            Angle coordinate.
+        amount : float, optional
             Amount of blurring of the position, given as a fraction of `radius`.
+            Default is 0.07.
         random_state : {int, 'random-seed', 'global-rng', `~numpy.random.RandomState`}
             Defines random number generator initialisation.
             Passed to `~gammapy.utils.random.get_random_state`.
+            Default is 'random-seed'.
         """
         random_state = get_random_state(random_state)
 
@@ -431,20 +457,22 @@ class FaucherSpiral(LogSpiral):
     ):
         """Correction of source distribution towards the galactic center.
 
-        To avoid spiralarm features near the Galactic Center, the position angle theta
+        To avoid spiral arm features near the Galactic Center, the position angle theta
         is blurred by a certain amount towards the GC.
 
         Parameters
         ----------
         radius : `~astropy.units.Quantity`
-            Radius coordinate
+            Radius coordinate.
         theta : `~astropy.units.Quantity`
-            Angle coordinate
+            Angle coordinate.
         r_corr : `~astropy.units.Quantity`, optional
-            Scale of the correction towards the GC
+            Scale of the correction towards the GC.
+            Default is 2.857 * u.kpc.
         random_state : {int, 'random-seed', 'global-rng', `~numpy.random.RandomState`}
             Defines random number generator initialisation.
             Passed to `~gammapy.utils.random.get_random_state`.
+            Default is 'random-seed'.
         """
         random_state = get_random_state(random_state)
 
@@ -454,7 +482,7 @@ class FaucherSpiral(LogSpiral):
     def __call__(self, radius, blur=True, random_state="random-seed"):
         """Draw random position from spiral arm distribution.
 
-        Returns the corresponding angle theta[rad] to a given radius[kpc] and number of spiralarm.
+        Returns the corresponding angle theta[rad] to a given radius[kpc] and number of spiral arm.
         Possible numbers are:
 
         * Norma = 0,
@@ -467,6 +495,7 @@ class FaucherSpiral(LogSpiral):
         random_state : {int, 'random-seed', 'global-rng', `~numpy.random.RandomState`}
             Defines random number generator initialisation.
             Passed to `~gammapy.utils.random.get_random_state`.
+            Default is 'random-seed'.
 
         Returns
         -------
