@@ -1,12 +1,13 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Source catalog and object base classes."""
 import abc
+import html
 import numbers
 from copy import deepcopy
 import numpy as np
 from astropy.coordinates import SkyCoord
-from astropy.utils import lazyproperty
 from astropy.table import Table
+from astropy.utils import lazyproperty
 from gammapy.maps import TimeMapAxis
 from gammapy.modeling.models import Models
 from gammapy.utils.table import table_row_to_dict
@@ -56,20 +57,26 @@ class SourceCatalogObject:
         if data_extended:
             self.data_extended = Bunch(**data_extended)
 
+    def _repr_html_(self):
+        try:
+            return self.to_html()
+        except AttributeError:
+            return f"<pre>{html.escape(str(self))}</pre>"
+
     @property
     def name(self):
-        """Source name (str)"""
+        """Source name as a string."""
         name = self.data[self._source_name_key]
         return name.strip()
 
     @property
     def row_index(self):
-        """Row index of source in catalog (int)"""
+        """Row index of source in catalog as an integer."""
         return self.data[self._row_index_key]
 
     @property
     def position(self):
-        """Source position (`~astropy.coordinates.SkyCoord`)."""
+        """Source position as an `~astropy.coordinates.SkyCoord` object."""
         table = Table([self.data])
         return _skycoord_from_table(table)[0]
 
@@ -88,7 +95,7 @@ class SourceCatalog(abc.ABC):
     table : `~astropy.table.Table`
         Table with catalog data.
     source_name_key : str
-        Column with source name information
+        Column with source name information.
     source_name_alias : tuple of str
         Columns with source name aliases. This will allow accessing the source
         row by alias names as well.
@@ -97,7 +104,7 @@ class SourceCatalog(abc.ABC):
     @classmethod
     @abc.abstractmethod
     def description(cls):
-        """Catalog description (str)."""
+        """Catalog description as a string."""
         pass
 
     @property
@@ -134,18 +141,24 @@ class SourceCatalog(abc.ABC):
                         names[alias.strip()] = idx
         return names
 
+    def _repr_html_(self):
+        try:
+            return self.to_html()
+        except AttributeError:
+            return f"<pre>{html.escape(str(self))}</pre>"
+
     def row_index(self, name):
         """Look up row index of source by name.
 
         Parameters
         ----------
         name : str
-            Source name
+            Source name.
 
         Returns
         -------
         index : int
-            Row index of source in table
+            Row index of source in table.
         """
         index = self._name_to_index_cache[name]
         row = self.table[index]
@@ -167,7 +180,7 @@ class SourceCatalog(abc.ABC):
         Parameters
         ----------
         index : int
-            Row index of source in table
+            Row index of source in table.
         """
         source_name_col = self.table[self._source_name_key]
         name = source_name_col[index]
@@ -179,12 +192,12 @@ class SourceCatalog(abc.ABC):
         Parameters
         ----------
         key : str or int
-            Source name or row index
+            Source name or row index.
 
         Returns
         -------
         source : `SourceCatalogObject`
-            An object representing one source
+            An object representing one source.
         """
         if isinstance(key, str):
             index = self.row_index(key)
@@ -205,12 +218,12 @@ class SourceCatalog(abc.ABC):
         Parameters
         ----------
         index : int
-            Row index
+            Row index.
 
         Returns
         -------
         source : `SourceCatalogObject`
-            Source object
+            Source object.
         """
         data = table_row_to_dict(self.table[index])
         data[SourceCatalogObject._row_index_key] = index
@@ -261,11 +274,11 @@ class SourceCatalog(abc.ABC):
 
     @property
     def positions(self):
-        """Source positions (`~astropy.coordinates.SkyCoord`)."""
+        """Source positions as a `~astropy.coordinates.SkyCoord` object."""
         return _skycoord_from_table(self.table)
 
     def to_models(self, **kwargs):
-        """Create Models object from catalogue"""
+        """Create Models object from catalog."""
         return Models([_.sky_model(**kwargs) for _ in self])
 
 
@@ -274,6 +287,8 @@ def _skycoord_from_table(table):
 
     if {"RAJ2000", "DEJ2000"}.issubset(keys):
         lon, lat, frame = "RAJ2000", "DEJ2000", "icrs"
+    elif {"RAJ2000", "DECJ2000"}.issubset(keys):
+        lon, lat, frame = "RAJ2000", "DECJ2000", "fk5"
     elif {"RA", "DEC"}.issubset(keys):
         lon, lat, frame = "RA", "DEC", "icrs"
     elif {"ra", "dec"}.issubset(keys):
