@@ -1,26 +1,32 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Data and observation handling."""
+from gammapy.utils.observers import observatory_locations
 from .data_store import DataStore
 from .event_list import EventList
 from .filters import ObservationFilter
 from .gti import GTI
 from .hdu_index_table import HDUIndexTable
+from .metadata import EventListMetaData, ObservationMetaData
 from .obs_table import ObservationTable
 from .observations import Observation, Observations
-from .observers import observatory_locations
 from .pointing import FixedPointingInfo, PointingInfo, PointingMode
+from .utils import get_irfs_features
+from .simulate import ObservationsEventsSampler
 
 __all__ = [
     "DataStore",
     "EventList",
+    "EventListMetaData",
     "FixedPointingInfo",
     "GTI",
     "HDUIndexTable",
     "Observation",
     "ObservationFilter",
     "Observations",
+    "ObservationsEventsSampler",
     "ObservationTable",
     "observatory_locations",
     "PointingInfo",
     "PointingMode",
+    "get_irfs_features",
 ]
