@@ -1,4 +1,5 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
+import html
 import logging
 import warnings
 from enum import Enum, auto
@@ -6,7 +7,9 @@ import numpy as np
 import scipy.interpolate
 import astropy.units as u
 from astropy.coordinates import (
+    ICRS,
     AltAz,
+    BaseCoordinateFrame,
     CartesianRepresentation,
     SkyCoord,
     UnitSphericalRepresentation,
@@ -15,7 +18,7 @@ from astropy.io import fits
 from astropy.table import Table
 from astropy.units import Quantity
 from astropy.utils import lazyproperty
-from gammapy.utils.deprecation import GammapyDeprecationWarning, deprecated
+from gammapy.utils.deprecation import GammapyDeprecationWarning
 from gammapy.utils.fits import earth_location_from_dict, earth_location_to_dict
 from gammapy.utils.scripts import make_path
 from gammapy.utils.time import time_ref_from_dict, time_ref_to_dict, time_to_fits_header
@@ -25,15 +28,37 @@ log = logging.getLogger(__name__)
 __all__ = ["FixedPointingInfo", "PointingInfo", "PointingMode"]
 
 
+def _check_coord_frame(coord_or_frame, expected_frame, name):
+    """Check if a skycoord or frame is given in expected_frame."""
+    is_coord = isinstance(coord_or_frame, SkyCoord)
+    is_frame = isinstance(coord_or_frame, BaseCoordinateFrame)
+
+    if not (is_frame or is_coord):
+        raise TypeError(
+            f"{name} must be a 'astropy.coordinates.SkyCoord'"
+            "or {expected_frame} instance"
+        )
+
+    if is_coord:
+        frame = coord_or_frame.frame
+    else:
+        frame = coord_or_frame
+
+    if not isinstance(frame, expected_frame):
+        raise ValueError(
+            f"{name} is in wrong frame, expected {expected_frame}, got {frame}"
+        )
+
+
 class PointingMode(Enum):
     """
     Describes the behavior of the pointing during the observation.
 
-    See :ref:`gadf:obs-mode`.
+    See :ref:`gadf:iact-events-obs-mode`.
 
     For ground-based instruments, the most common options will be:
     * POINTING: The telescope observes a fixed position in the ICRS frame
-    * DRIFT: The telescope observes a fixed position in the AltAz frame
+    * DRIFT: The telescope observes a fixed position in the alt-az frame
 
     Gammapy only supports fixed pointing positions over the whole observation
     (either in equatorial or horizontal coordinates).
@@ -53,6 +78,7 @@ class PointingMode(Enum):
 
     @staticmethod
     def from_gadf_string(val):
+        """Parse a string from the GADF header into a PointingMode."""
         # OBS_MODE is not well-defined and not mandatory in GADF 0.2
         # We always assume that the observations are pointing observations
         # unless the OBS_MODE is set to DRIFT
@@ -74,13 +100,13 @@ class FixedPointingInfo:
         Passing this is deprecated, provide ``mode`` and ``fixed_icrs`` or ``fixed_altaz``
         instead or use `FixedPointingInfo.from_fits_header` instead.
     mode : `PointingMode`
-        How the telescope was pointing during the observation
-    fixed_icrs : SkyCoord in ICRS frame
-        Mandatory if mode is `PointingMode.POINTING`, the ICRS coordinates that are fixed
-        for the duration of the observation.
-    fixed_altaz : SkyCoord in AltAz frame
-        Mandatory if mode is `PointingMode.DRIFT`, the AltAz coordinates that are fixed
-        for the duration of the observation.
+        How the telescope was pointing during the observation.
+    fixed_icrs : `~astropy.coordinates.SkyCoord`, optional
+        The coordinates of the observation in ICRS as a `~astropy.coordinates.SkyCoord` object. Default is None.
+        Required if mode is `PointingMode.POINTING`.
+    fixed_altaz : `~astropy.coordinates.SkyCoord`, optional
+        The coordinates of the observation in alt-az as a `~astropy.coordinates.SkyCoord` object. Default is None.
+        Required if mode is `PointingMode.DRIFT`.
 
     Examples
     --------
@@ -88,7 +114,7 @@ class FixedPointingInfo:
     >>> from astropy.coordinates import SkyCoord
     >>> import astropy.units as u
     >>> fixed_icrs = SkyCoord(83.633 * u.deg, 22.014 * u.deg, frame="icrs")
-    >>> pointing_info = FixedPointingInfo(mode=PointingMode.POINTING, fixed_icrs=fixed_icrs)
+    >>> pointing_info = FixedPointingInfo(fixed_icrs=fixed_icrs)
     >>> print(pointing_info)
     FixedPointingInfo:
     <BLANKLINE>
@@ -100,6 +126,7 @@ class FixedPointingInfo:
     def __init__(
         self,
         meta=None,
+        *,
         mode=None,
         fixed_icrs=None,
         fixed_altaz=None,
@@ -125,19 +152,24 @@ class FixedPointingInfo:
             self.__dict__.update(self.from_fits_header(meta).__dict__)
             return
 
-        if not isinstance(mode, PointingMode):
-            raise TypeError(f"mode must be an instance of PointingMode, got {mode!r}")
+        if mode is not None:
+            warnings.warn(
+                "Passing mode is deprecated and the argument will be removed in Gammapy 1.3."
+                " pointing mode is deduced from whether fixed_icrs or fixed_altaz is given",
+                GammapyDeprecationWarning,
+            )
 
-        self._mode = mode
         self._location = location
         self._time_start = time_start
         self._time_stop = time_stop
         self._time_ref = time_ref
         self._legacy_altaz = legacy_altaz or AltAz(np.nan * u.deg, np.nan * u.deg)
 
-        if mode is PointingMode.POINTING:
-            if fixed_icrs is None:
-                raise ValueError("fixed_icrs is mandatory for PointingMode.POINTING")
+        if fixed_icrs is not None and fixed_altaz is not None:
+            raise ValueError("fixed_icrs and fixed_altaz are mutually exclusive")
+
+        if fixed_icrs is not None:
+            _check_coord_frame(fixed_icrs, ICRS, "fixed_icrs")
 
             if np.isnan(fixed_icrs.ra.value) or np.isnan(fixed_icrs.dec.value):
                 warnings.warn(
@@ -145,36 +177,37 @@ class FixedPointingInfo:
                     GammapyDeprecationWarning,
                 )
 
+            self._mode = PointingMode.POINTING
             self._fixed_icrs = fixed_icrs
             self._fixed_altaz = None
 
-        elif mode is PointingMode.DRIFT:
-            if fixed_altaz is None:
-                raise ValueError("pointing_altaz is required for PointingMode.DRIFT")
-
-            if fixed_icrs is not None:
-                raise ValueError("fixed_icrs is excluded for PointingMode.DRIFT")
-
-            self._fixed_altaz = fixed_altaz
-            self._fixed_icrs = None
         else:
-            raise ValueError(f"Unsupported pointing mode for FixedPointingInfo: {mode}")
+            _check_coord_frame(fixed_altaz, AltAz, "fixed_altaz")
+            self._mode = PointingMode.DRIFT
+            self._fixed_icrs = None
+            self._fixed_altaz = fixed_altaz
+
+    def _repr_html_(self):
+        try:
+            return self.to_html()
+        except AttributeError:
+            return f"<pre>{html.escape(str(self))}</pre>"
 
     @classmethod
     def from_fits_header(cls, header):
         """
-        Parse FixedPointingInfo from the given fits header
+        Parse `~gammapy.data.FixedPointingInfo` from the given FITS header.
 
         Parameters
         ----------
-        header : astropy.fits.Header
+        header : `astropy.fits.Header`
             Header to parse, e.g. from a GADF EVENTS HDU.
-            Currently, only GADF is supported.
+            Currently, only the GADF format is supported.
 
         Returns
         -------
-        pointing: FixedPointingInfo
-            The FixedPointingInfo instance filled from the given header
+        pointing : `~gammapy.data.FixedPointingInfo`
+            The FixedPointingInfo instance filled from the given header.
         """
         obs_mode = header.get("OBS_MODE", "POINTING")
         mode = PointingMode.from_gadf_string(obs_mode)
@@ -229,7 +262,6 @@ class FixedPointingInfo:
                 time_stop = time_ref + u.Quantity(time_stop, time_unit)
 
         return cls(
-            mode=mode,
             location=location,
             fixed_icrs=fixed_icrs,
             fixed_altaz=pointing_altaz,
@@ -241,22 +273,22 @@ class FixedPointingInfo:
 
     def to_fits_header(self, format="gadf", version="0.3", time_ref=None):
         """
-        Convert this FixedPointingInfo object into a fits header for the given format
+        Convert this FixedPointingInfo object into a fits header for the given format.
 
         Parameters
         ----------
-        format : str
-            Format, currently only "gadf" is supported
-        version : str
+        format : {"gadf"}
+            Format, currently only "gadf" is supported. Default is "gadf".
+        version : str, optional
             Version of the ``format``, this function currently supports
-            gadf versions 0.2 and 0.3.
-        time_ref : astropy.time.Time or None
-            Reference time for storing the time related information in fits format
+            gadf versions 0.2 and 0.3. Default is "0.3".
+        time_ref : `astropy.time.Time`, optional
+            Reference time for storing the time related information in fits format. Default is None.
 
         Returns
         -------
-        header : astropy.fits.Header
-            Header with fixed pointing information filled for the requested format
+        header : `astropy.fits.Header`
+            Header with fixed pointing information filled for the requested format.
         """
         if format != "gadf":
             raise ValueError(f'Only the "gadf" format supported, got {format}')
@@ -272,7 +304,7 @@ class FixedPointingInfo:
             header["OBS_MODE"] = "POINTING"
             header["RA_PNT"] = self.fixed_icrs.ra.deg, u.deg.to_string("fits")
             header["DEC_PNT"] = self.fixed_icrs.dec.deg, u.deg.to_string("fits")
-        elif self.mode is PointingMode.POINTING:
+        elif self.mode is PointingMode.DRIFT:
             header["OBS_MODE"] = "DRIFT"
             header["AZ_PNT"] = self.fixed_altaz.az.deg, u.deg.to_string("fits")
             header["ALT_PNT"] = self.fixed_altaz.alt.deg, u.deg.to_string("fits")
@@ -287,7 +319,7 @@ class FixedPointingInfo:
         if self._time_start is not None:
             header["TSTART"] = time_to_fits_header(self._time_start, epoch=time_ref)
         if self._time_stop is not None:
-            header["TSTOP"] = time_to_fits_header(self._time_start, epoch=time_ref)
+            header["TSTOP"] = time_to_fits_header(self._time_stop, epoch=time_ref)
 
         if self._time_start is not None or self._time_stop is not None:
             header.update(time_ref_to_dict(time_ref))
@@ -304,14 +336,14 @@ class FixedPointingInfo:
         Parameters
         ----------
         filename : str
-            File name
-        hdu : int or str
-            HDU number or name
+            Filename.
+        hdu : int or str, optional
+            HDU number or name. Default is "EVENTS".
 
         Returns
         -------
         pointing_info : `PointingInfo`
-            Pointing info object
+            Pointing information.
         """
         filename = make_path(filename)
         header = fits.getheader(filename, extname=hdu)
@@ -319,23 +351,23 @@ class FixedPointingInfo:
 
     @property
     def mode(self):
-        """See `PointingMode`, if not present, assume POINTING"""
+        """See `PointingMode`, if not present, assume POINTING."""
         return self._mode
 
     @property
     def fixed_altaz(self):
-        """The fixed coordinates in AltAz of the observation.
+        """The fixed coordinates of the observation in alt-az as a `~astropy.coordinates.SkyCoord` object.
 
-        None if not a DRIFT observation
+        None if not a DRIFT observation.
         """
         return self._fixed_altaz
 
     @property
     def fixed_icrs(self):
         """
-        The fixed coordinates in ICRS of the observation.
+        The fixed coordinates of the observation in ICRS as a `~astropy.coordinates.SkyCoord` object.
 
-        None if not a POINTING observation
+        None if not a POINTING observation.
         """
         return self._fixed_icrs
 
@@ -346,17 +378,22 @@ class FixedPointingInfo:
         If the observation was performed tracking a fixed position in ICRS,
         the icrs pointing is returned with the given obstime attached.
 
-        If the observation was performed in drift mode, the fixed altaz coordinates
+        If the observation was performed in drift mode, the fixed alt-az coordinates
         are transformed to ICRS using the observation location and the given time.
 
 
         Parameters
         ----------
-        obstime: `astropy.time.Time`
-            Time for which to get the pointing position in ICRS frame
-        location: `astropy.coordinates.EarthLocation`
+        obstime : `astropy.time.Time`, optional
+            Time for which to get the pointing position in ICRS frame. Default is None.
+        location : `astropy.coordinates.EarthLocation`, optional
             Observatory location, only needed for drift observations to transform
-            from horizontal coordinates to ICRS.
+            from horizontal coordinates to ICRS. Default is None.
+
+        Returns
+        -------
+        icrs : `astropy.coordinates.SkyCoord`
+            Pointing position in ICRS frame.
         """
         if self.mode == PointingMode.POINTING:
             return SkyCoord(self._fixed_icrs.data, location=location, obstime=obstime)
@@ -371,24 +408,30 @@ class FixedPointingInfo:
 
     def get_altaz(self, obstime=None, location=None) -> SkyCoord:
         """
-        Get the pointing position in AltAz frame for a given time.
+        Get the pointing position in alt-az frame for a given time.
 
         If the observation was performed tracking a fixed position in ICRS,
         the icrs pointing is transformed at the given time using the location
         of the observation.
 
         If the observation was performed in drift mode,
-        the fixed altaz coordinate is returned with `obstime` attached.
+        the fixed alt-az coordinate is returned with `obstime` attached.
 
         Parameters
         ----------
-        obstime: `astropy.time.Time`
-            Time for which to get the pointing position in AltAz frame
-        location: `astropy.coordinates.EarthLocation`
+        obstime : `astropy.time.Time`, optional
+            Time for which to get the pointing position in alt-az frame. Default is None.
+        location : `astropy.coordinates.EarthLocation`, optional
             Observatory location, only needed for pointing observations to transform
-            from ICRS to horizontal coordinates.
+            from ICRS to horizontal coordinates. Default is None.
+
+        Returns
+        -------
+        altaz : `astropy.coordinates.SkyCoord`
+            Pointing position in alt-az frame.
         """
-        location = location if location is not None else self.location
+        location = location if location is not None else self._location
+
         frame = AltAz(location=location, obstime=obstime)
 
         if self.mode == PointingMode.POINTING:
@@ -406,98 +449,6 @@ class FixedPointingInfo:
 
         raise ValueError(f"Unsupported pointing mode: {self.mode}.")
 
-    # the rest is deprecated...
-    @property
-    @deprecated("1.1")
-    def meta(self):
-        if self._meta is not None:
-            return self._meta
-        return dict(self.to_fits_header(time_ref=self._time_ref))
-
-    @property
-    @deprecated("1.1")
-    def location(self):
-        """Observatory location (`~astropy.coordinates.EarthLocation`)."""
-        return self._location
-
-    @property
-    @deprecated("1.1")
-    def time_start(self):
-        """Start time (`~astropy.time.Time`)."""
-        return self._time_start
-
-    @property
-    @deprecated("1.1")
-    def time_stop(self):
-        """Stop time (`~astropy.time.Time`)."""
-        warnings.warn(
-            "Accessing time information through pointing is deprecated",
-            DeprecationWarning,
-        )
-        return self._time_stop
-
-    @property
-    @deprecated("1.1")
-    def time_ref(self):
-        """Reference time (`~astropy.time.Time`)."""
-        return self._time_ref
-
-    @lazyproperty
-    @deprecated("1.1")
-    def obstime(self):
-        """Average observation time for the observation (`~astropy.time.Time`)."""
-        if self.time_start is None or self.duration is None:
-            return None
-        return self.time_start + self.duration / 2
-
-    @lazyproperty
-    @deprecated("1.1")
-    def duration(self):
-        """Pointing duration (`~astropy.time.TimeDelta`).
-
-        The time difference between the TSTART and TSTOP.
-        """
-        if self.time_start is None or self.time_stop is None:
-            return None
-        return self.time_stop - self.time_start
-
-    @lazyproperty
-    @deprecated("1.1")
-    def radec(self):
-        """
-        RA/DEC pointing position from table (`~astropy.coordinates.SkyCoord`).
-
-        Use `get_icrs` to get the pointing at a specific time, correctly
-        handling different pointing modes.
-        """
-        return self._fixed_icrs
-
-    @lazyproperty
-    @deprecated("1.1")
-    def altaz_frame(self):
-        """ALT / AZ frame (`~astropy.coordinates.AltAz`)."""
-        return AltAz(obstime=self.obstime, location=self.location)
-
-    @lazyproperty
-    @deprecated("1.1")
-    def altaz(self):
-        """
-        ALT/AZ pointing position computed from RA/DEC (`~astropy.coordinates.SkyCoord`)
-        for the midpoint of the run.
-
-        Use `get_altaz` to get the pointing at a specific time, correctly
-        handling different pointing modes.
-        """
-        frame = AltAz(location=self.location, obstime=self.obstime)
-        if frame.location is None or frame.obstime is None:
-            log.warning(
-                "Location or time information missing,"
-                " using ALT_PNT/AZ_PNT and incomplete frame"
-            )
-            return self._legacy_altaz
-
-        return self.radec.transform_to(frame)
-
     def __str__(self):
         coordinates = (
             self.fixed_icrs if self.mode == PointingMode.POINTING else self.fixed_altaz
@@ -512,12 +463,12 @@ class FixedPointingInfo:
 class PointingInfo:
     """IACT array pointing info.
 
-    Data format specification: :ref:`gadf:iact-pnt`
+    Data format specification: :ref:`gadf:iact-pnt`.
 
     Parameters
     ----------
     table : `~astropy.table.Table`
-        Table (with meta header info) on pointing
+        Table (with meta header information) on pointing.
 
     Examples
     --------
@@ -563,14 +514,14 @@ class PointingInfo:
         Parameters
         ----------
         filename : str
-            File name
-        hdu : int or str
-            HDU number or name
+            Filename.
+        hdu : int or str, optional
+            HDU number or name. Default is "POINTING".
 
         Returns
         -------
         pointing_info : `PointingInfo`
-            Pointing info object
+            Pointing information.
         """
         filename = make_path(filename)
         table = Table.read(filename, hdu=hdu)
@@ -605,17 +556,17 @@ class PointingInfo:
 
     @lazyproperty
     def location(self):
-        """Observatory location (`~astropy.coordinates.EarthLocation`)."""
+        """Observatory location as an `~astropy.coordinates.EarthLocation` object."""
         return earth_location_from_dict(self.table.meta)
 
     @lazyproperty
     def time_ref(self):
-        """Time reference (`~astropy.time.Time`)."""
+        """Time reference as a `~astropy.time.Time` object."""
         return time_ref_from_dict(self.table.meta)
 
     @lazyproperty
     def duration(self):
-        """Pointing table duration (`~astropy.time.TimeDelta`).
+        """Pointing table duration as a `~astropy.time.TimeDelta` object.
 
         The time difference between the first and last entry.
         """
@@ -623,31 +574,31 @@ class PointingInfo:
 
     @lazyproperty
     def time(self):
-        """Time array (`~astropy.time.Time`)."""
+        """Time array as a `~astropy.time.Time` object."""
         met = Quantity(self.table["TIME"].astype("float64"), "second")
         time = self.time_ref + met
         return time.tt
 
     @lazyproperty
     def radec(self):
-        """RA / DEC position from table (`~astropy.coordinates.SkyCoord`)."""
+        """RA / DEC position from table as a `~astropy.coordinates.SkyCoord`."""
         lon = self.table["RA_PNT"]
         lat = self.table["DEC_PNT"]
         return SkyCoord(lon, lat, unit="deg", frame="icrs")
 
     @lazyproperty
     def altaz_frame(self):
-        """ALT / AZ frame (`~astropy.coordinates.AltAz`)."""
+        """ALT / AZ frame as a `~astropy.coordinates.AltAz` object."""
         return AltAz(obstime=self.time, location=self.location)
 
     @lazyproperty
     def altaz(self):
-        """ALT / AZ position computed from RA / DEC (`~astropy.coordinates.SkyCoord`)."""
+        """ALT / AZ position computed from RA / DEC as a`~astropy.coordinates.SkyCoord`."""
         return self.radec.transform_to(self.altaz_frame)
 
     @lazyproperty
     def altaz_from_table(self):
-        """ALT / AZ position from table (`~astropy.coordinates.SkyCoord`)."""
+        """ALT / AZ position from table as a `~astropy.coordinates.SkyCoord`."""
         lon = self.table["AZ_PNT"]
         lat = self.table["ALT_PNT"]
         return SkyCoord(lon, lat, unit="deg", frame=self.altaz_frame)
@@ -676,8 +627,13 @@ class PointingInfo:
 
         Parameters
         ----------
-        obstime: `astropy.time.Time`
-            Time for which to get the pointing position in ICRS frame
+        obstime : `astropy.time.Time`
+            Time for which to get the pointing position in ICRS frame.
+
+        Returns
+        -------
+        icrs : `astropy.coordinates.SkyCoord`
+            Pointing position in ICRS frame.
         """
         return SkyCoord(
             self._interpolate_cartesian(self.time.mjd, self.radec, obstime.mjd),
@@ -687,19 +643,24 @@ class PointingInfo:
 
     def get_altaz(self, obstime):
         """
-        Get the pointing position in AltAz frame for a given time.
+        Get the pointing position in alt-az frame for a given time.
 
         If the observation was performed tracking a fixed position in ICRS,
         the icrs pointing is transformed at the given time using the location
         of the observation.
 
         If the observation was performed in drift mode,
-        the fixed altaz coordinate is returned with `obstime` attached.
+        the fixed alt-az coordinate is returned with `obstime` attached.
 
         Parameters
         ----------
-        obstime: `astropy.time.Time`
-            Time for which to get the pointing position in AltAz frame
+        obstime : `astropy.time.Time`
+            Time for which to get the pointing position in alt-az frame.
+
+        Returns
+        -------
+        altaz : `astropy.coordinates.SkyCoord`
+            Pointing position in alt-az frame.
         """
         # give precedence to ALT_PNT / AZ_PNT if present
         if "ALT_PNT" in self.table and "AZ_PNT" in self.table:
