@@ -4,14 +4,22 @@ import numpy as np
 from numpy.testing import assert_allclose
 import astropy.units as u
 from astropy.coordinates import EarthLocation, SkyCoord
+from astropy.io import fits
+from astropy.table import Table
 from astropy.time import Time
 from astropy.units import Quantity
-from gammapy.data import DataStore, Observation, ObservationFilter
-from gammapy.data.pointing import FixedPointingInfo, PointingMode
+from gammapy.data import (
+    DataStore,
+    EventList,
+    Observation,
+    ObservationFilter,
+    Observations,
+)
+from gammapy.data.metadata import ObservationMetaData
+from gammapy.data.pointing import FixedPointingInfo
 from gammapy.data.utils import get_irfs_features
 from gammapy.irf import PSF3D, load_irf_dict_from_file
 from gammapy.utils.cluster import hierarchical_clustering
-from gammapy.utils.deprecation import GammapyDeprecationWarning
 from gammapy.utils.fits import HDULocation
 from gammapy.utils.testing import (
     assert_skycoord_allclose,
@@ -36,13 +44,9 @@ def test_observation(data_store):
 
     c = SkyCoord(83.63333129882812, 21.51444435119629, unit="deg")
     assert_skycoord_allclose(obs.get_pointing_icrs(obs.tmid), c)
-    with pytest.warns(GammapyDeprecationWarning):
-        assert_skycoord_allclose(obs.pointing_radec, c)
 
     c = SkyCoord(22.558341, 41.950807, unit="deg")
     assert_skycoord_allclose(obs.get_pointing_altaz(obs.tmid), c)
-    with pytest.warns(GammapyDeprecationWarning):
-        assert_skycoord_allclose(obs.pointing_altaz, c)
 
     c = SkyCoord(83.63333129882812, 22.01444435119629, unit="deg")
     assert_skycoord_allclose(obs.target_radec, c)
@@ -50,7 +54,6 @@ def test_observation(data_store):
 
 @requires_data()
 def test_observation_peek(data_store):
-
     obs = Observation.read(
         "$GAMMAPY_DATA/hess-dl3-dr1/data/hess_dl3_dr1_obs_id_023523.fits.gz"
     )
@@ -191,6 +194,11 @@ def test_observations_mutation(data_store):
         obss[["1", "2"]]
 
 
+def test_empty_observations():
+    observations = Observations()
+    assert len(observations) == 0
+
+
 @requires_data()
 def test_observations_str(data_store):
     obs_ids = data_store.obs_table["OBS_ID"][:4]
@@ -227,7 +235,6 @@ def test_observations_select_time_time_intervals_list(data_store):
 def test_observation_cta_1dc():
     ontime = 5.0 * u.hr
     pointing = FixedPointingInfo(
-        mode=PointingMode.POINTING,
         fixed_icrs=SkyCoord(0, 0, unit="deg", frame="galactic").icrs,
     )
     irfs = load_irf_dict_from_file(
@@ -250,16 +257,17 @@ def test_observation_cta_1dc():
 
     assert_skycoord_allclose(obs.get_pointing_icrs(obs.tmid), pointing.fixed_icrs)
     assert_allclose(obs.observation_live_time_duration, 0.9 * ontime)
-    assert_allclose(obs.target_radec.ra, np.nan)
-    with pytest.warns(GammapyDeprecationWarning):
-        assert not np.isnan(obs.pointing_zen)
-    assert_allclose(obs.muoneff, 1)
+    assert obs.target_radec is None
+
+    assert isinstance(obs.meta, ObservationMetaData)
+    assert obs.meta.deadtime_fraction == 0.1
+    assert_allclose(obs.meta.location.height.to_value("m"), 2000)
+    assert "Gammapy" in obs.meta.creation.creator
 
 
 @requires_data()
 def test_observation_create_radmax():
     pointing = FixedPointingInfo(
-        mode=PointingMode.POINTING,
         fixed_icrs=SkyCoord(0, 0, unit="deg", frame="galactic").icrs,
     )
     obs = Observation.read("$GAMMAPY_DATA/joint-crab/dl3/magic/run_05029748_DL3.fits")
@@ -301,6 +309,16 @@ def test_observation_read():
     assert_allclose(val.value, 278000.54120855, rtol=1e-5)
     assert val.unit == "m2"
 
+    assert isinstance(obs.meta, ObservationMetaData)
+    assert "Gammapy" in obs.meta.creation.creator
+
+    assert obs.meta.obs_info.telescope == "HESS"
+    assert obs.meta.obs_info.instrument == "H.E.S.S. Phase I"
+    assert obs.meta.target.name == "MSH15-52"
+    assert obs.meta.optional["N_TELS"] == 4
+    with pytest.raises(KeyError):
+        obs.meta.optional["BROKPIX"]
+
 
 @requires_data()
 def test_observation_read_single_file():
@@ -361,6 +379,8 @@ def test_observation_write(tmp_path):
         "$GAMMAPY_DATA/hess-dl3-dr1/data/hess_dl3_dr1_obs_id_023523.fits.gz"
     )
     path = tmp_path / "obs.fits.gz"
+
+    obs.meta.creation.origin = "test"
     obs.write(path)
     obs_read = obs.read(path)
 
@@ -370,6 +390,8 @@ def test_observation_write(tmp_path):
     assert obs_read.edisp is not None
     assert obs_read.bkg is not None
     assert obs_read.rad_max is None
+    assert obs_read.obs_id == 23523
+    assert_allclose(obs_read.observatory_earth_location.lat.deg, -23.271778)
 
     # unsupported format
     with pytest.raises(ValueError):
@@ -387,6 +409,30 @@ def test_observation_write(tmp_path):
     assert obs_read.rad_max is None
 
 
+@requires_data()
+def test_observation_read_write_checksum(tmp_path):
+    obs = Observation.read(
+        "$GAMMAPY_DATA/hess-dl3-dr1/data/hess_dl3_dr1_obs_id_023523.fits.gz"
+    )
+    path = tmp_path / "obs.fits"
+
+    obs.write(path, checksum=True)
+
+    with fits.open(path) as hdul:
+        for hdu in hdul:
+            assert "CHECKSUM" in hdu.header
+            assert "DATASUM" in hdu.header
+
+    with open(path, "r+b") as file:
+        chunk = file.read(10000)
+        index = chunk.find("EV_CLASS".encode("ascii"))
+        file.seek(index)
+        file.write("BAD__KEY".encode("ascii"))
+
+    with pytest.warns(UserWarning):
+        Observation.read(path, checksum=True)
+
+
 @requires_data()
 def test_obervation_copy(data_store):
     obs = data_store.obs(23523)
@@ -418,7 +464,6 @@ def test_observation_tmid():
 
 @requires_data()
 def test_observations_clustering(data_store):
-
     selection = dict(
         type="sky_circle",
         frame="icrs",
@@ -501,3 +546,80 @@ def test_filter_live_time_phase(data_store):
     live_time_filter = observation.observation_live_time_duration
 
     assert_allclose(live_time_filter, default_obs_live_time * (0.8 - 0.2))
+
+
+@requires_data()
+def test_stack_observations(data_store, caplog):
+    obs_1 = data_store.get_observations([20136, 20137, 20151])
+    obs_2 = data_store.get_observations([20275, 20282])
+
+    obs12 = Observations.from_stack([obs_1, obs_2])
+
+    assert len(obs12) == 5
+    assert isinstance(obs12[0], Observation)
+
+    obs122 = Observations.from_stack([obs12, obs_2])
+
+    assert len(obs122) == 7
+    assert "WARNING" in [_.levelname for _ in caplog.records]
+    assert "Observation with obs_id 20275 already belongs to Observations." in [
+        _.message for _ in caplog.records
+    ]
+
+    caplog.clear()
+    obs_1[2] = obs_1[0]
+
+    assert "WARNING" in [_.levelname for _ in caplog.records]
+    assert "Observation with obs_id 20136 already belongs to Observations." in [
+        _.message for _ in caplog.records
+    ]
+
+    with pytest.raises(TypeError):
+        Observations.from_stack([obs_1, ["a"]])
+
+
+@requires_data()
+def test_slice(data_store):
+    obs_1 = data_store.get_observations([20136, 20137, 20151])
+    assert isinstance(obs_1[0], Observation)
+    assert isinstance(obs_1[1:], Observations)
+
+
+@requires_data()
+def test_observations_generator(data_store):
+    """Test Observations.generator()"""
+    obs_1 = data_store.get_observations([20136, 20137, 20151])
+
+    for idx, obs in enumerate(obs_1.in_memory_generator()):
+        assert isinstance(obs, Observation)
+        assert obs.obs_id == obs_1[idx].obs_id
+        assert isinstance(obs.events, EventList)
+        assert isinstance(obs.psf, PSF3D)
+
+
+@requires_data()
+def test_event_setter():
+    irfs = load_irf_dict_from_file(
+        "$GAMMAPY_DATA/cta-1dc/caldb/data/cta/1dc/bcf/South_z20_50h/irf_file.fits"
+    )
+    pointing = FixedPointingInfo(
+        fixed_icrs=SkyCoord(0 * u.deg, 0 * u.deg),
+    )
+    location = EarthLocation(lon="-70d18m58.84s", lat="-24d41m0.34s", height="2000m")
+    obs = Observation.create(
+        obs_id=1,
+        pointing=pointing,
+        livetime=20 * u.min,
+        irfs=irfs,
+        location=location,
+    )
+
+    assert obs.events is None
+
+    for invalid in (5, Table(), "foo"):
+        with pytest.raises(TypeError):
+            obs.events = invalid
+
+    events = EventList(Table())
+    obs.events = events
+    assert obs.events is events
