@@ -1,8 +1,17 @@
+# Licensed under a 3-clause BSD style license - see LICENSE.rst
 from gammapy.utils.registry import Registry
 from .core import Dataset, Datasets
 from .flux_points import FluxPointsDataset
 from .io import OGIPDatasetReader, OGIPDatasetWriter
+from .map import (
+    MapDataset,
+    MapDatasetOnOff,
+    create_map_dataset_from_observation,
+    create_map_dataset_geoms,
+)
+from .simulate import MapDatasetEventSampler, ObservationEventSampler
 from .map import MapDataset, MapDatasetOnOff, create_map_dataset_geoms
+from .metadata import MapDatasetMetaData
 from .simulate import MapDatasetEventSampler
 from .spectrum import SpectrumDataset, SpectrumDatasetOnOff
 
@@ -19,6 +28,7 @@ DATASET_REGISTRY = Registry(
 """Registry of dataset classes in Gammapy."""
 
 __all__ = [
+    "create_map_dataset_from_observation",
     "create_map_dataset_geoms",
     "Dataset",
     "DATASET_REGISTRY",
@@ -27,8 +37,10 @@ __all__ = [
     "MapDataset",
     "MapDatasetEventSampler",
     "MapDatasetOnOff",
+    "ObservationEventSampler",
     "OGIPDatasetWriter",
     "OGIPDatasetReader",
     "SpectrumDataset",
     "SpectrumDatasetOnOff",
+    "MapDatasetMetaData",
 ]
