@@ -1,11 +1,13 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
+import html
 import logging
 import numpy as np
 import astropy.units as u
-from astropy.coordinates.angle_utilities import angular_separation
+from astropy.coordinates import angular_separation
 from astropy.utils import lazyproperty
 from regions import CircleSkyRegion
 import matplotlib.pyplot as plt
+from gammapy.irf import EDispKernel
 from gammapy.maps import HpxNDMap, Map, RegionNDMap, WcsNDMap
 from gammapy.modeling.models import PointSpatialModel, TemplateNPredModel
 from .utils import apply_edisp
@@ -27,17 +29,17 @@ class MapEvaluator:
     Parameters
     ----------
     model : `~gammapy.modeling.models.SkyModel`
-        Sky model
+        Sky model.
     exposure : `~gammapy.maps.Map`
-        Exposure map
+        Exposure map.
     psf : `~gammapy.irf.PSFKernel`
-        PSF kernel
+        PSF kernel.
     edisp : `~gammapy.irf.EDispKernel`
-        Energy dispersion
+        Energy dispersion.
     mask : `~gammapy.maps.Map`
         Mask to apply to the likelihood for fitting.
     gti : `~gammapy.data.GTI`
-        GTI of the observation or union of GTI if it is a stacked observation
+        GTI of the observation or union of GTI if it is a stacked observation.
     evaluation_mode : {"local", "global"}
         Model evaluation mode.
         The "local" mode evaluates the model components on smaller grids to save computation time.
@@ -45,7 +47,7 @@ class MapEvaluator:
         The "global" evaluation mode evaluates the model components on the full map.
         This mode is recommended for global optimization algorithms.
     use_cache : bool
-        Use npred caching
+        Use npred caching.
     """
 
     def __init__(
@@ -67,7 +69,6 @@ class MapEvaluator:
         self.mask = mask
         self.gti = gti
         self.use_cache = use_cache
-        self._init_position = None
         self.contributes = True
         self.psf_containment = None
 
@@ -91,9 +92,14 @@ class MapEvaluator:
         self._cached_position = (0, 0)
         self._computation_cache = None
         self._spatial_oversampling_factor = 1
-        if self.exposure is not None:
-            if not self.geom.is_region or self.geom.region is not None:
-                self.update_spatial_oversampling_factor(self.geom)
+        if exposure is not None:
+            self.update_spatial_oversampling_factor(self.geom)
+
+    def _repr_html_(self):
+        try:
+            return self.to_html()
+        except AttributeError:
+            return f"<pre>{html.escape(str(self))}</pre>"
 
     def reset_cache_properties(self):
         """Reset cached properties."""
@@ -103,7 +109,10 @@ class MapEvaluator:
     @property
     def geom(self):
         """True energy map geometry (`~gammapy.maps.Geom`)."""
-        return self.exposure.geom
+        if self.exposure is not None:
+            return self.exposure.geom
+        else:
+            return None
 
     @property
     def _geom_reco(self):
@@ -143,7 +152,7 @@ class MapEvaluator:
         return psf_width
 
     def use_psf_containment(self, geom):
-        """Use psf containment for point sources and circular regions."""
+        """Use PSF containment for point sources and circular regions."""
         if not geom.is_region:
             return False
 
@@ -151,7 +160,12 @@ class MapEvaluator:
         is_circle_region = isinstance(geom.region, CircleSkyRegion)
         return is_point_model & is_circle_region
 
-    @property
+    @lazyproperty
+    def position(self):
+        """Latest evaluation position."""
+        return self.model.position
+
+    @lazyproperty
     def cutout_width(self):
         """Cutout width for the model component."""
         return self.psf_width + 2 * (self.model.evaluation_radius + CUTOUT_MARGIN)
@@ -162,25 +176,29 @@ class MapEvaluator:
         Parameters
         ----------
         exposure : `~gammapy.maps.Map`
-            Exposure map
+            Exposure map.
         psf : `gammapy.irf.PSFMap`
-            PSF map
+            PSF map.
         edisp : `gammapy.irf.EDispMap`
-            Edisp map
+            Edisp map.
         geom : `WcsGeom`
-            Counts geom
+            Counts geom.
         mask : `~gammapy.maps.Map`
-            Mask to apply to the likelihood for fitting
+            Mask to apply to the likelihood for fitting.
         """
         # TODO: simplify and clean up
         log.debug("Updating model evaluator")
 
+        del self.position
+        del self.cutout_width
+
         # lookup edisp
         if edisp:
             energy_axis = geom.axes["energy"]
             self.edisp = edisp.get_edisp_kernel(
-                position=self.model.position, energy_axis=energy_axis
+                position=self.position, energy_axis=energy_axis
             )
+            del self._edisp_diagonal
 
         # lookup psf
         if psf and self.model.spatial_model:
@@ -199,41 +217,52 @@ class MapEvaluator:
                     geom_psf = geom_psf.to_wcs_geom()
 
                 self.psf = psf.get_psf_kernel(
-                    position=self.model.position,
+                    position=self.position,
                     geom=geom_psf,
                     containment=PSF_CONTAINMENT,
                     max_radius=PSF_MAX_RADIUS,
                 )
 
+        self.exposure = exposure
         if self.evaluation_mode == "local":
             self.contributes = self.model.contributes(mask=mask, margin=self.psf_width)
-
-            if self.contributes:
-                self.exposure = exposure.cutout(
-                    position=self.model.position, width=self.cutout_width, odd_npix=True
+            if self.contributes and not self.model.contributes(mask=mask):
+                log.warning(
+                    "Model {m.name} is outside the target geom but contributes inside through the psf."
+                    "This contribution cannot be estimated precisely."
+                    "Consider extending the dataset geom and/or the masked margin in the mask_fit."
                 )
-        else:
-            self.exposure = exposure
 
-        if self.contributes:
-            if not self.geom.is_region or self.geom.region is not None:
-                self.update_spatial_oversampling_factor(self.geom)
+            if self.contributes and not self.geom.is_region:
+                self.exposure = exposure._cutout_view(
+                    position=self.position, width=self.cutout_width, odd_npix=True
+                )
+        self.update_spatial_oversampling_factor(self.geom)
 
         self.reset_cache_properties()
         self._computation_cache = None
         self._cached_parameter_previous = None
 
+    @lazyproperty
+    def _edisp_diagonal(self):
+        return EDispKernel.from_diagonal_response(
+            energy_axis_true=self.edisp.axes["energy_true"],
+            energy_axis=self.edisp.axes["energy"],
+        )
+
     def update_spatial_oversampling_factor(self, geom):
         """Update spatial oversampling_factor for model evaluation."""
-        res_scale = self.model.evaluation_bin_size_min
 
-        res_scale = res_scale.to_value("deg") if res_scale is not None else 0
+        if self.contributes and (not geom.is_region or geom.region is not None):
+            res_scale = self.model.evaluation_bin_size_min
 
-        if geom.is_region or geom.is_hpx:
-            geom = geom.to_wcs_geom()
-        if res_scale != 0:
-            factor = int(np.ceil(np.max(geom.pixel_scales.deg) / res_scale))
-            self._spatial_oversampling_factor = factor
+            res_scale = res_scale.to_value("deg") if res_scale is not None else 0
+
+            if res_scale != 0:
+                if geom.is_region or geom.is_hpx:
+                    geom = geom.to_wcs_geom()
+                factor = int(np.ceil(np.max(geom.pixel_scales.deg) / res_scale))
+                self._spatial_oversampling_factor = factor
 
     def compute_dnde(self):
         """Compute model differential flux at map pixel centers.
@@ -241,8 +270,8 @@ class MapEvaluator:
         Returns
         -------
         model_map : `~gammapy.maps.Map`
-            Sky cube with data filled with evaluated model values
-            Units: ``cm-2 s-1 TeV-1 deg-2``
+            Sky cube with data filled with evaluated model values.
+            Units: ``cm-2 s-1 TeV-1 deg-2``.
         """
         return self.model.evaluate_geom(self.geom, self.gti)
 
@@ -251,7 +280,7 @@ class MapEvaluator:
         return self.model.integrate_geom(self.geom, self.gti)
 
     def compute_flux_psf_convolved(self, *arg):
-        """Compute psf convolved and temporal model corrected flux."""
+        """Compute PSF convolved and temporal model corrected flux."""
         value = self.compute_flux_spectral()
 
         if self.model.spatial_model:
@@ -278,7 +307,7 @@ class MapEvaluator:
         Returns
         ----------
         value: `~astropy.units.Quantity`
-            PSF-corrected, integrated flux over a given region
+            PSF-corrected, integrated flux over a given region.
         """
         if self.geom.is_region:
             # We don't estimate spatial contributions if no psf are defined
@@ -352,14 +381,20 @@ class MapEvaluator:
         Parameters
         ----------
         npred : `~gammapy.maps.Map`
-            Predicted counts in true energy bins
+            Predicted counts in true energy bins.
 
         Returns
         -------
         npred_reco : `~gammapy.maps.Map`
-            Predicted counts in reco energy bins
+            Predicted counts in reconstructed energy bins.
         """
-        return apply_edisp(npred, self.edisp)
+        if self.model.apply_irf["edisp"]:
+            return apply_edisp(npred, self.edisp)
+        else:
+            if "energy_true" in npred.geom.axes.names:
+                return apply_edisp(npred, self._edisp_diagonal)
+            else:
+                return npred
 
     @lazyproperty
     def _compute_npred(self):
@@ -393,7 +428,7 @@ class MapEvaluator:
         Returns
         -------
         npred : `~gammapy.maps.Map`
-            Predicted counts on the map (in reco energy bins)
+            Predicted counts on the map (in reconstructed energy bins).
         """
         if self.parameters_changed or not self.use_cache:
             del self._compute_npred
@@ -404,8 +439,6 @@ class MapEvaluator:
     def parameters_changed(self):
         """Parameters changed."""
         values = self.model.parameters.value
-
-        # TODO: possibly allow for a tolerance here?
         changed = ~np.all(self._cached_parameter_values == values)
 
         if changed:
@@ -433,16 +466,14 @@ class MapEvaluator:
         Parameters
         ----------
         reset : bool
-            Reset cached values
+            Reset cached values. Default is True.
 
         Returns
         -------
         changed : bool
-            Whether spatial parameters changed
+            Whether spatial parameters changed.
         """
         values = self.model.spatial_model.parameters.value
-
-        # TODO: possibly allow for a tolerance here?
         changed = ~np.all(self._cached_parameter_values_spatial == values)
 
         if changed and reset:
@@ -505,21 +536,20 @@ class MapEvaluator:
             ]
         if not self.model.apply_irf["exposure"]:
             methods.remove(self.apply_exposure)
-        if not self.model.apply_irf["edisp"]:
-            methods.remove(self.apply_edisp)
         return methods
 
     def peek(self, figsize=(12, 15)):
         """Quick-look summary plots.
+
         Parameters
         ----------
         figsize : tuple
-            Size of the figure
+            Size of the figure. Default is (12, 15).
         """
         if self.needs_update:
             raise AttributeError(
                 "The evaluator needs to be updated first. Execute "
-                "`MapDataset.npred_signal(model_name=...)` before calling this method."
+                "`MapDataset.npred_signal(model_names=...)` before calling this method."
             )
 
         nrows = 1
