@@ -1,11 +1,13 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Simulate observations."""
+import html
+from copy import deepcopy
 import numpy as np
 import astropy.units as u
 from astropy.coordinates import SkyCoord, SkyOffsetFrame
 from astropy.table import Table
 from astropy.time import Time
-import gammapy
+from gammapy import __version__
 from gammapy.data import EventList, observatory_locations
 from gammapy.maps import MapAxis, MapCoord, RegionNDMap, TimeMapAxis
 from gammapy.modeling.models import (
@@ -13,9 +15,11 @@ from gammapy.modeling.models import (
     ConstantTemporalModel,
     PointSpatialModel,
 )
+from gammapy.utils.fits import earth_location_to_dict
 from gammapy.utils.random import get_random_state
+from .map import create_map_dataset_from_observation
 
-__all__ = ["MapDatasetEventSampler"]
+__all__ = ["MapDatasetEventSampler", "ObservationEventSampler"]
 
 
 class MapDatasetEventSampler:
@@ -23,21 +27,40 @@ class MapDatasetEventSampler:
 
     Parameters
     ----------
-    random_state : {int, 'random-seed', 'global-rng', `~numpy.random.RandomState`}
-        Defines random number generator initialisation via the `~gammapy.utils.random.get_random_state` function
-    oversample_energy_factor: {int}
+    random_state : {int, 'random-seed', 'global-rng', `~numpy.random.RandomState`}, optional
+        Defines random number generator initialisation via the `~gammapy.utils.random.get_random_state` function.
+    oversample_energy_factor : int, optional
         Defines an oversampling factor for the energies; it is used only when sampling
-        an energy-dependent time-varying source
-    t_delta : `~astropy.units.Quantity`
-        Time interval used to sample the time-dependent source
+        an energy-dependent time-varying source.
+    t_delta : `~astropy.units.Quantity`, optional
+        Time interval used to sample the time-dependent source.
+    keep_mc_id : bool, optional
+        Flag to tag sampled events from a given model with a Montecarlo identifier.
+        Default is True. If set to False, no identifier will be assigned.
+    n_event_bunch : int
+        Size of events bunches to sample. If None, sample all events in memory.
+        Default is 10000.
     """
 
     def __init__(
-        self, random_state="random-seed", oversample_energy_factor=10, t_delta=0.5 * u.s
+        self,
+        random_state="random-seed",
+        oversample_energy_factor=10,
+        t_delta=0.5 * u.s,
+        keep_mc_id=True,
+        n_event_bunch=10000,
     ):
         self.random_state = get_random_state(random_state)
         self.oversample_energy_factor = oversample_energy_factor
         self.t_delta = t_delta
+        self.keep_mc_id = keep_mc_id
+        self.n_event_bunch = n_event_bunch
+
+    def _repr_html_(self):
+        try:
+            return self.to_html()
+        except AttributeError:
+            return f"<pre>{html.escape(str(self))}</pre>"
 
     def _make_table(self, coords, time_ref):
         """Create a table for sampled events.
@@ -45,14 +68,14 @@ class MapDatasetEventSampler:
         Parameters
         ----------
         coords : `~gammapy.maps.MapCoord`
-            Coordinates of the sampled events
+            Coordinates of the sampled events.
         time_ref : `~astropy.time.Time`
-            Reference time of the event list
+            Reference time of the event list.
 
         Returns
         -------
         table : `~astropy.table.Table`
-            Table of the sampled events
+            Table of the sampled events.
         """
         table = Table()
         try:
@@ -79,14 +102,14 @@ class MapDatasetEventSampler:
         Parameters
         ----------
         dataset : `~gammapy.datasets.MapDataset`
-            Map dataset
+            Map dataset.
         model : `~gammapy.modeling.models.SkyModel`
-            Sky model instance
+            Sky model instance.
 
         Returns
         -------
         npred : `~gammapy.maps.RegionNDMap`
-            Npred map
+            Npred map.
         """
         energy_true = dataset.edisp.edisp_map.geom.axes["energy_true"]
         energy_new = energy_true.upsample(self.oversample_energy_factor)
@@ -110,13 +133,12 @@ class MapDatasetEventSampler:
             time_axis_eval.time_mid, energy=energy_new.center
         )
 
-        norm_parameters = model.spectral_model.parameters.norm_parameters
-        norm = norm_parameters[0].quantity
+        norm = model.spectral_model(energy=energy_new.center)
 
         if temp_eval.unit.is_equivalent(norm.unit):
-            flux_diff = temp_eval.to(norm.unit)
+            flux_diff = temp_eval.to(norm.unit) * norm.value[:, None]
         else:
-            flux_diff = temp_eval * norm
+            flux_diff = temp_eval * norm[:, None]
 
         flux_inte = flux_diff * energy_new.bin_width[:, None]
 
@@ -127,7 +149,7 @@ class MapDatasetEventSampler:
             unit=flux_inte.unit,
         )
 
-        mapcoord = flux_pred.geom.get_coord()
+        mapcoord = flux_pred.geom.get_coord(sparse=True)
         mapcoord["energy_true"] = energy_true.center[:, None, None, None]
 
         flux_values = flux_pred.interp_by_coord(mapcoord) * flux_pred.unit
@@ -148,14 +170,14 @@ class MapDatasetEventSampler:
         Parameters
         ----------
         dataset : `~gammapy.datasets.MapDataset`
-            Map dataset
+            Map dataset.
         model : `~gammapy.modeling.models.SkyModel`
-            Sky model instance
+            Sky model instance.
 
         Returns
         -------
         table : `~astropy.table.Table`
-            Table of sampled events
+            Table of sampled events.
         """
         if not isinstance(model.spatial_model, PointSpatialModel):
             raise TypeError(
@@ -169,7 +191,13 @@ class MapDatasetEventSampler:
 
         npred = self._evaluate_timevar_source(dataset, model=model)
         data = npred.data[np.isfinite(npred.data)]
-        n_events = self.random_state.poisson(np.sum(data))
+
+        try:
+            n_events = self.random_state.poisson(np.sum(data))
+        except ValueError:
+            raise ValueError(
+                f"The number of predicted events for the model {model.name} is too large. No event sampling will be performed for this model!"
+            )
 
         coords = npred.sample_coord(n_events=n_events, random_state=self.random_state)
 
@@ -185,16 +213,16 @@ class MapDatasetEventSampler:
         Parameters
         ----------
         npred : `~gammapy.dataset.MapDataset`
-            Npred map
+            Npred map.
         temporal_model : `~gammapy.modeling.models\
-            Temporal model of the source
+            Temporal model of the source.
         gti : `~gammapy.data.GTI`
-             GTI of the dataset
+             GTI of the dataset.
 
         Returns
         -------
         table : `~astropy.table.Table`
-            Table of sampled events
+            Table of sampled events.
         """
         data = npred.data[np.isfinite(npred.data)]
         n_events = self.random_state.poisson(np.sum(data))
@@ -220,15 +248,15 @@ class MapDatasetEventSampler:
         Parameters
         ----------
         dataset : `~gammapy.datasets.MapDataset`
-            Map dataset
+            Map dataset.
 
         Returns
         -------
         events : `~gammapy.data.EventList`
-            Event list
+            Event list.
         """
 
-        events_all = []
+        events_all = EventList(Table())
         for idx, evaluator in enumerate(dataset.evaluators.values()):
             if evaluator.needs_update:
                 evaluator.update(
@@ -238,6 +266,8 @@ class MapDatasetEventSampler:
                     dataset._geom,
                     dataset.mask,
                 )
+            if not evaluator.contributes:
+                continue
 
             if evaluator.model.temporal_model is None:
                 temporal_model = ConstantTemporalModel()
@@ -251,17 +281,18 @@ class MapDatasetEventSampler:
                 npred = evaluator.apply_exposure(flux)
                 table = self._sample_coord_time(npred, temporal_model, dataset.gti)
 
-            if len(table) == 0:
-                mcid = table.Column(name="MC_ID", length=0, dtype=int)
-                table.add_column(mcid)
+            if self.keep_mc_id:
+                if len(table) == 0:
+                    mcid = table.Column(name="MC_ID", length=0, dtype=int)
+                    table.add_column(mcid)
 
-            table["MC_ID"] = idx + 1
-            table.meta["MID{:05d}".format(idx + 1)] = idx + 1
-            table.meta["MMN{:05d}".format(idx + 1)] = evaluator.model.name
+                table["MC_ID"] = idx + 1
+                table.meta["MID{:05d}".format(idx + 1)] = idx + 1
+                table.meta["MMN{:05d}".format(idx + 1)] = evaluator.model.name
 
-            events_all.append(EventList(table))
+            events_all.stack(EventList(table))
 
-        return EventList.from_stack(events_all)
+        return events_all
 
     def sample_background(self, dataset):
         """Sample background.
@@ -269,26 +300,30 @@ class MapDatasetEventSampler:
         Parameters
         ----------
         dataset : `~gammapy.datasets.MapDataset`
-            Map dataset
+            Map dataset.
 
         Returns
         -------
         events : `gammapy.data.EventList`
-            Background events
+            Background events.
         """
-        background = dataset.npred_background()
 
-        temporal_model = ConstantTemporalModel()
+        table = Table()
+        if dataset.background:
+            background = dataset.npred_background()
 
-        table = self._sample_coord_time(background, temporal_model, dataset.gti)
+            temporal_model = ConstantTemporalModel()
 
-        table["MC_ID"] = 0
-        table["ENERGY"] = table["ENERGY_TRUE"]
-        table["RA"] = table["RA_TRUE"]
-        table["DEC"] = table["DEC_TRUE"]
+            table = self._sample_coord_time(background, temporal_model, dataset.gti)
 
-        table.meta["MID{:05d}".format(0)] = 0
-        table.meta["MMN{:05d}".format(0)] = dataset.background_model.name
+            table["ENERGY"] = table["ENERGY_TRUE"]
+            table["RA"] = table["RA_TRUE"]
+            table["DEC"] = table["DEC_TRUE"]
+
+            if self.keep_mc_id:
+                table["MC_ID"] = 0
+                table.meta["MID{:05d}".format(0)] = 0
+                table.meta["MMN{:05d}".format(0)] = dataset.background_model.name
 
         return EventList(table)
 
@@ -298,14 +333,14 @@ class MapDatasetEventSampler:
         Parameters
         ----------
         edisp_map : `~gammapy.irf.EDispMap`
-            Energy dispersion map
+            Energy dispersion map.
         events : `~gammapy.data.EventList`
-            Event list with the true energies
+            Event list with the true energies.
 
         Returns
         -------
         events : `~gammapy.data.EventList`
-            Event list with reconstructed energy column
+            Event list with reconstructed energy column.
         """
         coord = MapCoord(
             {
@@ -316,24 +351,26 @@ class MapDatasetEventSampler:
             frame="icrs",
         )
 
-        coords_reco = edisp_map.sample_coord(coord, self.random_state)
+        coords_reco = edisp_map.sample_coord(
+            coord, self.random_state, self.n_event_bunch
+        )
         events.table["ENERGY"] = coords_reco["energy"]
         return events
 
     def sample_psf(self, psf_map, events):
-        """Sample psf map.
+        """Sample PSF map.
 
         Parameters
         ----------
         psf_map : `~gammapy.irf.PSFMap`
-            PSF map
+            PSF map.
         events : `~gammapy.data.EventList`
-            Event list
+            Event list.
 
         Returns
         -------
         events : `~gammapy.data.EventList`
-            Event list with reconstructed position columns
+            Event list with reconstructed position columns.
         """
         coord = MapCoord(
             {
@@ -344,7 +381,8 @@ class MapDatasetEventSampler:
             frame="icrs",
         )
 
-        coords_reco = psf_map.sample_coord(coord, self.random_state)
+        coords_reco = psf_map.sample_coord(coord, self.random_state, self.n_event_bunch)
+
         events.table["RA"] = coords_reco["lon"] * u.deg
         events.table["DEC"] = coords_reco["lat"] * u.deg
         return events
@@ -356,14 +394,14 @@ class MapDatasetEventSampler:
         Parameters
         ----------
         observation : `~gammapy.data.Observation`
-            In memory observation
+            In memory observation.
         events : `~gammapy.data.EventList`
-            Event list
+            Event list.
 
         Returns
         -------
         events : `~gammapy.data.EventList`
-            Event list with columns of event detector coordinates
+            Event list with columns of event detector coordinates.
         """
         sky_coord = SkyCoord(events.table["RA"], events.table["DEC"], frame="icrs")
         frame = SkyOffsetFrame(origin=observation.get_pointing_icrs(observation.tmid))
@@ -374,20 +412,24 @@ class MapDatasetEventSampler:
         return events
 
     @staticmethod
-    def event_list_meta(dataset, observation):
+    def event_list_meta(dataset, observation, keep_mc_id=True):
         """Event list meta info.
+        Please, note that this function will be updated in the future.
 
         Parameters
         ----------
         dataset : `~gammapy.datasets.MapDataset`
-            Map dataset
+            Map dataset.
         observation : `~gammapy.data.Observation`
-            In memory observation
+            In memory observation.
+        keep_mc_id : bool
+            Flag to tag sampled events from a given model with a Montecarlo identifier.
+            Default is True. If set to False, no identifier will be assigned.
 
         Returns
         -------
         meta : dict
-            Meta dictionary
+            Meta dictionary.
         """
         # See: https://gamma-astro-data-formats.readthedocs.io/en/latest/events/events.html#mandatory-header-keywords  # noqa: E501
         meta = {}
@@ -416,7 +458,7 @@ class MapDatasetEventSampler:
         meta["EQUINOX"] = "J2000"
         meta["RADECSYS"] = "icrs"
 
-        meta["CREATOR"] = "Gammapy {}".format(gammapy.__version__)
+        meta["CREATOR"] = "Gammapy {}".format(__version__)
         meta["EUNIT"] = "TeV"
         meta["EVTVER"] = ""
 
@@ -463,27 +505,32 @@ class MapDatasetEventSampler:
         meta["CONV_RA"] = 0
         meta["CONV_DEC"] = 0
 
-        meta["NMCIDS"] = len(dataset.models)
+        if keep_mc_id:
+            meta["NMCIDS"] = len(dataset.models)
 
         # Necessary for DataStore, but they should be ALT and AZ instead!
         telescope = observation.aeff.meta["TELESCOP"]
         instrument = observation.aeff.meta["INSTRUME"]
-        if telescope == "CTA":
-            if instrument == "Southern Array":
-                loc = observatory_locations["cta_south"]
-            elif instrument == "Northern Array":
-                loc = observatory_locations["cta_north"]
-            else:
-                loc = observatory_locations["cta_south"]
+        loc = observation.observatory_earth_location
+        if loc is None:
+            if telescope == "CTA":
+                if instrument == "Southern Array":
+                    loc = observatory_locations["cta_south"]
+                elif instrument == "Northern Array":
+                    loc = observatory_locations["cta_north"]
+                else:
+                    loc = observatory_locations["cta_south"]
 
-        else:
-            loc = observatory_locations[telescope.lower()]
+            else:
+                loc = observatory_locations[telescope.lower()]
+
+        meta.update(earth_location_to_dict(loc))
 
         # this is not really correct but maybe OK for now
         coord_altaz = observation.pointing.get_altaz(dataset.gti.time_start, loc)
 
-        meta["ALT_PNT"] = str(coord_altaz.alt.deg[0])
-        meta["AZ_PNT"] = str(coord_altaz.az.deg[0])
+        meta["ALT_PNT"] = coord_altaz.alt.deg[0]
+        meta["AZ_PNT"] = coord_altaz.az.deg[0]
 
         # TO DO: these keywords should be taken from the IRF of the dataset
         meta["ORIGIN"] = "Gammapy"
@@ -492,8 +539,8 @@ class MapDatasetEventSampler:
         meta["N_TELS"] = ""
         meta["TELLIST"] = ""
 
-        meta["CREATED"] = ""
-        meta["OBS_MODE"] = ""
+        meta["CREATED"] = Time.now().iso
+        meta["OBS_MODE"] = "POINTING"
         meta["EV_CLASS"] = ""
 
         return meta
@@ -504,46 +551,117 @@ class MapDatasetEventSampler:
         Parameters
         ----------
         dataset : `~gammapy.datasets.MapDataset`
-            Map dataset
-        observation : `~gammapy.data.Observation`
-            In memory observation
-        edisp : Bool
-            Whether to include or exclude the Edisp in the simulation
+            Map dataset.
+        observation : `~gammapy.data.Observation`, optional
+            In memory observation. Default is None.
 
         Returns
         -------
         events : `~gammapy.data.EventList`
-            Event list
+            Event list.
         """
-        if len(dataset.models) > 1:
-            events_src = self.sample_sources(dataset)
+        events_src = self.sample_sources(dataset)
 
-            if len(events_src.table) > 0:
-                if dataset.psf:
-                    events_src = self.sample_psf(dataset.psf, events_src)
-                else:
-                    events_src.table["RA"] = events_src.table["RA_TRUE"]
-                    events_src.table["DEC"] = events_src.table["DEC_TRUE"]
-
-                if dataset.edisp:
-                    events_src = self.sample_edisp(dataset.edisp, events_src)
-                else:
-                    events_src.table["ENERGY"] = events_src.table["ENERGY_TRUE"]
-
-            if dataset.background:
-                events_bkg = self.sample_background(dataset)
-                events = EventList.from_stack([events_bkg, events_src])
+        if len(events_src.table) > 0:
+            if dataset.psf:
+                events_src = self.sample_psf(dataset.psf, events_src)
             else:
-                events = events_src
+                events_src.table["RA"] = events_src.table["RA_TRUE"]
+                events_src.table["DEC"] = events_src.table["DEC_TRUE"]
 
-        if len(dataset.models) == 1 and dataset.background_model is not None:
-            events_bkg = self.sample_background(dataset)
-            events = EventList.from_stack([events_bkg])
+            if dataset.edisp:
+                events_src = self.sample_edisp(dataset.edisp, events_src)
+            else:
+                events_src.table["ENERGY"] = events_src.table["ENERGY_TRUE"]
+
+        events_bkg = self.sample_background(dataset)
+        events = EventList.from_stack([events_bkg, events_src])
 
-        events = self.event_det_coords(observation, events)
         events.table["EVENT_ID"] = np.arange(len(events.table))
-        events.table.meta.update(self.event_list_meta(dataset, observation))
+        if observation is not None:
+            events = self.event_det_coords(observation, events)
+            events.table.meta.update(
+                self.event_list_meta(dataset, observation, self.keep_mc_id)
+            )
 
         geom = dataset._geom
         selection = geom.contains(events.map_coord(geom))
         return events.select_row_subset(selection)
+
+
+class ObservationEventSampler(MapDatasetEventSampler):
+    """
+    Sample event lists for a given observation and signal models.
+
+    Signal events are sampled from the predicted counts distribution given by the product of the sky models and the
+    expected exposure. They are then folded with the instrument response functions.
+    To improve performance, IRFs are evaluated on a pre-defined binning,
+    not at each individual event energy / coordinate.
+
+    Parameters
+    ----------
+    random_state : {int, 'random-seed', 'global-rng', `~numpy.random.RandomState`}, optional
+        Defines random number generator initialisation via the `~gammapy.utils.random.get_random_state` function.
+    oversample_energy_factor : int, optional
+        Defines an oversampling factor for the energies; it is used only when sampling
+        an energy-dependent time-varying source. Default is 10.
+    t_delta : `~astropy.units.Quantity`, optional
+        Time interval used to sample the time-dependent source. Default is 0.5 s.
+    keep_mc_id : bool, optional
+        Flag to tag sampled events from a given model with a Montecarlo identifier.
+        Default is True. If set to False, no identifier will be assigned.
+    n_event_bunch : int
+        Size of events bunches to sample. If None, sample all events in memory.
+        Default is 10000.
+    dataset_kwargs : dict, optional
+        Arguments passed to `~gammapy.datasets.create_map_dataset_from_observation()`
+    """
+
+    def __init__(
+        self,
+        random_state="random-seed",
+        oversample_energy_factor=10,
+        t_delta=0.5 * u.s,
+        keep_mc_id=True,
+        n_event_bunch=10000,
+        dataset_kwargs=None,
+    ):
+        self.dataset_kwargs = dataset_kwargs
+        self.random_state = get_random_state(random_state)
+        self.oversample_energy_factor = oversample_energy_factor
+        self.t_delta = t_delta
+        self.n_event_bunch = n_event_bunch
+        self.keep_mc_id = keep_mc_id
+
+    def run(self, observation, models=None, dataset_name=None):
+        """Sample events for given observation and signal models.
+
+        The signal distribution is sampled from the given models
+        in true coordinates and energy. The true quantities are
+        then folded with the IRFs to obtain the observable quantities.
+
+        Parameters
+        ----------
+        observation : `~gammapy.data.Observation`
+            Observation to be simulated.
+        models : `~gammapy.modeling.Models`, optional
+            Models to simulate.
+            Can be None to only sample background events. Default is None.
+        dataset_name : str, optional
+            If `models` contains one or multiple `FoVBackgroundModel`
+            it should match the `dataset_name` of the background model to use.
+            Default is None.
+        Returns
+        -------
+        observation : `~gammapy.data.Observation`
+            A copy of the input observation with event list filled.
+        """
+
+        dataset = create_map_dataset_from_observation(
+            observation, models, dataset_name, **self.dataset_kwargs
+        )
+        events = super().run(dataset, observation)
+
+        observation = deepcopy(observation)
+        observation._events = events
+        return observation
