@@ -1,12 +1,16 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 import json
+import warnings
 import pytest
 import numpy as np
 from numpy.testing import assert_allclose, assert_equal
 import astropy.units as u
 from astropy.coordinates import SkyCoord
+from astropy.io import fits
 from astropy.table import Table
+from astropy.utils.exceptions import AstropyUserWarning
 from regions import CircleSkyRegion
+import gammapy.irf.psf.map as psf_map_module
 from gammapy.catalog import SourceCatalog3FHL
 from gammapy.data import GTI
 from gammapy.datasets import Datasets, MapDataset, MapDatasetOnOff
@@ -30,7 +34,6 @@ from gammapy.maps import (
     WcsGeom,
     WcsNDMap,
 )
-from gammapy.maps.io import JsonQuantityEncoder
 from gammapy.modeling import Fit
 from gammapy.modeling.models import (
     DiskSpatialModel,
@@ -40,8 +43,10 @@ from gammapy.modeling.models import (
     PointSpatialModel,
     PowerLawSpectralModel,
     SkyModel,
+    UniformPrior,
 )
 from gammapy.utils.testing import mpl_plot_check, requires_data, requires_dependency
+from gammapy.utils.types import JsonQuantityEncoder
 
 
 @pytest.fixture
@@ -294,7 +299,6 @@ def test_different_exposure_unit(sky_model, geom):
 @pytest.mark.parametrize(("edisp_mode"), ["edispmap", "edispkernelmap"])
 @requires_data()
 def test_to_spectrum_dataset(sky_model, geom, geom_etrue, edisp_mode):
-
     dataset_ref = get_map_dataset(geom, geom_etrue, edisp=edisp_mode)
 
     bkg_model = FoVBackgroundModel(dataset_name=dataset_ref.name)
@@ -600,6 +604,7 @@ def test_map_dataset_fits_io(tmp_path, sky_model, geom, geom_etrue):
     dataset_new = MapDataset.read(tmp_path / "test.fits")
 
     assert dataset_new.name == "test"
+    assert_allclose(dataset.meta.creation.date.mjd, dataset_new.meta.creation.date.mjd)
 
     assert dataset_new.mask.data.dtype == bool
 
@@ -638,6 +643,21 @@ def test_map_dataset_fits_io(tmp_path, sky_model, geom, geom_etrue):
     assert_allclose(stacked1.edisp.edisp_map, stacked.edisp.edisp_map)
 
 
+@requires_data()
+def test_map_auto_psf_upsampling(sky_model, geom, geom_etrue):
+    dataset_2 = get_map_dataset(geom, geom_etrue, name="test-2")
+    datasets = Datasets([dataset_2])
+
+    models = Models(datasets.models)
+    models.insert(0, sky_model)
+
+    datasets.models = models
+    psf_map_module.PSF_UPSAMPLING_FACTOR = None
+    npred = dataset_2.npred().data.sum()
+    assert_allclose(npred, 9525.340707, rtol=1e-3)
+    psf_map_module.PSF_UPSAMPLING_FACTOR = 4
+
+
 @requires_data()
 def test_map_fit(sky_model, geom, geom_etrue):
     dataset_1 = get_map_dataset(geom, geom_etrue, name="test-1")
@@ -661,7 +681,7 @@ def test_map_fit(sky_model, geom, geom_etrue):
     result = fit.run(datasets=datasets)
 
     assert result.success
-    assert "minuit" in repr(result)
+    assert "minuit" in str(result)
 
     npred = dataset_1.npred().data.sum()
     assert_allclose(npred, 7525.790688, rtol=1e-3)
@@ -707,6 +727,84 @@ def test_map_fit(sky_model, geom, geom_etrue):
     assert not dataset_1.evaluators["test-model"].contributes
 
 
+@requires_data()
+def test_prior_stat_sum(sky_model, geom, geom_etrue):
+    dataset = get_map_dataset(geom, geom_etrue, name="test")
+    datasets = Datasets([dataset])
+
+    models = Models(datasets.models)
+    models.insert(0, sky_model)
+
+    datasets.models = models
+    dataset.counts = dataset.npred()
+
+    uniformprior = UniformPrior(min=-np.inf, max=0, weight=1)
+    datasets.models.parameters["amplitude"].prior = uniformprior
+    assert_allclose(datasets.stat_sum(), 12825.9370, rtol=1e-3)
+
+    datasets.models.parameters["amplitude"].value = -1e-12
+    stat_sum_neg = datasets.stat_sum()
+    assert_allclose(stat_sum_neg, 470298.864993, rtol=1e-3)
+
+    datasets.models.parameters["amplitude"].prior.weight = 100
+    assert_allclose(datasets.stat_sum() - stat_sum_neg, 99, rtol=1e-3)
+
+
+@requires_data()
+@requires_dependency("ray")
+def test_map_fit_ray(sky_model, geom, geom_etrue):
+    from gammapy.datasets.actors import DatasetsActor
+
+    dataset_1 = get_map_dataset(geom, geom_etrue, name="test-1")
+    dataset_2 = get_map_dataset(geom, geom_etrue, name="test-2")
+    datasets = Datasets([dataset_1, dataset_2])
+
+    models = Models(datasets.models)
+    models.insert(0, sky_model)
+
+    models["test-1-bkg"].spectral_model.norm.value = 0.5
+    models["test-model"].spatial_model.sigma.frozen = True
+
+    datasets.models = models
+    dataset_2.counts = dataset_2.npred()
+    dataset_1.counts = dataset_1.npred()
+
+    models["test-1-bkg"].spectral_model.norm.value = 0.49
+    models["test-2-bkg"].spectral_model.norm.value = 0.99
+
+    actors = DatasetsActor(datasets)
+    fit = Fit()
+    result = fit.run(datasets=actors)
+
+    assert result.success
+    assert result.optimize_result.backend == "minuit"
+
+    npred = actors[0].npred().data.sum()
+    assert_allclose(npred, 7525.790688, rtol=1e-3)
+    assert_allclose(result.total_stat, 21625.845714, rtol=1e-3)
+
+    pars = models.parameters
+    assert_allclose(pars["lon_0"].value, 0.2, rtol=1e-2)
+    assert_allclose(pars["lon_0"].error, 0.002244, rtol=1e-2)
+
+    assert_allclose(pars["index"].value, 3, rtol=1e-2)
+    assert_allclose(pars["index"].error, 0.0242, rtol=1e-2)
+
+    assert_allclose(pars["amplitude"].value, 1e-11, rtol=1e-2)
+    assert_allclose(pars["amplitude"].error, 4.216e-13, rtol=1e-2)
+
+    # background norm 1
+    assert_allclose(pars[8].value, 0.5, rtol=1e-2)
+    assert_allclose(pars[8].error, 0.015811, rtol=1e-2)
+
+    # background norm 2
+    assert_allclose(pars[11].value, 1, rtol=1e-2)
+    assert_allclose(pars[11].error, 0.02147, rtol=1e-2)
+
+    with mpl_plot_check():
+        actors.plot_residuals()
+
+
 @requires_data()
 def test_map_fit_linked(sky_model, geom, geom_etrue):
     dataset_1 = get_map_dataset(geom, geom_etrue, name="test-1")
@@ -735,7 +833,7 @@ def test_map_fit_linked(sky_model, geom, geom_etrue):
     result = fit.run(datasets=datasets)
 
     assert result.success
-    assert "minuit" in repr(result)
+    assert "minuit" in str(result)
 
     assert sky_model2.parameters["index"] is sky_model.parameters["index"]
     assert sky_model2.parameters["reference"] is sky_model.parameters["reference"]
@@ -1246,6 +1344,32 @@ def test_map_datasets_on_off_fits_io(images, tmp_path):
     assert_allclose(dataset.mask_safe, dataset_new.mask_safe)
 
 
+@requires_data()
+def test_map_datasets_on_off_checksum(images, tmp_path):
+    dataset = get_map_dataset_onoff(images)
+    Datasets([dataset]).write(tmp_path / "test.yaml", checksum=True)
+
+    hdul = fits.open(tmp_path / "MapDatasetOnOff-test.fits")
+    for hdu in hdul:
+        assert "CHECKSUM" in hdu.header
+        assert "DATASUM" in hdu.header
+
+    with warnings.catch_warnings():
+        warnings.simplefilter("error")
+        Datasets.read(tmp_path / "test.yaml", lazy=False)
+
+    path = tmp_path / "MapDatasetOnOff-test.fits"
+    # Modify counts map header to replace interpolation scheme
+    with open(path, "r+b") as file:
+        chunk = file.read(10000)
+        index = chunk.find("lin".encode("ascii"))
+        file.seek(index)
+        file.write("log".encode("ascii"))
+
+    with pytest.warns(AstropyUserWarning):
+        MapDatasetOnOff.read(path, checksum=True)
+
+
 def test_create_onoff(geom):
     # tests empty datasets created
 
@@ -1275,6 +1399,8 @@ def test_create_onoff(geom):
 def test_map_dataset_onoff_str(images):
     dataset = get_map_dataset_onoff(images)
     assert "MapDatasetOnOff" in str(dataset)
+    assert "counts_off" in str(dataset)
+    assert int(str(dataset)[-52:-48]) == 4273
 
 
 @requires_data()
@@ -1667,6 +1793,10 @@ def test_to_map_dataset():
     assert isinstance(dataset, MapDataset)
     assert dataset.counts == dataset_onoff.counts
 
+    dataset_onoff.counts_off = None
+    dataset2 = dataset_onoff.to_map_dataset(name="ds2")
+    assert dataset2.background is None
+
 
 def test_downsample_onoff():
     axis = MapAxis.from_energy_bounds(1, 10, 4, unit="TeV")
@@ -1823,7 +1953,6 @@ def test_map_dataset_region_geom_npred():
 
 @requires_dependency("healpy")
 def test_map_dataset_create_hpx_geom(geom_hpx):
-
     dataset = MapDataset.create(**geom_hpx, binsz_irf=10 * u.deg)
 
     assert isinstance(dataset.counts.geom, HpxGeom)
@@ -1844,7 +1973,6 @@ def test_map_dataset_create_hpx_geom(geom_hpx):
 
 @requires_dependency("healpy")
 def test_map_dataset_create_hpx_geom_partial(geom_hpx_partial):
-
     dataset = MapDataset.create(**geom_hpx_partial, binsz_irf=2 * u.deg)
 
     assert isinstance(dataset.counts.geom, HpxGeom)
@@ -1865,7 +1993,6 @@ def test_map_dataset_create_hpx_geom_partial(geom_hpx_partial):
 
 @requires_dependency("healpy")
 def test_map_dataset_stack_hpx_geom(geom_hpx_partial, geom_hpx):
-
     dataset_all = MapDataset.create(**geom_hpx, binsz_irf=5 * u.deg)
 
     gti = GTI.create(start=0 * u.s, stop=30 * u.min)
@@ -1909,3 +2036,27 @@ def test_peek(images):
 def test_create_psf_reco(geom):
     dat = MapDataset.create(geom, reco_psf=True)
     assert isinstance(dat.psf, RecoPSFMap)
+
+
+def test_to_masked():
+    axis = MapAxis.from_energy_bounds(1, 10, 2, unit="TeV")
+    geom = WcsGeom.create(npix=(10, 10), binsz=0.05, axes=[axis])
+    counts = Map.from_geom(geom, data=1)
+    mask = Map.from_geom(geom, data=True, dtype=bool)
+    mask.data[0][5:8] = False
+    dataset = MapDataset(counts=counts, mask_safe=mask)
+    d1 = dataset.to_masked()
+    assert_allclose(d1.counts.data.sum(), 170)
+
+    acceptance = Map.from_geom(geom, data=1)
+    acceptance_off = Map.from_geom(geom, data=0.1)
+    counts_off = counts
+    datasetonoff = MapDatasetOnOff(
+        counts=counts,
+        acceptance=acceptance,
+        mask_safe=mask,
+        acceptance_off=acceptance_off,
+        counts_off=counts_off,
+    )
+    d1 = datasetonoff.to_masked()
+    assert_allclose(d1.counts.data.sum(), 170)
