@@ -7,8 +7,8 @@ from astropy.coordinates import EarthLocation, SkyCoord
 from astropy.io import fits
 from astropy.table import Table
 from astropy.time import Time
-from gammapy.data import GTI, DataStore, Observation
-from gammapy.data.pointing import FixedPointingInfo, PointingMode
+from gammapy.data import GTI, DataStore, Observation, ObservationsEventsSampler
+from gammapy.data.pointing import FixedPointingInfo
 from gammapy.datasets import MapDataset, MapDatasetEventSampler
 from gammapy.datasets.tests.test_map import get_map_dataset
 from gammapy.irf import load_irf_dict_from_file
@@ -30,7 +30,7 @@ LOCATION = EarthLocation(lon="-70d18m58.84s", lat="-24d41m0.34s", height="2000m"
 
 
 @pytest.fixture()
-def models():
+def signal_model():
     spatial_model = GaussianSpatialModel(
         lon_0="0 deg", lat_0="0 deg", sigma="0.2 deg", frame="galactic"
     )
@@ -50,15 +50,18 @@ def models():
     table.meta = dict(MJDREFI=t_ref.mjd, MJDREFF=0, TIMEUNIT="s", TIMESYS="utc")
     temporal_model = LightCurveTemplateTemporalModel.from_table(table)
 
-    model = SkyModel(
+    return SkyModel(
         spatial_model=spatial_model,
         spectral_model=spectral_model,
         temporal_model=temporal_model,
         name="test-source",
     )
 
+
+@pytest.fixture()
+def models(signal_model):
     bkg_model = FoVBackgroundModel(dataset_name="test")
-    return [model, bkg_model]
+    return [signal_model, bkg_model]
 
 
 @pytest.fixture()
@@ -237,20 +240,41 @@ def test_sample_coord_time_energy(dataset, energy_dependent_temporal_sky_model):
     energy_dependent_temporal_sky_model.spatial_model = PointSpatialModel(
         lon_0="0 deg", lat_0="0 deg", frame="galactic"
     )
+    energy_dependent_temporal_sky_model.spectral_model.const.value = 2
+
     dataset.models = energy_dependent_temporal_sky_model
     evaluator = dataset.evaluators["test-source"]
 
+    expected = np.array([854.26361, 7.840697, 266.404988, -28.936178])
     events = sampler._sample_coord_time_energy(dataset, evaluator.model)
 
-    assert len(events) == 1254
+    assert len(events) == 2514
 
     assert_allclose(
         [events[0][0], events[0][1], events[0][2], events[0][3]],
-        [854.108591, 6.22904, 266.404988, -28.936178],
+        expected,
         rtol=1e-6,
     )
 
 
+@requires_data()
+def test_fail_sample_coord_time_energy(
+    dataset, models, energy_dependent_temporal_sky_model
+):
+    new_dataset = dataset.copy("my-dataset")
+    new_dataset.gti = GTI.create(
+        start=0 * u.s, stop=2.5 * u.s, reference_time=Time("2000-01-01").tt
+    )
+
+    new_dataset.models = energy_dependent_temporal_sky_model
+    new_dataset.models[0].temporal_model.map.data *= 1e20
+    evaluator = new_dataset.evaluators["test-source"]
+
+    sampler = MapDatasetEventSampler(random_state=0, oversample_energy_factor=1)
+    with pytest.raises(ValueError):
+        sampler._sample_coord_time_energy(new_dataset, evaluator.model)
+
+
 @requires_data()
 def test_sample_coord_time_energy_random_seed(
     dataset, energy_dependent_temporal_sky_model
@@ -337,7 +361,6 @@ def test_mde_sample_weak_src(dataset, models):
     )
     livetime = 10.0 * u.hr
     pointing = FixedPointingInfo(
-        mode=PointingMode.POINTING,
         fixed_icrs=SkyCoord(0, 0, unit="deg", frame="galactic").icrs,
     )
     obs = Observation.create(
@@ -367,14 +390,17 @@ def test_mde_sample_background(dataset, models):
     sampler = MapDatasetEventSampler(random_state=0)
     events = sampler.sample_background(dataset=dataset)
 
-    assert len(events.table["ENERGY"]) == 15
-    assert_allclose(events.table["ENERGY"][0], 1.894698, rtol=1e-5)
+    assert len(events.table) == 15
+
+    assert_allclose(np.mean(events.table["ENERGY"]), 4.1, rtol=0.1)
     assert events.table["ENERGY"].unit == "TeV"
 
-    assert_allclose(events.table["RA"][0], 266.571824, rtol=1e-5)
+    assert np.all(events.table["RA"] < 269.95)
+    assert np.all(events.table["RA"] > 262.90)
     assert events.table["RA"].unit == "deg"
 
-    assert_allclose(events.table["DEC"][0], -27.979152, rtol=1e-5)
+    assert np.all(events.table["DEC"] < -25.43)
+    assert np.all(events.table["DEC"] > -32.43)
     assert events.table["DEC"].unit == "deg"
 
     assert events.table["DEC_TRUE"][0] == events.table["DEC"][0]
@@ -427,7 +453,6 @@ def test_event_det_coords(dataset, models):
     )
     livetime = 1.0 * u.hr
     pointing = FixedPointingInfo(
-        mode=PointingMode.POINTING,
         fixed_icrs=SkyCoord(0, 0, unit="deg", frame="galactic").icrs,
     )
     obs = Observation.create(
@@ -443,21 +468,26 @@ def test_event_det_coords(dataset, models):
     events = sampler.run(dataset=dataset, observation=obs)
 
     assert len(events.table) == 99
-    assert_allclose(events.table["DETX"][0], -1.15531813, rtol=1e-5)
+
+    # Check that det coordinates are within sqrt(2) * width of dataset
+    assert np.all(events.table["DETX"] < 3.53)
+    assert np.all(events.table["DETX"] > -3.53)
+
     assert events.table["DETX"].unit == "deg"
 
-    assert_allclose(events.table["DETY"][0], -1.3343611, rtol=1e-5)
+    assert np.all(events.table["DETY"] < 3.53)
+    assert np.all(events.table["DETY"] > -3.53)
+
     assert events.table["DETY"].unit == "deg"
 
 
 @requires_data()
-def test_mde_run(dataset, models):
+def test_mde_run(dataset, models, tmp_path):
     irfs = load_irf_dict_from_file(
         "$GAMMAPY_DATA/cta-1dc/caldb/data/cta/1dc/bcf/South_z20_50h/irf_file.fits"
     )
     livetime = 1.0 * u.hr
     pointing = FixedPointingInfo(
-        mode=PointingMode.POINTING,
         fixed_icrs=SkyCoord(0, 0, unit="deg", frame="galactic").icrs,
     )
     obs = Observation.create(
@@ -477,15 +507,17 @@ def test_mde_run(dataset, models):
 
     events_bkg = sampler.run(dataset=dataset_bkg, observation=obs)
 
-    assert len(events.table) == 99
-    assert_allclose(events.table["ENERGY"][0], 4.406880, rtol=1e-5)
-    assert_allclose(events.table["RA"][0], 265.0677009, rtol=1e-5)
-    assert_allclose(events.table["DEC"][0], -30.2640157, rtol=1e-5)
+    #    assert len(events.table) == 99
+    assert_allclose(np.mean(events.table["ENERGY"]), 3.5, atol=1.0)
+    assert np.all(events.table["ENERGY"] > 1)
+
+    src_events = events.select_parameter("MC_ID", [0.5, 1.5])
+    assert_allclose(np.mean(src_events.table["RA"]), 266.40, atol=0.1)
+    assert_allclose(np.mean(src_events.table["DEC"]), -28.93, atol=0.1)
+    separation = src_events.radec.separation(models[0].spatial_model.position)
+    assert np.all(separation.to_value("deg") < 0.7)
 
     assert len(events_bkg.table) == 21
-    assert_allclose(events_bkg.table["ENERGY"][0], 1.5462581456, rtol=1e-5)
-    assert_allclose(events_bkg.table["RA"][0], 265.77338329, rtol=1e-5)
-    assert_allclose(events_bkg.table["DEC"][0], -30.701417442, rtol=1e-5)
     assert_allclose(events_bkg.table["MC_ID"][0], 0, rtol=1e-5)
 
     meta = events.table.meta
@@ -540,14 +572,23 @@ def test_mde_run(dataset, models):
     assert meta["MMN00000"] == "test-bkg"
     assert meta["MID00001"] == 1
     assert meta["NMCIDS"] == 2
-    assert_allclose(float(meta["ALT_PNT"]), float("-13.5345076464"), rtol=1e-7)
-    assert_allclose(float(meta["AZ_PNT"]), float("228.82981620065763"), rtol=1e-7)
+    assert_allclose(meta["ALT_PNT"], -13.5345076464, rtol=1e-7)
+    assert_allclose(meta["AZ_PNT"], 228.82981620065763, rtol=1e-7)
     assert meta["ORIGIN"] == "Gammapy"
     assert meta["TELESCOP"] == "CTA"
     assert meta["INSTRUME"] == "1DC"
     assert meta["N_TELS"] == ""
     assert meta["TELLIST"] == ""
 
+    # test writing out and reading back in works
+    obs.events = events
+    path = tmp_path / "obs.fits.gz"
+    obs.write(path)
+    obs_back = Observation.read(path)
+    assert u.isclose(obs_back.observatory_earth_location.lon, LOCATION.lon)
+    assert u.isclose(obs_back.observatory_earth_location.lat, LOCATION.lat)
+    assert u.isclose(obs_back.observatory_earth_location.height, LOCATION.height)
+
 
 @requires_data()
 def test_irf_alpha_config(dataset, models):
@@ -556,7 +597,6 @@ def test_irf_alpha_config(dataset, models):
     )
     livetime = 1.0 * u.hr
     pointing = FixedPointingInfo(
-        mode=PointingMode.POINTING,
         fixed_icrs=SkyCoord(0, 0, unit="deg", frame="galactic").icrs,
     )
     obs = Observation.create(
@@ -580,7 +620,6 @@ def test_mde_run_switchoff(dataset, models):
     )
     livetime = 1.0 * u.hr
     pointing = FixedPointingInfo(
-        mode=PointingMode.POINTING,
         fixed_icrs=SkyCoord(0, 0, unit="deg", frame="galactic").icrs,
     )
     obs = Observation.create(
@@ -620,7 +659,6 @@ def test_events_datastore(tmp_path, dataset, models):
     )
     livetime = 10.0 * u.hr
     pointing = FixedPointingInfo(
-        mode=PointingMode.POINTING,
         fixed_icrs=SkyCoord(0, 0, unit="deg", frame="galactic").icrs,
     )
     obs = Observation.create(
@@ -651,7 +689,7 @@ def test_MC_ID(model_alternative):
     )
     livetime = 0.1 * u.hr
     skydir = SkyCoord(0, 0, unit="deg", frame="galactic")
-    pointing = FixedPointingInfo(mode=PointingMode.POINTING, fixed_icrs=skydir.icrs)
+    pointing = FixedPointingInfo(fixed_icrs=skydir.icrs)
     obs = Observation.create(
         obs_id=1001,
         pointing=pointing,
@@ -708,7 +746,7 @@ def test_MC_ID_NMCID(model_alternative):
     )
     livetime = 0.1 * u.hr
     skydir = SkyCoord(0, 0, unit="deg", frame="galactic")
-    pointing = FixedPointingInfo(mode=PointingMode.POINTING, fixed_icrs=skydir.icrs)
+    pointing = FixedPointingInfo(fixed_icrs=skydir.icrs)
     obs = Observation.create(
         obs_id=1001,
         pointing=pointing,
@@ -757,3 +795,209 @@ def test_MC_ID_NMCID(model_alternative):
     assert meta["MID00002"] == 2
     assert meta["MID00003"] == 3
     assert meta["NMCIDS"] == 4
+
+
+@requires_data()
+def test_MC_ID_flag(model_alternative):
+    irfs = load_irf_dict_from_file(
+        "$GAMMAPY_DATA/cta-1dc/caldb/data/cta/1dc/bcf/South_z20_50h/irf_file.fits"
+    )
+    livetime = 0.1 * u.hr
+    skydir = SkyCoord(0, 0, unit="deg", frame="galactic")
+    pointing = FixedPointingInfo(fixed_icrs=skydir.icrs)
+    obs = Observation.create(
+        obs_id=1001,
+        pointing=pointing,
+        livetime=livetime,
+        irfs=irfs,
+        location=LOCATION,
+    )
+
+    energy_axis = MapAxis.from_energy_bounds(
+        "1.0 TeV", "10 TeV", nbin=10, per_decade=True
+    )
+    energy_axis_true = MapAxis.from_energy_bounds(
+        "0.5 TeV", "20 TeV", nbin=20, per_decade=True, name="energy_true"
+    )
+    migra_axis = MapAxis.from_bounds(0.5, 2, nbin=150, node_type="edges", name="migra")
+
+    geom = WcsGeom.create(
+        skydir=skydir,
+        width=(2, 2),
+        binsz=0.06,
+        frame="icrs",
+        axes=[energy_axis],
+    )
+
+    empty = MapDataset.create(
+        geom,
+        energy_axis_true=energy_axis_true,
+        migra_axis=migra_axis,
+        name="test",
+    )
+    maker = MapDatasetMaker(selection=["exposure", "background", "psf", "edisp"])
+    dataset = maker.run(empty, obs)
+
+    model_alternative[0].spectral_model.parameters["amplitude"].value = 1e-16
+    dataset.models = model_alternative
+    sampler = MapDatasetEventSampler(random_state=0, keep_mc_id=False)
+    events = sampler.run(dataset=dataset, observation=obs)
+
+    meta = events.table.meta
+    assert len(events.table) == 47
+    assert "MC_ID" not in events.table.colnames
+    assert "MID00000" not in meta.keys()
+    assert "MMN00000" not in meta.keys()
+    assert "MID00001" not in meta.keys()
+    assert "MID00002" not in meta.keys()
+    assert "MID00003" not in meta.keys()
+    assert "NMCIDS" not in meta.keys()
+
+
+@requires_data()
+def test_bunch_event_number_sample_sources(dataset):
+    spatial_model = GaussianSpatialModel(
+        lon_0="0 deg", lat_0="0 deg", sigma="0.2 deg", frame="galactic"
+    )
+    spectral_model = PowerLawSpectralModel(amplitude="4e-10 cm-2 s-1 TeV-1")
+
+    dataset.models = [
+        SkyModel(spectral_model=spectral_model, spatial_model=spatial_model),
+        FoVBackgroundModel(dataset_name=dataset.name),
+    ]
+
+    sampler = MapDatasetEventSampler(random_state=0, n_event_bunch=1000)
+    events = sampler.run(dataset=dataset)
+
+    assert len(events.table) == 24128
+
+
+@requires_data()
+def test_observation_event_sampler(signal_model, tmp_path):
+    from gammapy.datasets.simulate import ObservationEventSampler
+
+    irfs = load_irf_dict_from_file(
+        "$GAMMAPY_DATA/cta-caldb/Prod5-South-20deg-AverageAz-14MSTs37SSTs.180000s-v0.1.fits.gz"
+    )
+    pointing = FixedPointingInfo(
+        fixed_icrs=SkyCoord(83.63311446, 22.01448714, unit="deg", frame="icrs"),
+    )
+    time_start = Time("2021-11-20T03:00:00")
+    time_stop = Time("2021-11-20T03:30:00")
+
+    obs = Observation.create(
+        pointing=pointing,
+        location=LOCATION,
+        obs_id=1,
+        tstart=time_start,
+        tstop=time_stop,
+        irfs=irfs,
+        deadtime_fraction=0.01,
+    )
+
+    dataset_kwargs = dict(
+        spatial_width=5 * u.deg,
+        spatial_bin_size=0.01 * u.deg,
+        energy_axis=MapAxis.from_energy_bounds(
+            10 * u.GeV, 100 * u.TeV, nbin=5, per_decade=True
+        ),
+        energy_axis_true=MapAxis.from_energy_bounds(
+            10 * u.GeV, 100 * u.TeV, nbin=5, per_decade=True, name="energy_true"
+        ),
+    )
+    maker = ObservationEventSampler(dataset_kwargs=dataset_kwargs)
+
+    sim_obs = maker.run(obs, [signal_model])
+    assert sim_obs.events is not None
+    assert len(sim_obs.events.table) > 0
+
+
+@pytest.fixture(scope="session")
+def observations():
+    pointing = FixedPointingInfo(fixed_icrs=SkyCoord(0 * u.deg, 0 * u.deg))
+    livetime = 0.5 * u.hr
+    irfs = load_irf_dict_from_file(
+        "$GAMMAPY_DATA/cta-caldb/Prod5-South-20deg-AverageAz-14MSTs37SSTs.180000s-v0.1.fits.gz"
+    )
+    observations = [
+        Observation.create(
+            obs_id=100 + k, pointing=pointing, livetime=livetime, irfs=irfs
+        )
+        for k in range(2)
+    ]
+    return observations
+
+
+@pytest.fixture(scope="session")
+def models_list():
+    spectral_model_pwl = PowerLawSpectralModel(
+        index=2, amplitude="1e-12 TeV-1 cm-2 s-1", reference="1 TeV"
+    )
+    spatial_model_point = PointSpatialModel(
+        lon_0="0 deg", lat_0="0.0 deg", frame="galactic"
+    )
+
+    sky_model_pntpwl = SkyModel(
+        spectral_model=spectral_model_pwl,
+        spatial_model=spatial_model_point,
+        name="point-pwl",
+    )
+    models = Models(sky_model_pntpwl)
+    return models
+
+
+@requires_data()
+def test_observations_events_sampler(tmpdir, observations):
+    sampler_kwargs = dict(random_state=0)
+    dataset_kwargs = dict(
+        spatial_bin_size_min=0.1 * u.deg,
+        spatial_width_max=0.2 * u.deg,
+        energy_bin_per_decade_max=2,
+    )
+    sampler = ObservationsEventsSampler(
+        sampler_kwargs=sampler_kwargs,
+        dataset_kwargs=dataset_kwargs,
+        n_jobs=1,
+        outdir=tmpdir,
+        overwrite=True,
+    )
+    sampler.run(observations, models=None)
+
+
+@requires_data()
+def test_observations_events_sampler_time(
+    tmpdir, observations, energy_dependent_temporal_sky_model
+):
+    models = Models(energy_dependent_temporal_sky_model)
+    sampler_kwargs = dict(random_state=0)
+    dataset_kwargs = dict(
+        spatial_bin_size_min=0.1 * u.deg,
+        spatial_width_max=0.2 * u.deg,
+        energy_bin_per_decade_max=2,
+    )
+    sampler = ObservationsEventsSampler(
+        sampler_kwargs=sampler_kwargs,
+        dataset_kwargs=dataset_kwargs,
+        n_jobs=1,
+        outdir=tmpdir,
+        overwrite=True,
+    )
+    sampler.run(observations, models=models)
+
+
+@requires_data()
+def test_observations_events_sampler_parallel(tmpdir, observations, models_list):
+    sampler_kwargs = dict(random_state=0)
+    dataset_kwargs = dict(
+        spatial_bin_size_min=0.1 * u.deg,
+        spatial_width_max=0.2 * u.deg,
+        energy_bin_per_decade_max=2,
+    )
+    sampler = ObservationsEventsSampler(
+        sampler_kwargs=sampler_kwargs,
+        dataset_kwargs=dataset_kwargs,
+        n_jobs=2,
+        outdir=tmpdir,
+        overwrite=True,
+    )
+    sampler.run(observations, models=models_list)
