@@ -3,8 +3,10 @@ import pytest
 import numpy as np
 from numpy.testing import assert_allclose, assert_equal
 import astropy.units as u
+from astropy.io import fits
 from astropy.table import Table
 from astropy.time import Time
+from astropy.utils.exceptions import AstropyUserWarning
 from gammapy.data import GTI
 from gammapy.datasets import Datasets, SpectrumDataset, SpectrumDatasetOnOff
 from gammapy.irf import EDispKernelMap, EffectiveAreaTable2D
@@ -172,7 +174,7 @@ def test_fit(spectrum_dataset):
     fit = Fit()
     result = fit.run(datasets=[spectrum_dataset])
     assert result.success
-    assert "minuit" in repr(result)
+    assert "minuit" in str(result)
 
     npred = spectrum_dataset.npred().data.sum()
     assert_allclose(npred, 907012.186399, rtol=1e-3)
@@ -588,6 +590,29 @@ class TestSpectrumOnOff:
         assert newdataset.edisp is None
         assert newdataset.gti is None
 
+    def test_to_ogip_files_checksum(self, tmp_path):
+        dataset = self.dataset.copy(name="test")
+        dataset.write(tmp_path / "test.fits", format="ogip", checksum=True)
+
+        for name in ["test.fits", "test_arf.fits", "test_rmf.fits", "test_bkg.fits"]:
+            # TODO: this should not emit AstropyUserWarning
+            with fits.open(tmp_path / name, checksum=True) as hdul:
+                for hdu in hdul:
+                    assert "CHECKSUM" in hdu.header
+                    assert "DATASUM" in hdu.header
+
+        def replace_in_fits_header(filename, string):
+            with open(filename, "r+b") as file:
+                chunk = file.read(10000)
+                index = chunk.find(string.encode("ascii"))
+                file.seek(index)
+                file.write("bad".encode("ascii"))
+
+        path = tmp_path / "test.fits"
+        replace_in_fits_header(path, "unknown")
+        with pytest.warns(AstropyUserWarning):
+            SpectrumDatasetOnOff.read(path, checksum=True)
+
     def test_spectrum_dataset_onoff_fits_io(self, tmp_path):
         self.dataset.write(tmp_path / "test.fits", format="gadf")
         d1 = SpectrumDatasetOnOff.read(tmp_path / "test.fits", format="gadf")
