@@ -20,7 +20,24 @@ log = logging.getLogger(__name__)
 
 
 def convolved_map_dataset_counts_statistics(dataset, kernel, mask, correlate_off):
-    """Return CountsDataset objects containing smoothed maps from the MapDataset"""
+    """Return a `CountsStatistic` object.
+
+    Parameters
+    ----------
+    dataset : `~gammapy.datasets.MapDataset` or `~gammapy.datasets.MapDatasetOnOff`
+        Map dataset.
+    kernel : `~astropy.convolution.Kernel`
+        Kernel.
+    mask : `~gammapy.maps.Map`
+        Mask map.
+    correlate_off : bool
+        Correlate OFF events.
+
+    Returns
+    -------
+    counts_statistic : `~gammapy.stats.CashCountsStatistic` or `~gammapy.stats.WStatCountsStatistic`
+        The counts statistic.
+    """
     # Kernel is modified later make a copy here
     kernel = copy.deepcopy(kernel)
     kernel_data = kernel.data / kernel.data.max()
@@ -56,7 +73,6 @@ def convolved_map_dataset_counts_statistics(dataset, kernel, mask, correlate_off
             n_on_conv.data, n_off.data, alpha.data, npred_sig_convolve.data
         )
     else:
-
         npred = dataset.npred() * mask
         background_conv = npred.convolve(kernel_data)
         return CashCountsStatistic(n_on_conv.data, background_conv.data)
@@ -72,7 +88,7 @@ class ExcessMapEstimator(Estimator):
 
         By default the excess estimator correlates the off counts as well to avoid
         artifacts at the edges of the :term:`FoV` for stacked on-off datasets.
-        However when the on-off dataset has been derived from a ring background
+        However, when the on-off dataset has been derived from a ring background
         estimate, this leads to the off counts being correlated twice. To avoid
         artifacts and the double correlation, the `ExcessMapEstimator` has to
         be applied per dataset and the resulting maps need to be stacked, taking
@@ -80,23 +96,36 @@ class ExcessMapEstimator(Estimator):
 
     Parameters
     ----------
-    correlation_radius : ~astropy.coordinate.Angle
-        correlation radius to use
+    correlation_radius : `~astropy.coordinate.Angle`
+        Correlation radius to use.
     n_sigma : float
         Confidence level for the asymmetric errors expressed in number of sigma.
     n_sigma_ul : float
         Confidence level for the upper limits expressed in number of sigma.
-    selection_optional : list of str
+    n_sigma_sensitivity : float
+        Confidence level for the sensitivity expressed in number of sigma.
+    gamma_min_sensitivity : float, optional
+        Minimum number of gamma-rays. Default is 10.
+    bkg_syst_fraction_sensitivity : float, optional
+        Fraction of background counts that are above the gamma-ray counts. Default is 0.05.
+    apply_threshold_sensitivity : bool
+        If True, use `bkg_syst_fraction_sensitivity` and `gamma_min_sensitivity` in the sensitivity computation.
+        Default is False which is the same setting as the HGPS catalog.
+    selection_optional : list of str, optional
         Which additional maps to estimate besides delta TS, significance and symmetric error.
         Available options are:
 
             * "all": all the optional steps are executed
             * "errn-errp": estimate asymmetric errors.
             * "ul": estimate upper limits.
+            * "sensitivity": estimate sensitivity for a given significance
 
         Default is None so the optional steps are not executed.
-    energy_edges : `~astropy.units.Quantity`
-        Energy edges of the target excess maps bins.
+    energy_edges : list of `~astropy.units.Quantity`, optional
+        Edges of the target maps energy bins. The resulting bin edges won't be exactly equal to the input ones,
+        but rather the closest values to the energy axis edges of the parent dataset.
+        Default is None: apply the estimator in each energy bin of the parent dataset.
+        For further explanation see :ref:`estimators`.
     correlate_off : bool
         Correlate OFF events. Default is True.
     spectral_model : `~gammapy.modeling.models.SpectralModel`
@@ -117,7 +146,7 @@ class ExcessMapEstimator(Estimator):
       geom                   : WcsGeom
       axes                   : ['lon', 'lat', 'energy']
       shape                  : (320, 240, 1)
-      quantities             : ['npred', 'npred_excess', 'counts', 'ts', 'sqrt_ts', 'norm', 'norm_err']  # noqa: E501
+      quantities             : ['npred', 'npred_excess', 'counts', 'ts', 'sqrt_ts', 'norm', 'norm_err']
       ref. model             : pl
       n_sigma                : 1
       n_sigma_ul             : 2
@@ -127,7 +156,7 @@ class ExcessMapEstimator(Estimator):
     """
 
     tag = "ExcessMapEstimator"
-    _available_selection_optional = ["errn-errp", "ul"]
+    _available_selection_optional = ["errn-errp", "ul", "sensitivity"]
 
     def __init__(
         self,
@@ -138,10 +167,18 @@ class ExcessMapEstimator(Estimator):
         energy_edges=None,
         correlate_off=True,
         spectral_model=None,
+        n_sigma_sensitivity=5,
+        gamma_min_sensitivity=10,
+        bkg_syst_fraction_sensitivity=0.05,
+        apply_threshold_sensitivity=False,
     ):
         self.correlation_radius = correlation_radius
         self.n_sigma = n_sigma
         self.n_sigma_ul = n_sigma_ul
+        self.n_sigma_sensitivity = n_sigma_sensitivity
+        self.gamma_min_sensitivity = gamma_min_sensitivity
+        self.bkg_syst_fraction_sensitivity = bkg_syst_fraction_sensitivity
+        self.apply_threshold_sensitivity = apply_threshold_sensitivity
         self.selection_optional = selection_optional
         self.energy_edges = energy_edges
         self.correlate_off = correlate_off
@@ -157,7 +194,7 @@ class ExcessMapEstimator(Estimator):
 
     @correlation_radius.setter
     def correlation_radius(self, correlation_radius):
-        """Sets radius"""
+        """Set radius."""
         self._correlation_radius = Angle(correlation_radius)
 
     def run(self, dataset):
@@ -169,12 +206,12 @@ class ExcessMapEstimator(Estimator):
         Parameters
         ----------
         dataset : `~gammapy.datasets.MapDataset` or `~gammapy.datasets.MapDatasetOnOff`
-            Map dataset
+            Map dataset.
 
         Returns
         -------
         maps : `FluxMaps`
-            Flux maps
+            Flux maps.
         """
         if not isinstance(dataset, MapDataset):
             raise ValueError(
@@ -189,7 +226,9 @@ class ExcessMapEstimator(Estimator):
         if isinstance(dataset, MapDatasetOnOff):
             resampled_dataset.models = dataset.models
         else:
-            resampled_dataset.background = dataset.npred().resample_axis(axis=axis)
+            resampled_dataset.background = dataset.npred().resample_axis(
+                axis=axis, weights=dataset.mask_safe
+            )
             resampled_dataset.models = None
 
         result = self.estimate_excess_map(resampled_dataset)
@@ -206,7 +245,7 @@ class ExcessMapEstimator(Estimator):
         Returns
         -------
         kernel : `~astropy.convolution.Tophat2DKernel`
-            Kernel
+            Kernel.
         """
 
         pixel_size = np.mean(np.abs(dataset.counts.geom.wcs.wcs.cdelt))
@@ -228,8 +267,8 @@ class ExcessMapEstimator(Estimator):
 
         Returns
         -------
-        mask : `Map`
-            Mask map
+        mask : `~gammapy.maps.Map`
+            Mask map.
         """
         if dataset.mask_fit:
             mask = dataset.mask
@@ -245,17 +284,17 @@ class ExcessMapEstimator(Estimator):
 
         Parameters
         ----------
-        dataset : `MapDataset`
-            Map dataset
+        dataset : `~gammapy.datasets.MapDataset`
+            Map dataset.
         kernel : `~astropy.convolution.Tophat2DKernel`
-            Kernel
-        mask : `Map`
-            Mask map
+            Kernel.
+        mask : `~gammapy.maps.Map`
+            Mask map.
 
         Returns
         -------
         reco_exposure : `Map`
-            Reconstructed exposure map
+            Reconstructed exposure map.
         """
         if dataset.exposure:
             reco_exposure = estimate_exposure_reco_energy(
@@ -270,14 +309,14 @@ class ExcessMapEstimator(Estimator):
         return reco_exposure
 
     def estimate_excess_map(self, dataset):
-        """Estimate excess and ts maps for a single dataset.
+        """Estimate excess and test statistic maps for a single dataset.
 
         If exposure is defined, a flux map is also computed.
 
         Parameters
         ----------
-        dataset : `MapDataset`
-            Map dataset
+        dataset : `~gammapy.datasets.MapDataset`
+            Map dataset.
         """
 
         kernel = self.estimate_kernel(dataset)
@@ -324,6 +363,23 @@ class ExcessMapEstimator(Estimator):
                     )
                     / reco_exposure
                 )
+            if "sensitivity" in self.selection_optional:
+                excess_counts = counts_stat.n_sig_matching_significance(
+                    self.n_sigma_sensitivity
+                )
+                if self.apply_threshold_sensitivity:
+                    is_gamma_limited = excess_counts < self.gamma_min_sensitivity
+                    excess_counts[is_gamma_limited] = self.gamma_min_sensitivity
+                    bkg_syst_limited = (
+                        excess_counts
+                        < self.bkg_syst_fraction_sensitivity * dataset.background.data
+                    )
+                    excess_counts[bkg_syst_limited] = (
+                        self.bkg_syst_fraction_sensitivity
+                        * dataset.background.data[bkg_syst_limited]
+                    )
+                excess = Map.from_geom(geom=geom, data=excess_counts)
+                maps["norm_sensitivity"] = excess / reco_exposure
 
         # return nan values outside mask
         for name in maps:
@@ -332,8 +388,12 @@ class ExcessMapEstimator(Estimator):
         meta = {
             "n_sigma": self.n_sigma,
             "n_sigma_ul": self.n_sigma_ul,
+            "n_sigma_sensitivity": self.n_sigma_sensitivity,
             "sed_type_init": "likelihood",
         }
+        if self.apply_threshold_sensitivity:
+            meta["gamma_min_sensitivity"] = self.gamma_min_sensitivity
+            meta["bkg_syst_fraction_sensitivity"] = self.bkg_syst_fraction_sensitivity
 
         return FluxMaps.from_maps(
             maps=maps,
