@@ -6,7 +6,9 @@ import astropy.units as u
 import gammapy.utils.parallel as parallel
 from gammapy.data import GTI
 from gammapy.datasets import Datasets
+from gammapy.datasets.actors import DatasetsActor
 from gammapy.maps import LabelMapAxis, Map, TimeMapAxis
+from gammapy.utils.deprecation import deprecated_attribute
 from gammapy.utils.pbar import progress_bar
 from .core import FluxPoints
 from .sed import FluxPointsEstimator
@@ -20,7 +22,7 @@ class LightCurveEstimator(FluxPointsEstimator):
     """Estimate light curve.
 
     The estimator will apply flux point estimation on the source model component to datasets
-    in each of the provided time intervals.  The normalization is the only
+    in each of the provided time intervals.  The normalisation, `norm`, is the only
     parameter of the source model left free to vary. Other model components
     can be left free to vary with the reoptimize option.
 
@@ -36,11 +38,9 @@ class LightCurveEstimator(FluxPointsEstimator):
     Parameters
     ----------
     time_intervals : list of `astropy.time.Time`
-        Start and stop time for each interval to compute the LC
+        Start and stop time for each interval to compute the LC.
     source : str or int
-        For which source in the model to compute the flux points. Default is 0
-    energy_edges : `~astropy.units.Quantity`
-        Energy edges of the light curve.
+        For which source in the model to compute the flux points. Default is 0.
     atol : `~astropy.units.Quantity`
         Tolerance value for time comparison with different scale. Default 1e-6 sec.
     norm_min : float
@@ -55,25 +55,42 @@ class LightCurveEstimator(FluxPointsEstimator):
         Number of sigma to use for asymmetric error computation. Default is 1.
     n_sigma_ul : int
         Number of sigma to use for upper limit computation. Default is 2.
-    selection_optional : list of str
+    selection_optional : list of str, optional
         Which steps to execute. Available options are:
 
-            * "all": all the optional steps are executed
+            * "all": all the optional steps are executed.
             * "errn-errp": estimate asymmetric errors.
             * "ul": estimate upper limits.
             * "scan": estimate fit statistic profiles.
 
         Default is None so the optional steps are not executed.
+    energy_edges : list of `~astropy.units.Quantity`, optional
+        Edges of the lightcurve energy bins. The resulting bin edges won't be exactly equal to the input ones,
+        but rather the closest values to the energy axis edges of the parent dataset.
+        Default is None: apply the estimator in each energy bin of the parent dataset.
+        For further explanation see :ref:`estimators`.
     fit : `Fit`
         Fit instance specifying the backend and fit options.
     reoptimize : bool
-        Re-optimize other free model parameters. Default is False.
+        If True the free parameters of the other models are fitted in each bin independently,
+        together with the norm of the source of interest
+        (but the other parameters of the source of interest are kept frozen).
+        If False only the norm of the source of interest if fitted,
+        and all other parameters are frozen at their current values.
     n_jobs : int
         Number of processes used in parallel for the computation. Default is one,
         unless `~gammapy.utils.parallel.N_JOBS_DEFAULT` was modified. The number
         of jobs is limited to the number of physical CPUs.
     parallel_backend : {"multiprocessing", "ray"}
         Which backend to use for multiprocessing. Defaults to `~gammapy.utils.parallel.BACKEND_DEFAULT`.
+    norm : ~gammapy.modeling.Parameter` or dict
+        Norm parameter used for the fit
+        Default is None and a new parameter is created automatically,
+        with value=1, name="norm", scan_min=0.2, scan_max=5, and scan_n_values = 11.
+        By default the min and max are not set and derived from the source model,
+        unless the source model does not have one and only one norm parameter.
+        If a dict is given the entries should be a subset of
+        `~gammapy.modeling.Parameter` arguments.
 
     Examples
     --------
@@ -83,6 +100,11 @@ class LightCurveEstimator(FluxPointsEstimator):
 
     tag = "LightCurveEstimator"
 
+    norm_min = deprecated_attribute("norm_min", "1.2")
+    norm_max = deprecated_attribute("norm_max", "1.2")
+    norm_n_values = deprecated_attribute("norm_n_values", "1.2")
+    norm_values = deprecated_attribute("norm_values", "1.2")
+
     def __init__(self, time_intervals=None, atol="1e-6 s", **kwargs):
         self.time_intervals = time_intervals
         self.atol = u.Quantity(atol)
@@ -94,6 +116,10 @@ class LightCurveEstimator(FluxPointsEstimator):
 
         Normalize integral and energy flux between emin and emax.
 
+        Notes
+        -----
+        The progress bar can be displayed for this function.
+
         Parameters
         ----------
         datasets : list of `~gammapy.datasets.SpectrumDataset` or `~gammapy.datasets.MapDataset`
@@ -102,9 +128,10 @@ class LightCurveEstimator(FluxPointsEstimator):
         Returns
         -------
         lightcurve : `~gammapy.estimators.FluxPoints`
-            Light curve flux points
+            Light curve flux points.
         """
-        datasets = Datasets(datasets)
+        if not isinstance(datasets, DatasetsActor):
+            datasets = Datasets(datasets)
 
         if self.time_intervals is None:
             gti = datasets.gti
@@ -139,6 +166,7 @@ class LightCurveEstimator(FluxPointsEstimator):
                 parallel_datasets.append(datasets_to_fit)
 
         if self.n_jobs > 1:
+            self._update_child_jobs()
             rows = parallel.run_multiprocessing(
                 self.estimate_time_bin_flux,
                 zip(
@@ -162,14 +190,14 @@ class LightCurveEstimator(FluxPointsEstimator):
 
     @staticmethod
     def expand_map(m, dataset_names):
-        """Expand map in dataset axis
+        """Expand map in dataset axis.
 
         Parameters
         ----------
         map : `Map`
             Map to expand.
         dataset_names : list of str
-            Dataset names
+            Dataset names.
 
         Returns
         -------
@@ -190,7 +218,7 @@ class LightCurveEstimator(FluxPointsEstimator):
         Parameters
         ----------
         datasets : `~gammapy.modeling.Datasets`
-            List of dataset objects
+            List of dataset objects.
 
         Returns
         -------
@@ -198,7 +226,9 @@ class LightCurveEstimator(FluxPointsEstimator):
             Resulting flux points.
         """
 
-        fp = super().run(datasets)
+        estimator = self.copy()
+        estimator.n_jobs = self._n_child_jobs
+        fp = estimator._run_flux_points(datasets)
 
         if dataset_names:
             for name in ["counts", "npred", "npred_excess"]:
@@ -206,3 +236,6 @@ class LightCurveEstimator(FluxPointsEstimator):
                     fp._data[name], dataset_names=dataset_names
                 )
         return fp
+
+    def _run_flux_points(self, datasets):
+        return super().run(datasets)
