@@ -4,9 +4,10 @@ import astropy.units as u
 from astropy.visualization import quantity_support
 import matplotlib.pyplot as plt
 from matplotlib.ticker import FormatStrFormatter
-from gammapy.maps import Map, MapAxes, MapAxis, MapCoord, WcsGeom
+from gammapy.maps import HpxGeom, Map, MapAxes, MapAxis, MapCoord, WcsGeom
 from gammapy.maps.axes import UNIT_STRING_FORMAT
 from gammapy.modeling.models import PowerLawSpectralModel
+from gammapy.utils.deprecation import deprecated_renamed_argument
 from gammapy.utils.gauss import Gauss2DPDF
 from gammapy.utils.random import InverseCDFSampler, get_random_state
 from ..core import IRFMap
@@ -16,6 +17,26 @@ from .kernel import PSFKernel
 __all__ = ["PSFMap", "RecoPSFMap"]
 
 
+PSF_MAX_OVERSAMPLING = 4  # for backward compatibility
+
+
+def _psf_upsampling_factor(psf, geom, position, energy=None, precision_factor=12):
+    """Minimal factor between the bin half-width of the geom and the median R68% containment radius."""
+    if energy is None:
+        energy = geom.axes[psf.energy_name].center
+    psf_r68 = psf.containment_radius(
+        0.68, geom.axes[psf.energy_name].center, position=position
+    )
+    psf_r68_median = np.percentile(psf_r68, 50)
+    base_factor = (2 * psf_r68_median / geom.pixel_scales.max()).to_value("")
+    factor = np.minimum(
+        int(np.ceil(precision_factor / base_factor)), PSF_MAX_OVERSAMPLING
+    )
+    if isinstance(geom, HpxGeom):
+        factor = int(2 ** np.ceil(np.log(factor) / np.log(2)))
+    return factor
+
+
 class IRFLikePSF(PSF):
     required_axes = ["energy_true", "rad", "lat_idx", "lon_idx"]
     tag = "irf_like_psf"
@@ -27,7 +48,7 @@ class PSFMap(IRFMap):
     Parameters
     ----------
     psf_map : `~gammapy.maps.Map`
-        the input PSF Map. Should be a Map with 2 non spatial axes.
+        The input PSF Map. Should be a Map with 2 non spatial axes.
         rad and true energy axes should be given in this specific order.
     exposure_map : `~gammapy.maps.Map`
         Associated exposure map. Needs to have a consistent map geometry.
@@ -38,34 +59,36 @@ class PSFMap(IRFMap):
 
         from astropy.coordinates import SkyCoord
         from gammapy.maps import WcsGeom, MapAxis
-        from gammapy.data import Observation
+        from gammapy.data import Observation, FixedPointingInfo
         from gammapy.irf import load_irf_dict_from_file
         from gammapy.makers import MapDatasetMaker
 
         # Define observation
-        pointing = SkyCoord("0d", "0d")
+        pointing_position = SkyCoord(0, 0, unit="deg", frame="galactic")
+        pointing = FixedPointingInfo(
+            fixed_icrs=pointing_position.icrs,
+        )
         filename = "$GAMMAPY_DATA/cta-1dc/caldb/data/cta/1dc/bcf/South_z20_50h/irf_file.fits"
         irfs = load_irf_dict_from_file(filename)
         obs = Observation.create(pointing=pointing, irfs=irfs, livetime="1h")
 
-        # Create WcsGeom
         # Define energy axis. Note that the name is fixed.
         energy_axis = MapAxis.from_energy_bounds("0.1 TeV", "10 TeV", nbin=3, name="energy_true")
 
         # Define rad axis. Again note the axis name
         rad_axis = MapAxis.from_bounds(0, 0.5, nbin=100, name="rad", unit="deg")
 
+        # Create WcsGeom
         geom = WcsGeom.create(
-            binsz=0.25, width="5 deg", skydir=pointing, axes=[rad_axis, energy_axis]
+            binsz=0.25, width="5 deg", skydir=pointing_position, axes=[rad_axis, energy_axis]
         )
 
         maker = MapDatasetMaker()
-
         psf = maker.make_psf(geom=geom, observation=obs)
 
         # Get a PSF kernel at the center of the image
-        geom=exposure_geom.upsample(factor=10).drop("rad")
-        psf_kernel = psf_map.get_psf_kernel(geom=geom)
+        upsample_geom = geom.upsample(factor=10).drop("rad")
+        psf_kernel = psf.get_psf_kernel(geom=upsample_geom)
     """
 
     tag = "psf_map"
@@ -87,12 +110,12 @@ class PSFMap(IRFMap):
         self._irf_map = value
 
     def normalize(self):
-        """Normalize PSF map"""
+        """Normalize PSF map."""
         self.psf_map.normalize(axis_name="rad")
 
     @classmethod
     def from_geom(cls, geom):
-        """Create psf map from geom.
+        """Create PSF map from geometry.
 
         Parameters
         ----------
@@ -114,8 +137,8 @@ class PSFMap(IRFMap):
     def _psf_irf(self):
         geom = self.psf_map.geom
         npix_x, npix_y = geom.npix
-        axis_lon = MapAxis.from_edges(np.arange(npix_x + 1) - 0.5, name="lon_idx")
-        axis_lat = MapAxis.from_edges(np.arange(npix_y + 1) - 0.5, name="lat_idx")
+        axis_lon = MapAxis.from_edges(np.arange(npix_x[0] + 1) - 0.5, name="lon_idx")
+        axis_lat = MapAxis.from_edges(np.arange(npix_y[0] + 1) - 0.5, name="lat_idx")
         axes = MapAxes(
             [geom.axes[self.energy_name], geom.axes["rad"], axis_lat, axis_lon]
         )
@@ -147,21 +170,22 @@ class PSFMap(IRFMap):
         return coords_irf
 
     def containment(self, rad, energy_true, position=None):
-        """Containment at given coords
+        """Containment at given coordinates.
 
         Parameters
         ----------
         rad : `~astropy.units.Quantity`
-            Rad value
+            Rad value.
         energy_true : `~astropy.units.Quantity`
-            Energy true value
-        position : `~astropy.coordinates.SkyCoord`
-            Sky position. By default the center of the map is chosen
+            Energy true value.
+        position : `~astropy.coordinates.SkyCoord`, optional
+            Sky position. If None, the center of the map is chosen.
+            Default is None.
 
         Returns
         -------
         containment : `~astropy.units.Quantity`
-            Containment values
+            Containment values.
         """
         if position is None:
             position = self.psf_map.geom.center_skydir
@@ -171,21 +195,22 @@ class PSFMap(IRFMap):
         return self.psf_map.integral(axis_name="rad", coords=coords).to("")
 
     def containment_radius(self, fraction, energy_true, position=None):
-        """Containment at given coords
+        """Containment at given coordinates.
 
         Parameters
         ----------
         fraction : float
-            Containment fraction
+            Containment fraction.
         energy_true : `~astropy.units.Quantity`
-            Energy true value
-        position : `~astropy.coordinates.SkyCoord`
-            Sky position. By default the center of the map is chosen
+            Energy true value.
+        position : `~astropy.coordinates.SkyCoord`, optional
+            Sky position. If None, the center of the map is chosen.
+            Default is None.
 
         Returns
         -------
         containment : `~astropy.units.Quantity`
-            Containment values
+            Containment values.
         """
         if position is None:
             position = self.psf_map.geom.center_skydir
@@ -201,14 +226,15 @@ class PSFMap(IRFMap):
         Parameters
         ----------
         energy_true : `~astropy.units.Quantity`
-            Energy true at which to compute the containment radius
-        fraction : float
-            Containment fraction (range: 0 to 1)
+            Energy true at which to compute the containment radius.
+        fraction : float, optional
+            Containment fraction (range: 0 to 1).
+            Default is 0.68.
 
         Returns
         -------
         containment_radius_map : `~gammapy.maps.Map`
-            Containment radius map
+            Containment radius map.
         """
         geom = self.psf_map.geom.to_image()
 
@@ -219,35 +245,50 @@ class PSFMap(IRFMap):
         )
         return Map.from_geom(geom=geom, data=data.value, unit=data.unit)
 
+    @deprecated_renamed_argument(
+        "factor", "precision_factor", "v1.2", arg_in_kwargs=True
+    )
     def get_psf_kernel(
-        self, geom, position=None, max_radius=None, containment=0.999, factor=4
+        self,
+        geom,
+        position=None,
+        max_radius=None,
+        containment=0.999,
+        factor=None,
+        precision_factor=12,
     ):
-        """Returns a PSF kernel at the given position.
+        """Return a PSF kernel at the given position.
 
         The PSF is returned in the form a WcsNDMap defined by the input Geom.
 
         Parameters
         ----------
         geom : `~gammapy.maps.Geom`
-            Target geometry to use
-        position : `~astropy.coordinates.SkyCoord`
-            Target position. Should be a single coordinate. By default the
+            Target geometry to use.
+        position : `~astropy.coordinates.SkyCoord`, optional
+            Target position. Should be a single coordinate. By default, the
             center position is used.
-        max_radius : `~astropy.coordinates.Angle`
-            maximum angular size of the kernel map
-        containment : float
+        max_radius : `~astropy.coordinates.Angle`, optional
+            Maximum angular size of the kernel map.
+        containment : float, optional
             Containment fraction to use as size of the kernel. The max. radius
             across all energies is used. The radius can be overwritten using
-            the `max_radius` argument.
-        factor : int
-            oversampling factor to compute the PSF
+            the `max_radius` argument. Default is 0.999.
+        factor : int, optional
+            Oversampling factor to compute the PSF.
+            Default is None and it will be computed automatically.
+        precision_factor : int, optional
+            Factor between the bin half-width of the geom and the median R68% containment radius.
+            Used only for the oversampling method. Default is 10.
 
         Returns
         -------
         kernel : `~gammapy.irf.PSFKernel`
-            the resulting kernel
+            The resulting kernel.
         """
-        # TODO: try to simplify...is the oversampling needed?
+        if factor is None:  # TODO: remove once deprecated
+            factor = _psf_upsampling_factor(self, geom, position, precision_factor)
+
         if position is None:
             position = self.psf_map.geom.center_skydir
 
@@ -263,9 +304,8 @@ class PSFMap(IRFMap):
             radii = self.containment_radius(**kwargs)
             max_radius = np.max(radii)
 
-        geom = geom.to_odd_npix(max_radius=max_radius)
-        geom_upsampled = geom.upsample(factor=factor)
-        coords = geom_upsampled.get_coord(sparse=True)
+        geom = geom.to_odd_npix(max_radius=max_radius).upsample(factor=factor)
+        coords = geom.get_coord(sparse=True)
         rad = coords.skycoord.separation(geom.center_skydir)
 
         coords = {
@@ -278,59 +318,70 @@ class PSFMap(IRFMap):
             coords=coords,
             method="linear",
         )
-
-        kernel_map = Map.from_geom(geom=geom_upsampled, data=np.clip(data, 0, np.inf))
-        kernel_map = kernel_map.downsample(factor, preserve_counts=True)
+        kernel_map = Map.from_geom(geom=geom, data=np.clip(data, 0, np.inf))
+        kernel_map = kernel_map.downsample(factor=factor, preserve_counts=True)
         return PSFKernel(kernel_map, normalize=True)
 
-    def sample_coord(self, map_coord, random_state=0):
+    def sample_coord(self, map_coord, random_state=0, chunk_size=10000):
         """Apply PSF corrections on the coordinates of a set of simulated events.
 
         Parameters
         ----------
         map_coord : `~gammapy.maps.MapCoord` object.
             Sequence of coordinates and energies of sampled events.
-        random_state : {int, 'random-seed', 'global-rng', `~numpy.random.RandomState`}
+        random_state : {int, 'random-seed', 'global-rng', `~numpy.random.RandomState`}, optional
             Defines random number generator initialisation.
-            Passed to `~gammapy.utils.random.get_random_state`.
+            Passed to `~gammapy.utils.random.get_random_state`. Default is 0.
+        chunk_size : int
+            If set, this will slice the input MapCoord into smaller chunks of chunk_size elements.
+            Default is 10000.
 
         Returns
         -------
-        corr_coord : `~gammapy.maps.MapCoord` object.
+        corr_coord : `~gammapy.maps.MapCoord`
             Sequence of PSF-corrected coordinates of the input map_coord map.
         """
-
         random_state = get_random_state(random_state)
         rad_axis = self.psf_map.geom.axes["rad"]
 
-        coord = {
-            "skycoord": map_coord.skycoord.reshape(-1, 1),
-            self.energy_name: map_coord[self.energy_name].reshape(-1, 1),
-            "rad": rad_axis.center,
-        }
+        position = map_coord.skycoord
+        energy = map_coord[self.energy_name]
 
-        pdf = (
-            self.psf_map.interp_by_coord(coord)
-            * rad_axis.center.value
-            * rad_axis.bin_width.value
-        )
+        size = position.size
+        separation = np.ones(size) * u.deg
+        chunk_size = size if chunk_size is None else chunk_size
 
-        sample_pdf = InverseCDFSampler(pdf, axis=1, random_state=random_state)
-        pix_coord = sample_pdf.sample_axis()
-        separation = rad_axis.pix_to_coord(pix_coord)
+        index = 0
+
+        while index < size:
+            chunk = slice(index, index + chunk_size, 1)
+            coord = {
+                "skycoord": position[chunk].reshape(-1, 1),
+                self.energy_name: energy[chunk].reshape(-1, 1),
+                "rad": rad_axis.center,
+            }
+
+            pdf = (
+                self.psf_map.interp_by_coord(coord)
+                * rad_axis.center.value
+                * rad_axis.bin_width.value
+            )
+
+            sample_pdf = InverseCDFSampler(pdf, axis=1, random_state=random_state)
+            pix_coord = sample_pdf.sample_axis()
+            separation[chunk] = rad_axis.pix_to_coord(pix_coord)
+            index += chunk_size
 
         position_angle = random_state.uniform(360, size=len(map_coord.lon)) * u.deg
 
         event_positions = map_coord.skycoord.directional_offset_by(
             position_angle=position_angle, separation=separation
         )
-        return MapCoord.create(
-            {"skycoord": event_positions, self.energy_name: map_coord[self.energy_name]}
-        )
+        return MapCoord.create({"skycoord": event_positions, self.energy_name: energy})
 
     @classmethod
     def from_gauss(cls, energy_axis_true, rad_axis=None, sigma=0.1 * u.deg, geom=None):
-        """Create all -sky PSF map from Gaussian width.
+        """Create all-sky PSF map from Gaussian width.
 
         This is used for testing and examples.
 
@@ -347,7 +398,7 @@ class PSFMap(IRFMap):
         sigma : `~astropy.coordinates.Angle`
             Gaussian width.
         geom : `Geom`
-            Image geometry. By default an allsky geometry is created.
+            Image geometry. By default, an all-sky geometry is created.
 
         Returns
         -------
@@ -383,8 +434,7 @@ class PSFMap(IRFMap):
         return cls(psf_map=psf_map, exposure_map=exposure_map)
 
     def to_image(self, spectrum=None, keepdims=True):
-        """Reduce to a 2-D map after weighing
-        with the associated exposure and a spectrum
+        """Reduce to a 2D map after weighing with the associated exposure and a spectrum.
 
         Parameters
         ----------
@@ -393,13 +443,12 @@ class PSFMap(IRFMap):
             Default is power-law with spectral index of 2.
         keepdims : bool, optional
             If True, the energy axis is kept with one bin.
-            If False, the axis is removed
-
+            If False, the axis is removed.
 
         Returns
         -------
         psf_out : `PSFMap`
-            `PSFMap` with the energy axis summed over
+            `PSFMap` with the energy axis summed over.
         """
         from gammapy.makers.utils import _map_spectrum_weight
 
@@ -426,8 +475,8 @@ class PSFMap(IRFMap):
 
         Parameters
         ----------
-        ax : `~matplotlib.pyplot.Axes`
-            Axes to plot on.
+        ax : `~matplotlib.pyplot.Axes`, optional
+            Matplotlib axes. Default is None.
         fraction : list of float or `~numpy.ndarray`
             Containment fraction between 0 and 1.
         **kwargs : dict
@@ -436,7 +485,7 @@ class PSFMap(IRFMap):
         Returns
         -------
         ax : `~matplotlib.pyplot.Axes`
-             Axes to plot on.
+             Matplotlib axes.
 
         """
         ax = plt.gca() if ax is None else ax
@@ -467,8 +516,8 @@ class PSFMap(IRFMap):
 
         Parameters
         ----------
-        ax : `~matplotlib.pyplot.Axes`
-            Axes to plot on.
+        ax : `~matplotlib.pyplot.Axes`, optional
+            Matplotlib axes. Default is None.
         energy : `~astropy.units.Quantity`
             Energies where to plot the PSF.
         **kwargs : dict
@@ -477,7 +526,7 @@ class PSFMap(IRFMap):
         Returns
         -------
         ax : `~matplotlib.pyplot.Axes`
-             Axes to plot on.
+             Matplotlib axes.
 
         """
         ax = plt.gca() if ax is None else ax
@@ -582,7 +631,7 @@ class RecoPSFMap(PSFMap):
         sigma : `~astropy.coordinates.Angle`
             Gaussian width.
         geom : `Geom`
-            Image geometry. By default an allsky geometry is created.
+            Image geometry. By default, an all-sky geometry is created.
 
         Returns
         -------
@@ -592,40 +641,40 @@ class RecoPSFMap(PSFMap):
         return super().from_gauss(energy_axis, rad_axis, sigma, geom)
 
     def containment(self, rad, energy, position=None):
-        """Containment at given coords
+        """Containment at given coordinates.
 
         Parameters
         ----------
         rad : `~astropy.units.Quantity`
-            Rad value
+            Rad value.
         energy : `~astropy.units.Quantity`
-            Energy value
-        position : `~astropy.coordinates.SkyCoord`
-            Sky position. By default the center of the map is chosen
+            Energy value.
+        position : `~astropy.coordinates.SkyCoord`, optional
+            Sky position. By default, the center of the map is chosen.
 
         Returns
         -------
         containment : `~astropy.units.Quantity`
-            Containment values
+            Containment values.
         """
         return super().containment(rad, energy, position)
 
     def containment_radius(self, fraction, energy, position=None):
-        """Containment at given coords
+        """Containment at given coordinates.
 
         Parameters
         ----------
         fraction : float
-            Containment fraction
+            Containment fraction.
         energy : `~astropy.units.Quantity`
-            Energy value
-        position : `~astropy.coordinates.SkyCoord`
-            Sky position. By default the center of the map is chosen
+            Energy value.
+        position : `~astropy.coordinates.SkyCoord`, optional
+            Sky position. By default, the center of the map is chosen.
 
         Returns
         -------
         containment : `~astropy.units.Quantity`
-            Containment values
+            Containment values.
         """
         return super().containment_radius(fraction, energy, position)
 
@@ -636,13 +685,14 @@ class RecoPSFMap(PSFMap):
         ----------
         energy : `~astropy.units.Quantity`
             Energy at which to compute the containment radius
-        fraction : float
-            Containment fraction (range: 0 to 1)
+        fraction : float, optional
+            Containment fraction (range: 0 to 1).
+            Default is 0.68.
 
         Returns
         -------
         containment_radius_map : `~gammapy.maps.Map`
-            Containment radius map
+            Containment radius map.
         """
         return super().containment_radius_map(energy, fraction=0.68)
 
@@ -653,8 +703,8 @@ class RecoPSFMap(PSFMap):
 
         Parameters
         ----------
-        ax : `~matplotlib.pyplot.Axes`
-            Axes to plot on.
+        ax : `~matplotlib.pyplot.Axes`, optional
+            Matplotlib axes. Default is None.
         energy : `~astropy.units.Quantity`
             Energies where to plot the PSF.
         **kwargs : dict
@@ -663,7 +713,7 @@ class RecoPSFMap(PSFMap):
         Returns
         -------
         ax : `~matplotlib.pyplot.Axes`
-             Axes to plot on.
+             Matplotlib axes.
 
         """
         return super().plot_psf_vs_rad(ax, energy_true=energy, **kwargs)
