@@ -97,7 +97,9 @@ def test_hpxmap_read_write(tmp_path, nside, nested, frame, region, axes):
 def test_hpxmap_read_write_fgst(tmp_path):
     path = tmp_path / "tmp.fits"
 
-    axis = MapAxis.from_bounds(100.0, 1000.0, 4, name="energy", unit="MeV")
+    axis = MapAxis.from_bounds(
+        100.0, 1000.0, 4, name="energy", unit="MeV", interp="log"
+    )
 
     # Test Counts Cube
     m = create_map(8, False, "galactic", None, [axis])
@@ -109,8 +111,10 @@ def test_hpxmap_read_write_fgst(tmp_path):
         assert hdulist["SKYMAP"].header["TTYPE1"] == "CHANNEL1"
 
     m2 = Map.read(path)
-    # TODO: add better asserts here
     assert m2 is not None
+    assert m.geom.axes.is_allclose(m2.geom.axes)
+    assert m.geom.is_allclose(m2.geom)
+    assert m.is_allclose(m2)
 
     # Test Model Cube
     m.write(path, format="fgst-template", overwrite=True)
@@ -121,8 +125,9 @@ def test_hpxmap_read_write_fgst(tmp_path):
         assert hdulist["SKYMAP"].header["TTYPE1"] == "ENERGY1"
 
     m2 = Map.read(path)
-    # TODO: add better asserts here
     assert m2 is not None
+    assert_allclose(m2.geom.axes["energy_true"].edges, axis.edges, atol=1e-3)
+    assert_allclose(m.data, m2.data)
 
 
 @requires_data()
@@ -612,3 +617,9 @@ def test_map_plot_mask():
 
     with mpl_plot_check():
         mask.plot_mask()
+
+
+def test_hpx_map_sampling():
+    hpxmap = HpxNDMap.create(nside=16)
+    with pytest.raises(NotImplementedError):
+        hpxmap.sample_coord(2)
