@@ -28,7 +28,6 @@ MAP_AXIS_NODE_TYPES = [
     ([0.25, 0.75, 1.0, 2.0], "sqrt", "center"),
 ]
 
-
 nodes_array = np.array([0.25, 0.75, 1.0, 2.0])
 
 MAP_AXIS_NODE_TYPE_UNIT = [
@@ -536,6 +535,40 @@ def test_coord_to_idx_time_axis(time_intervals):
     assert_allclose(pixels[1::2], [np.nan, 1, 3, 5, 7, 9, 11, 13, 15, 17, 19])
 
 
+def test_pix_to_coord_time_axis(time_intervals):
+    tmin = time_intervals["t_min"]
+    tmax = time_intervals["t_max"]
+    tref = time_intervals["t_ref"]
+    axis = TimeMapAxis(tmin, tmax, tref, name="time")
+
+    pixels = [1.3, 3.2, 5.4, 7, 15.33, 17.21, 19.11]
+    coords = axis.pix_to_coord(pixels)
+    assert_allclose(
+        coords[0:3].mjd, [58927.538816, 58928.587281, 58929.648246], rtol=1e-5
+    )
+
+    # test with nan indices
+    pixels.append(np.nan)
+    coords = axis.pix_to_coord(pixels)
+    assert_allclose(
+        coords[-3:].mjd,
+        [58935.9561, 58937.0046, -3.72500000e-04],
+        rtol=1e-5,
+    )
+
+    # assert with invalid pixels & multidim array
+    coords = axis.pix_to_coord([[-1.2, 0.6], [1.5, 24.7]])
+    assert_allclose(
+        coords.mjd,
+        [[-3.72500000e-04, 5.89270250e04], [5.89275471e04, -3.72500000e-04]],
+        rtol=1e-5,
+    )
+
+    # test with one value
+    coords = axis.pix_to_coord(3)
+    assert_allclose(coords.mjd, axis.time_min[3].mjd, rtol=1e-5)
+
+
 def test_slice_time_axis(time_intervals):
     axis = TimeMapAxis(
         time_intervals["t_min"], time_intervals["t_max"], time_intervals["t_ref"]
@@ -631,6 +664,15 @@ def test_from_gti_bounds():
     assert_time_allclose(axis.time_max[-1], expected)
 
 
+def test_to_gti(time_intervals):
+    time_axis = TimeMapAxis(
+        time_intervals["t_min"], time_intervals["t_max"], time_intervals["t_ref"]
+    )
+    gti = time_axis.to_gti()
+    assert len(gti.table) == 20
+    assert TimeMapAxis.from_gti(gti) == time_axis
+
+
 def test_map_with_time_axis(time_intervals):
     time_axis = TimeMapAxis(
         time_intervals["t_min"], time_intervals["t_max"], time_intervals["t_ref"]
@@ -837,6 +879,37 @@ def test_time_map_axis_format_plot_xaxis(time_intervals):
     assert ax2.axes.axes.get_xlabel().split()[1] == "[mjd]"
 
 
+def test_time_group_table(time_intervals):
+    axis = TimeMapAxis(
+        time_intervals["t_min"],
+        time_intervals["t_max"],
+        time_intervals["t_ref"],
+        name="time",
+    )
+
+    groups = axis.group_table(interval_edges=[5 * u.d - 1 * u.h, 6 * u.d + 2 * u.h])
+    assert_allclose(groups["idx_min"], [10])
+    assert_allclose(groups["idx_max"], [11])
+    assert_allclose(groups["time_min"], [58932.263158])
+    assert_allclose(groups["time_max"], [58932.83114])
+
+    groups_overflow = axis.group_table(interval_edges=[11 * u.d, 12 * u.d])
+    assert_allclose(groups_overflow["idx_min"], [-1])
+
+    groups_timeedges = axis.group_table(
+        interval_edges=[
+            Time("2020-03-19") + 5 * u.d - 1 * u.h,
+            Time("2020-03-19") + 6 * u.d + 2 * u.h,
+        ]
+    )
+    assert_allclose(groups_timeedges["time_min"], [58932.263158])
+    assert_allclose(groups_timeedges["time_max"], [58932.83114])
+
+    groups_exactedges = axis.group_table(interval_edges=[3 * u.d, 7 * u.d + 1 * u.h])
+    assert_allclose(groups_exactedges["idx_min"], [6])
+    assert_allclose(groups_exactedges["idx_max"], [13])
+
+
 def test_single_valued_axis():
     # this will be interpreted as a scalar value
     # that is against the specifications, but we allow it nevertheless
@@ -880,3 +953,12 @@ def test_label_map_axis_squash():
 
     assert squash_label.nbin == 1
     assert_equal(squash_label.center, np.array(["a...c"]))
+
+
+def test_energy_bin_per_decade_not_strict_bounds():
+    nbin = 5
+    axis = MapAxis.from_energy_bounds(
+        "0.03 TeV", "333 TeV", nbin=nbin, per_decade=True, strict_bounds=False
+    )
+
+    assert_allclose(axis.edges[0:-nbin] * 10.0, axis.edges[nbin:], rtol=1e-5, atol=0)
