@@ -25,8 +25,9 @@ from gammapy.modeling.models import (
     SkyModel,
     TemplateNPredModel,
 )
-from gammapy.utils.scripts import read_yaml, write_yaml
-from gammapy.utils.testing import requires_data
+from gammapy.utils.deprecation import GammapyDeprecationWarning
+from gammapy.utils.scripts import make_path, read_yaml, write_yaml
+from gammapy.utils.testing import requires_data, requires_dependency
 
 
 @pytest.fixture(scope="session")
@@ -108,7 +109,6 @@ def test_dict_to_skymodels(models):
 
 @requires_data()
 def test_sky_models_io(tmpdir, models):
-    # TODO: maybe change to a test case where we create a model programmatically?
     models.covariance = np.eye(len(models.parameters))
     models.write(tmpdir / "tmp.yaml", full_output=True, overwrite_templates=False)
     models = Models.read(tmpdir / "tmp.yaml")
@@ -123,6 +123,31 @@ def test_sky_models_io(tmpdir, models):
     # or check serialised dict content
 
 
+@requires_data()
+def test_sky_models_checksum(tmpdir, models):
+    import yaml
+
+    models.write(
+        tmpdir / "tmp.yaml", full_output=True, overwrite_templates=False, checksum=True
+    )
+    file = open(tmpdir / "tmp.yaml", "rb")
+    yaml_content = file.read()
+    file.close()
+
+    assert "checksum: " in str(yaml_content)
+
+    data = yaml.safe_load(yaml_content)
+    data["checksum"] = "bad"
+    yaml_str = yaml.dump(
+        data, sort_keys=False, indent=4, width=80, default_flow_style=False
+    )
+    path = make_path(tmpdir) / "bad_checksum.yaml"
+    path.write_text(yaml_str)
+
+    with pytest.warns(UserWarning):
+        Models.read(tmpdir / "bad_checksum.yaml", checksum=True)
+
+
 @requires_data()
 def test_sky_models_io_auto_write(tmp_path, models):
     models_new = models.copy()
@@ -285,6 +310,21 @@ def test_absorption_io(tmp_path):
     read_yaml(tmp_path / "tmp.yaml")
 
 
+@requires_dependency("naima")
+def test_naima_model():
+    import naima
+
+    particle_distribution = naima.models.PowerLaw(
+        amplitude=2e33 / u.eV, e_0=10 * u.TeV, alpha=2.5
+    )
+    radiative_model = naima.radiative.PionDecay(
+        particle_distribution, nh=1 * u.cm**-3
+    )
+    yield Model.create(
+        "NaimaSpectralModel", "spectral", radiative_model=radiative_model
+    )
+
+
 def make_all_models():
     """Make an instance of each model, for testing."""
     yield Model.create("ConstantSpatialModel", "spatial")
@@ -315,13 +355,15 @@ def make_all_models():
     yield Model.create("PowerLawNormSpectralModel", "spectral")
     yield Model.create("PowerLaw2SpectralModel", "spectral")
     yield Model.create("ExpCutoffPowerLawSpectralModel", "spectral")
-    yield Model.create("ExpCutoffPowerLawNormSpectralModel", "spectral")
+    with pytest.warns(GammapyDeprecationWarning):
+        yield Model.create("ExpCutoffPowerLawNormSpectralModel", "spectral")
     yield Model.create("ExpCutoffPowerLaw3FGLSpectralModel", "spectral")
     yield Model.create("SuperExpCutoffPowerLaw3FGLSpectralModel", "spectral")
     yield Model.create("SuperExpCutoffPowerLaw4FGLDR3SpectralModel", "spectral")
     yield Model.create("SuperExpCutoffPowerLaw4FGLSpectralModel", "spectral")
     yield Model.create("LogParabolaSpectralModel", "spectral")
-    yield Model.create("LogParabolaNormSpectralModel", "spectral")
+    with pytest.warns(GammapyDeprecationWarning):
+        yield Model.create("LogParabolaNormSpectralModel", "spectral")
     yield Model.create(
         "TemplateSpectralModel", "spectral", energy=[1, 2] * u.cm, values=[3, 4] * u.cm
     )  # TODO: add unit validation?
@@ -332,9 +374,16 @@ def make_all_models():
         norms=[3, 4] * u.cm,
     )
     yield Model.create("GaussianSpectralModel", "spectral")
-    # TODO: yield Model.create("EBLAbsorptionNormSpectralModel")
-    # TODO: yield Model.create("NaimaSpectralModel")
-    # TODO: yield Model.create("ScaleSpectralModel")
+    yield Model.create(
+        "EBLAbsorptionNormSpectralModel",
+        "spectral",
+        energy=[0, 1, 2] * u.keV,
+        param=[0, 1],
+        data=np.ones((2, 3)),
+        redshift=0.1,
+        alpha_norm=1.0,
+    )
+    yield Model.create("ScaleSpectralModel", "spectral", model=PowerLawSpectralModel())
     yield Model.create("ConstantTemporalModel", "temporal")
     yield Model.create("LinearTemporalModel", "temporal")
     yield Model.create("PowerLawTemporalModel", "temporal")
@@ -441,7 +490,6 @@ def test_to_dict_not_default():
     assert "error" not in index_dict
     assert "interp" not in index_dict
     assert "scale_method" not in index_dict
-    assert "is_norm" not in index_dict
 
     model_2 = model.from_dict(mdict)
     assert model_2.index.min == model.index.min
@@ -480,3 +528,13 @@ def test_compound_models_io(tmp_path):
         "model.spectral.alpha",
         "model.spectral.beta",
     ]
+
+
+def test_meta_io(caplog, tmp_path):
+    m = PowerLawSpectralModel()
+    sk = SkyModel(spectral_model=m, name="model")
+    Models([sk]).write(tmp_path / "test.yaml")
+
+    sk_dict = read_yaml(tmp_path / "test.yaml")
+    assert "metadata" in sk_dict
+    assert "Gammapy" in sk_dict["metadata"]["creator"]
