@@ -2,14 +2,16 @@
 """Model parameter classes."""
 import collections.abc
 import copy
+import html
 import itertools
 import logging
 import numpy as np
 from astropy import units as u
 from astropy.table import Table
+from gammapy.utils.deprecation import deprecated_attribute
 from gammapy.utils.interpolation import interpolation_scale
 
-__all__ = ["Parameter", "Parameters"]
+__all__ = ["Parameter", "Parameters", "PriorParameter", "PriorParameters"]
 
 log = logging.getLogger(__name__)
 
@@ -62,21 +64,21 @@ class Parameter:
     Parameters
     ----------
     name : str
-        Name
+        Name.
     value : float or `~astropy.units.Quantity`
-        Value
+        Value.
     scale : float, optional
-        Scale (sometimes used in fitting)
+        Scale (sometimes used in fitting).
     unit : `~astropy.units.Unit` or str, optional
-        Unit
+        Unit.
     min : float, optional
-        Minimum (sometimes used in fitting)
+        Minimum (sometimes used in fitting).
     max : float, optional
-        Maximum (sometimes used in fitting)
+        Maximum (sometimes used in fitting).
     frozen : bool, optional
-        Frozen? (used in fitting)
+        Frozen (used in fitting).
     error : float
-        Parameter error
+        Parameter error.
     scan_min : float
         Minimum value for the parameter scan. Overwrites scan_n_sigma.
     scan_max : float
@@ -86,15 +88,21 @@ class Parameter:
     scan_n_sigma : int
         Number of sigmas to scan.
     scan_values: `numpy.array`
-        Scan values. Overwrites all of the scan keywords before.
+        Scan values. Overwrites all the scan keywords before.
     scale_method : {'scale10', 'factor1', None}
-        Method used to set ``factor`` and ``scale``
+        Method used to set ``factor`` and ``scale``.
     interp : {"lin", "sqrt", "log"}
         Parameter scaling to use for the scan.
     is_norm : bool
         Whether the parameter represents the flux norm of the model.
+    prior : `~gammapy.modeling.models.Prior`
+        Prior set on the parameter.
     """
 
+    norm_parameters = deprecated_attribute("norm_parameters", "1.2")
+
+    is_norm = deprecated_attribute("is_norm", "1.2")
+
     def __init__(
         self,
         name,
@@ -113,6 +121,7 @@ class Parameter:
         scale_method="scale10",
         interp="lin",
         is_norm=False,
+        prior=None,
     ):
         if not isinstance(name, str):
             raise TypeError(f"Name must be string, got '{type(name)}' instead")
@@ -144,6 +153,7 @@ class Parameter:
         self.scan_n_sigma = scan_n_sigma
         self.interp = interp
         self.scale_method = scale_method
+        self.prior = prior
 
     def __get__(self, instance, owner):
         if instance is None:
@@ -165,9 +175,29 @@ class Parameter:
             raise ValueError(f"Expected parameter name '{name}', got {self._name}")
 
     @property
-    def is_norm(self):
-        """Whether the parameter represents the norm of the model"""
-        return self._is_norm
+    def prior(self):
+        """Prior applied to the parameter  as a `~gammapy.modeling.models.Prior`."""
+        return self._prior
+
+    @prior.setter
+    def prior(self, value):
+        if value is not None:
+            from .models import Prior
+
+            if isinstance(value, dict):
+                from .models import Model
+
+                self._prior = Model.from_dict({"prior": value})
+            elif isinstance(value, Prior):
+                self._prior = value
+            else:
+                raise TypeError(f"Invalid type: {value!r}")
+        else:
+            self._prior = value
+
+    def prior_stat_sum(self):
+        if self.prior is not None:
+            return self.prior(self)
 
     @property
     def type(self):
@@ -183,12 +213,12 @@ class Parameter:
 
     @property
     def name(self):
-        """Name (str)."""
+        """Name as a string."""
         return self._name
 
     @property
     def factor(self):
-        """Factor (float)."""
+        """Factor as a float."""
         return self._factor
 
     @factor.setter
@@ -197,7 +227,7 @@ class Parameter:
 
     @property
     def scale(self):
-        """Scale (float)."""
+        """Scale as a float."""
         return self._scale
 
     @scale.setter
@@ -206,7 +236,7 @@ class Parameter:
 
     @property
     def unit(self):
-        """Unit (`~astropy.units.Unit`)."""
+        """Unit as a `~astropy.units.Unit` object."""
         return self._unit
 
     @unit.setter
@@ -215,12 +245,12 @@ class Parameter:
 
     @property
     def min(self):
-        """Minimum (float)."""
+        """Minimum as a float."""
         return self._min
 
     @min.setter
     def min(self, val):
-        "Astropy Table has masked values for NaN. Replacing with np.nan."
+        """`~astropy.table.Table` has masked values for NaN. Replacing with NaN."""
         if isinstance(val, np.ma.core.MaskedConstant):
             self._min = np.nan
         else:
@@ -228,7 +258,7 @@ class Parameter:
 
     @property
     def factor_min(self):
-        """Factor min (float).
+        """Factor minimum as a float.
 
         This ``factor_min = min / scale`` is for the optimizer interface.
         """
@@ -236,12 +266,12 @@ class Parameter:
 
     @property
     def max(self):
-        """Maximum (float)."""
+        """Maximum as a float."""
         return self._max
 
     @max.setter
     def max(self, val):
-        "Astropy Table has masked values for NaN. Replacing with np.nan."
+        """`~astropy.table.Table` has masked values for NaN. Replacing with NaN."""
         if isinstance(val, np.ma.core.MaskedConstant):
             self._max = np.nan
         else:
@@ -249,7 +279,7 @@ class Parameter:
 
     @property
     def factor_max(self):
-        """Factor max (float).
+        """Factor maximum as a float.
 
         This ``factor_max = max / scale`` is for the optimizer interface.
         """
@@ -257,7 +287,7 @@ class Parameter:
 
     @property
     def scale_method(self):
-        """Method used to set ``factor`` and ``scale``"""
+        """Method used to set ``factor`` and ``scale``."""
         return self._scale_method
 
     @scale_method.setter
@@ -268,7 +298,7 @@ class Parameter:
 
     @property
     def frozen(self):
-        """Frozen? (used in fitting) (bool)."""
+        """Frozen (used in fitting) (bool)."""
         return self._frozen
 
     @frozen.setter
@@ -290,7 +320,7 @@ class Parameter:
 
     @property
     def quantity(self):
-        """Value times unit (`~astropy.units.Quantity`)."""
+        """Value times unit as a `~astropy.units.Quantity`."""
         return self.value * self.unit
 
     @quantity.setter
@@ -308,9 +338,9 @@ class Parameter:
     # TODO: possibly allow to set this independently
     @property
     def conf_min(self):
-        """Confidence min value (`float`)
+        """Confidence minimum value as a `float`.
 
-        Returns parameter minimum if defined else the scan_min
+        Return parameter minimum if defined, otherwise return the scan_min.
         """
         if not np.isnan(self.min):
             return self.min
@@ -320,9 +350,9 @@ class Parameter:
     # TODO: possibly allow to set this independently
     @property
     def conf_max(self):
-        """Confidence max value (`float`)
+        """Confidence maximum value as a `float`.
 
-        Returns parameter maximum if defined else the scan_max
+        Return parameter maximum if defined, otherwise return the scan_max.
         """
         if not np.isnan(self.max):
             return self.max
@@ -331,7 +361,7 @@ class Parameter:
 
     @property
     def scan_min(self):
-        """Stat scan min"""
+        """Stat scan minimum."""
         if self._scan_min is None:
             return self.value - self.error * self.scan_n_sigma
 
@@ -339,7 +369,7 @@ class Parameter:
 
     @property
     def scan_max(self):
-        """Stat scan max"""
+        """Stat scan maximum."""
         if self._scan_max is None:
             return self.value + self.error * self.scan_n_sigma
 
@@ -347,27 +377,27 @@ class Parameter:
 
     @scan_min.setter
     def scan_min(self, value):
-        """Stat scan min setter"""
+        """Stat scan minimum setter."""
         self._scan_min = value
 
     @scan_max.setter
     def scan_max(self, value):
-        """Stat scan max setter"""
+        """Stat scan maximum setter."""
         self._scan_max = value
 
     @property
     def scan_n_sigma(self):
-        """Stat scan n sigma"""
+        """Stat scan n sigma."""
         return self._scan_n_sigma
 
     @scan_n_sigma.setter
     def scan_n_sigma(self, n_sigma):
-        """Stat scan n sigma"""
+        """Stat scan n sigma."""
         self._scan_n_sigma = int(n_sigma)
 
     @property
     def scan_values(self):
-        """Stat scan values (`~numpy.ndarray`)"""
+        """Stat scan values as a `~numpy.ndarray`."""
         if self._scan_values is None:
             scale = interpolation_scale(self.interp)
             parmin, parmax = scale([self.scan_min, self.scan_max])
@@ -378,11 +408,11 @@ class Parameter:
 
     @scan_values.setter
     def scan_values(self, values):
-        """Set scan values"""
+        """Set scan values."""
         self._scan_values = values
 
     def check_limits(self):
-        """Emit a warning or error if value is outside the min/max range"""
+        """Emit a warning or error if value is outside the minimum/maximum range."""
         if not self.frozen:
             if (~np.isnan(self.min) and (self.value <= self.min)) or (
                 ~np.isnan(self.max) and (self.value >= self.max)
@@ -396,22 +426,29 @@ class Parameter:
         return (
             f"{self.__class__.__name__}(name={self.name!r}, value={self.value!r}, "
             f"factor={self.factor!r}, scale={self.scale!r}, unit={self.unit!r}, "
-            f"min={self.min!r}, max={self.max!r}, frozen={self.frozen!r}, id={hex(id(self))})"
+            f"min={self.min!r}, max={self.max!r}, frozen={self.frozen!r}, prior={self.prior!r}, id={hex(id(self))})"
         )
 
+    def _repr_html_(self):
+        try:
+            return self.to_html()
+        except AttributeError:
+            return f"<pre>{html.escape(str(self))}</pre>"
+
     def copy(self):
-        """A deep copy"""
+        """Deep copy."""
         return copy.deepcopy(self)
 
     def update_from_dict(self, data):
-        """Update parameters from a dict.
-        Protection against changing parameter model, type, name."""
-        keys = ["value", "unit", "min", "max", "frozen"]
+        """Update parameters from a dictionary."""
+        keys = ["value", "unit", "min", "max", "frozen", "prior"]
         for k in keys:
+            if k == "prior" and data[k] == "":
+                data[k] = None
             setattr(self, k, data[k])
 
     def to_dict(self):
-        """Convert to dict."""
+        """Convert to dictionary."""
         output = {
             "name": self.name,
             "value": self.value,
@@ -422,20 +459,21 @@ class Parameter:
             "frozen": self.frozen,
             "interp": self.interp,
             "scale_method": self.scale_method,
-            "is_norm": self.is_norm,
+            "is_norm": self._is_norm,
         }
 
         if self._link_label_io is not None:
             output["link"] = self._link_label_io
-
+        if self.prior is not None:
+            output["prior"] = self.prior.to_dict()["prior"]
         return output
 
     def autoscale(self):
         """Autoscale the parameters.
 
-        Set ``factor`` and ``scale`` according to ``scale_method`` attribute
+        Set ``factor`` and ``scale`` according to ``scale_method`` attribute.
 
-        Available ``scale_method``
+        Available ``scale_method``.
 
         * ``scale10`` sets ``scale`` to power of 10,
           so that abs(factor) is in the range 1 to 10
@@ -467,7 +505,7 @@ class Parameters(collections.abc.Sequence):
     Parameters
     ----------
     parameters : list of `Parameter`
-        List of parameters
+        List of parameters.
     """
 
     def __init__(self, parameters=None):
@@ -478,24 +516,41 @@ class Parameters(collections.abc.Sequence):
 
         self._parameters = parameters
 
+    def _repr_html_(self):
+        try:
+            return self.to_html()
+        except AttributeError:
+            return f"<pre>{html.escape(str(self))}</pre>"
+
     def check_limits(self):
-        """Check parameter limits and emit a warning"""
+        """Check parameter limits and emit a warning."""
         for par in self:
             par.check_limits()
 
+    @property
+    def prior(self):
+        return [par.prior for par in self]
+
+    def prior_stat_sum(self):
+        parameters_stat_sum = 0
+        for par in self:
+            if par.prior is not None:
+                parameters_stat_sum += par.prior_stat_sum()
+        return parameters_stat_sum
+
     @property
     def types(self):
-        """Parameter types"""
+        """Parameter types."""
         return [par.type for par in self]
 
     @property
     def min(self):
-        """Parameter mins (`numpy.ndarray`)."""
+        """Parameter minima as a `numpy.ndarray`."""
         return np.array([_.min for _ in self._parameters], dtype=np.float64)
 
     @min.setter
     def min(self, min_array):
-        """Parameter minima (`numpy.ndarray`)."""
+        """Parameter minima as a `numpy.ndarray`."""
         if not len(self) == len(min_array):
             raise ValueError("Minima must have same length as parameter list")
 
@@ -504,12 +559,12 @@ class Parameters(collections.abc.Sequence):
 
     @property
     def max(self):
-        """Parameter maxima (`numpy.ndarray`)."""
+        """Parameter maxima as a `numpy.ndarray`."""
         return np.array([_.max for _ in self._parameters], dtype=np.float64)
 
     @max.setter
     def max(self, max_array):
-        """Parameter maxima (`numpy.ndarray`)."""
+        """Parameter maxima as a `numpy.ndarray`."""
         if not len(self) == len(max_array):
             raise ValueError("Maxima must have same length as parameter list")
 
@@ -518,12 +573,12 @@ class Parameters(collections.abc.Sequence):
 
     @property
     def value(self):
-        """Parameter values (`numpy.ndarray`)."""
+        """Parameter values as a `numpy.ndarray`."""
         return np.array([_.value for _ in self._parameters], dtype=np.float64)
 
     @value.setter
     def value(self, values):
-        """Parameter values (`numpy.ndarray`)."""
+        """Parameter values as a `numpy.ndarray`."""
         if not len(self) == len(values):
             raise ValueError("Values must have same length as parameter list")
 
@@ -537,33 +592,33 @@ class Parameters(collections.abc.Sequence):
         Parameters
         ----------
         parameters_list : list of `Parameters`
-            List of `Parameters` objects
+            List of `Parameters` objects.
         """
         pars = itertools.chain(*parameters_list)
         return cls(pars)
 
     def copy(self):
-        """A deep copy"""
+        """Deep copy."""
         return copy.deepcopy(self)
 
     @property
     def norm_parameters(self):
-        """List of norm parameters"""
-        return self.__class__([par for par in self._parameters if par.is_norm])
+        """List of norm parameters."""
+        return self.__class__([par for par in self._parameters if par._is_norm])
 
     @property
     def free_parameters(self):
-        """List of free parameters"""
+        """List of free parameters."""
         return self.__class__([par for par in self._parameters if not par.frozen])
 
     @property
     def unique_parameters(self):
-        """Unique parameters (`Parameters`)."""
+        """Unique parameters as a `Parameters` object."""
         return self.__class__(dict.fromkeys(self._parameters))
 
     @property
     def names(self):
-        """List of parameter names"""
+        """List of parameter names."""
         return [par.name for par in self._parameters]
 
     def index(self, val):
@@ -585,7 +640,7 @@ class Parameters(collections.abc.Sequence):
             raise TypeError(f"Invalid type: {type(val)!r}")
 
     def __getitem__(self, key):
-        """Access parameter by name, index or boolean mask"""
+        """Access parameter by name, index or boolean mask."""
         if isinstance(key, np.ndarray) and key.dtype == bool:
             return self.__class__(list(np.array(self._parameters)[key]))
         else:
@@ -609,18 +664,32 @@ class Parameters(collections.abc.Sequence):
 
         return data
 
+    @staticmethod
+    def _create_default_table():
+        name_to_type = {
+            "type": "str",
+            "name": "str",
+            "value": "float",
+            "unit": "str",
+            "error": "float",
+            "min": "float",
+            "max": "float",
+            "frozen": "bool",
+            "is_norm": "bool",
+            "link": "str",
+            "prior": "str",
+        }
+        return Table(names=name_to_type.keys(), dtype=name_to_type.values())
+
     def to_table(self):
         """Convert parameter attributes to `~astropy.table.Table`."""
-        rows = []
+        table = self._create_default_table()
+
         for p in self._parameters:
-            d = p.to_dict()
-            if "link" not in d:
-                d["link"] = ""
-            for key in ["scale_method", "interp"]:
-                if key in d:
-                    del d[key]
-            rows.append({**dict(type=p.type), **d})
-        table = Table(rows)
+            d = {k: v for k, v in p.to_dict().items() if k in table.colnames}
+            if "prior" in d:
+                d["prior"] = d["prior"]["type"]
+            table.add_row(d)
 
         table["value"].format = ".4e"
         for name in ["error", "min", "max"]:
@@ -658,7 +727,7 @@ class Parameters(collections.abc.Sequence):
     def autoscale(self):
         """Autoscale all parameters.
 
-        See :func:`~gammapy.modeling.Parameter.autoscale`
+        See :func:`~gammapy.modeling.Parameter.autoscale`.
 
         """
         for par in self._parameters:
@@ -670,21 +739,21 @@ class Parameters(collections.abc.Sequence):
         type=None,
         frozen=None,
     ):
-        """Create a mask of models, true if all conditions are verified
+        """Create a mask of models, true if all conditions are verified.
 
         Parameters
         ----------
-        name : str or list
-            Name of the parameter
-        type : {None, spatial, spectral, temporal}
-           type of models
-        frozen : bool
-            Select frozen parameters if True, exclude them if False.
+        name : str or list, optional
+            Name of the parameter. Default is None.
+        type : {None, "spatial", "spectral", "temporal"}
+            Type of models. Default is None.
+        frozen : bool, optional
+            Select frozen parameters if True, exclude them if False. Default is None.
 
         Returns
         -------
         parameters : `Parameters`
-           Selected parameters
+           Selected parameters.
         """
         selection = np.ones(len(self), dtype=bool)
 
@@ -707,12 +776,12 @@ class Parameters(collections.abc.Sequence):
         return self[selection]
 
     def freeze_all(self):
-        """Freeze all parameters"""
+        """Freeze all parameters."""
         for par in self._parameters:
             par.frozen = True
 
     def unfreeze_all(self):
-        """Unfreeze all parameters (even those frozen by default)"""
+        """Unfreeze all parameters (even those frozen by default)."""
         for par in self._parameters:
             par.frozen = False
 
@@ -724,18 +793,16 @@ class Parameters(collections.abc.Sequence):
 
         Parameters
         ----------
-        restore_values : bool
-            Restore values if True, otherwise restore only frozen status.
+        restore_values : bool, optional
+            Restore values if True, otherwise restore only frozen status. Default is None.
 
         Examples
         --------
-        ::
-
-            from gammapy.modeling.models import PowerLawSpectralModel
-            pwl = PowerLawSpectralModel(index=2)
-            with pwl.parameters.restore_status():
-                pwl.parameters["index"].value = 3
-            print(pwl.parameters["index"].value)
+        >>> from gammapy.modeling.models import PowerLawSpectralModel
+        >>> pwl = PowerLawSpectralModel(index=2)
+        >>> with pwl.parameters.restore_status():
+        ...     pwl.parameters["index"].value = 3
+        >>> print(pwl.parameters["index"].value) # doctest: +SKIP
         """
         return restore_parameters_status(self, restore_values)
 
@@ -755,3 +822,85 @@ class restore_parameters_status:
             if self.restore_values:
                 par.value = value
             par.frozen = frozen
+
+
+class PriorParameter(Parameter):
+    def __init__(
+        self,
+        name,
+        value,
+        unit="",
+        scale=1,
+        min=np.nan,
+        max=np.nan,
+        error=0,
+    ):
+        if not isinstance(name, str):
+            raise TypeError(f"Name must be string, got '{type(name)}' instead")
+
+        self._name = name
+        self.scale = scale
+        self.min = min
+        self.max = max
+        self._error = error
+        if isinstance(value, u.Quantity) or isinstance(value, str):
+            val = u.Quantity(value)
+            self.value = val.value
+            self.unit = val.unit
+        else:
+            self.factor = value
+            self.unit = unit
+        self._type = "prior"
+
+    def to_dict(self):
+        """Convert to dictionary."""
+        output = {
+            "name": self.name,
+            "value": self.value,
+            "unit": self.unit.to_string("fits"),
+            "error": self.error,
+            "min": self.min,
+            "max": self.max,
+        }
+        return output
+
+    def __repr__(self):
+        return (
+            f"{self.__class__.__name__}(name={self.name!r}, value={self.value!r}, "
+            f"factor={self.factor!r}, scale={self.scale!r}, unit={self.unit!r}, "
+            f"min={self.min!r}, max={self.max!r})"
+        )
+
+
+class PriorParameters(Parameters):
+    def __init__(self, parameters=None):
+        if parameters is None:
+            parameters = []
+        else:
+            parameters = list(parameters)
+
+        self._parameters = parameters
+
+    def to_table(self):
+        """Convert parameter attributes to `~astropy.table.Table`."""
+        rows = []
+        for p in self._parameters:
+            d = p.to_dict()
+            rows.append({**dict(type=p.type), **d})
+        table = Table(rows)
+
+        table["value"].format = ".4e"
+        for name in ["error", "min", "max"]:
+            table[name].format = ".3e"
+
+        return table
+
+    @classmethod
+    def from_dict(cls, data):
+        parameters = []
+
+        for par in data:
+            parameter = PriorParameter(**par)
+            parameters.append(parameter)
+
+        return cls(parameters=parameters)
