@@ -6,10 +6,9 @@ from scipy.stats import chi2
 
 def sigma_to_ts(n_sigma, df=1):
     """Convert number of sigma to delta ts according to the Wilks' theorem.
-    The theorem is valid only if :
+    The theorem is valid only if:
     - the two hypotheses tested can be defined in the same parameters space
-    - the true value is not at the boundary of this parameters space
-    Reference:  https://en.wikipedia.org/wiki/Wilks%27_theorem
+    - the true value is not at the boundary of this parameters space.
 
     Parameters
     ----------
@@ -22,6 +21,10 @@ def sigma_to_ts(n_sigma, df=1):
     -------
     ts : float
         Test statistic
+
+    Reference
+    ---------
+    Wilks theorem: https://en.wikipedia.org/wiki/Wilks%27_theorem
     """
 
     p_value = chi2.sf(n_sigma**2, df=1)
@@ -38,7 +41,7 @@ def ts_to_sigma(ts, df=1):
     Parameters
     ----------
     ts : float
-        Test statistic
+        Test statistic.
     df : int
         Number of degree of freedom.
 
