@@ -1,5 +1,5 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-"""Utilities for testing"""
+"""Utilities for testing."""
 import os
 import sys
 from numpy.testing import assert_allclose
@@ -59,7 +59,7 @@ def requires_dependency(name):
 
 
 def has_data(name):
-    """Is a certain set of data available?"""
+    """Check if certain set of data available."""
     if name == "gammapy-extra":
         return "GAMMAPY_EXTRA" in os.environ
     elif name == "gammapy-data":
@@ -109,16 +109,16 @@ def run_cli(cli, args, exit_code=0):
     Parameters
     ----------
     cli : click.Command
-        Click command
+        Click command.
     args : list of str
-        Argument list
-    exit_code : int
-        Expected exit code of the command
+        Argument list.
+    exit_code : int, optional
+        Expected exit code of the command. Default is 0.
 
     Returns
     -------
     result : `click.testing.Result`
-        Result
+        Result.
     """
     from click.testing import CliRunner
 
@@ -146,7 +146,7 @@ def assert_skycoord_allclose(actual, desired):
 def assert_time_allclose(actual, desired, atol=1e-3):
     """Assert all-close for `astropy.time.Time` objects.
 
-    atol is absolute tolerance in seconds.
+    atol : Absolute tolerance in seconds. Default is 1e-3.
     """
     assert isinstance(actual, Time)
     assert isinstance(desired, Time)
@@ -157,8 +157,10 @@ def assert_time_allclose(actual, desired, atol=1e-3):
 
 
 def assert_quantity_allclose(actual, desired, rtol=1.0e-7, atol=None, **kwargs):
-    """Assert all-close for `astropy.units.Quantity` objects.
+    """Assert all-close for `~astropy.units.Quantity` objects.
 
+    Notes
+    _____
     Requires that ``unit`` is identical, not just that quantities
     are allclose taking different units into account.
 
@@ -208,7 +210,7 @@ def _unquantify_allclose_arguments(actual, desired, rtol, atol):
 def mpl_plot_check():
     """Matplotlib plotting test context manager.
 
-    It create a new figure on __enter__ and calls savefig for the
+    Create a new figure on __enter__ and calls savefig for the
     current figure in __exit__. This will trigger a render of the
     Figure, which can sometimes raise errors if there is a problem.
 
@@ -252,7 +254,7 @@ UNIT_REPLACEMENTS_ASTROPY_5_3 = {
 
 
 def modify_unit_order_astropy_5_3(expected_str):
-    """Modify unit order for tests with astropy >= 5.3"""
+    """Modify unit order for tests with astropy >= 5.3."""
     if ASTROPY_LT_5_3:
         for old, new in UNIT_REPLACEMENTS_ASTROPY_5_3.items():
             expected_str = expected_str.replace(old, new)
